# Generated by Django 5.1.2 on 2024-11-29 15:45

from django.db import migrations, models

import umap.models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0024_alter_map_share_status"),
    ]

    operations = [
        migrations.AlterField(
            model_name="datalayer",
            name="geojson",
            field=models.FileField(
                blank=True,
                null=True,
                storage=umap.models.set_storage,
                upload_to=umap.models.upload_to,
            ),
        ),
    ]
