# Generated by Django 5.1.2 on 2024-12-10 16:48

from django.db import migrations, models

import umap.models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0023_alter_datalayer_uuid"),
    ]

    operations = [
        migrations.AlterField(
            model_name="map",
            name="share_status",
            field=models.SmallIntegerField(
                choices=[
                    (0, "Draft (private)"),
                    (1, "Everyone (public)"),
                    (2, "Anyone with link"),
                    (3, "Editors and team only"),
                    (9, "Blocked"),
                    (99, "Deleted"),
                ],
                default=umap.models.get_default_share_status,
                verbose_name="share status",
            ),
        ),
    ]
