const locale = {
    "(area: {measure})": "(área: {measure})",
    "(length: {measure})": "(longitud: {measure})",
    "# one hash for main heading": "# una almohadilla para el título principal",
    "## two hashes for second heading": "## dos almohadillas para el subtítulo",
    "### three hashes for third heading": "### tres almohadillas para el título de tercer nivel",
    "**double star for bold**": "**dos asteriscos para negrita**",
    "*single star for italic*": "*un asterisco para cursiva*",
    "--- for a horizontal rule": "--- para una línea horizontal",
    "1 day": "1 día",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Una lista de números separados por comas que define el patrón de guiones. Ej.: \"5, 10, 15\".",
    "About": "Acerca de",
    "Action not allowed :(": "Acción no permitida :(",
    "Activate slideshow mode": "Activar modo de presentación",
    "Add a layer": "Añadir una capa",
    "Add a line to the current multi": "Añadir una línea al multielemento actual",
    "Add a new property": "Añadir una nueva propiedad",
    "Add a polygon to the current multi": "Añadir un polígono al multielemento actual",
    "Add image URL": "Añadir URL de imagen",
    "Advanced actions": "Acciones avanzadas",
    "Advanced properties": "Propiedades avanzadas",
    "All data and settings of the map": "Todos los datos y ajustes del mapa",
    "All properties are imported.": "Todas las propiedades se importaron.",
    "Allow interactions": "Permitir interacciones",
    "Allow scroll wheel zoom?": "¿Permitir zoom con la rueda de desplazamiento?",
    "always": "siempre",
    "Animated transitions": "Transiciones animadas",
    "Are you sure you want to clone this map and all its datalayers?": "¿Estás seguro de que quieres clonar este mapa y todas sus capas de datos?",
    "Are you sure you want to delete this map?": "¿Estás seguro de que quieres eliminar este mapa?",
    "Are you sure you want to delete this property on all the features?": "¿Estás seguro de que quieres eliminar esta propiedad en todos los elementos?",
    "Are you sure you want to restore this version?": "¿Estás seguro de que quieres restaurar esta versión?",
    "Attach the map to my account": "Adjuntar el mapa a mi cuenta",
    "attribution": "atribución",
    "Auto": "Automático",
    "Automatic": "Automático",
    "Autostart when map is loaded": "Inicio automático al cargar el mapa",
    "Back to preview": "Volver a la vista previa",
    "Background overlay url": "URL de superposición de fondo",
    "Ball": "Bola",
    "Bring feature to center": "Centrar el elemento",
    "Browse data": "Explorar datos",
    "by": "por",
    "Cache proxied request": "Almacenar en caché la solicitud de proxy",
    "Caption": "Leyenda",
    "Center map on your location": "Centrar el mapa en tu ubicación",
    "Change tilelayers": "Cambiar capas de teselas",
    "Change": "Cambiar",
    "Choose the data format": "Elegir el formato de datos",
    "Choropleth breakpoints": "Puntos de quiebre del coropleta",
    "Choropleth classes": "Clases de coropleta",
    "Choropleth color palette": "Paleta de colores del coropleta",
    "Choropleth mode": "Modo coropleta",
    "Choropleth property value": "Valor de propiedad del coropleta",
    "Choropleth": "Coropleta",
    "Circle": "Círculo",
    "clear": "limpiar",
    "Click last point to finish shape": "Haz clic en el último punto para terminar la forma",
    "Click to add a marker": "Haz clic para añadir un marcador",
    "Click to continue drawing": "Haz clic para continuar dibujando",
    "Click to edit": "Haz clic para editar",
    "Click to start drawing a line": "Haz clic para empezar a dibujar una línea",
    "Click to start drawing a polygon": "Haz clic para empezar a dibujar un polígono",
    "Clone of {name}": "Copia de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Clone": "Clonar",
    "Close": "Cerrar",
    "Clustered": "Agrupado",
    "Clustering radius": "Radio de agrupamiento",
    "collapsed": "contraído",
    "color": "color",
    "Comma separated list of numbers, including min and max values.": "Lista de números separados por comas, incluyendo valores mínimos y máximos.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Lista de propiedades separadas por comas para ordenar elementos. Para invertir el orden, coloca un signo menos (-) antes. Ej. miclave,-otraclave.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valores separados por coma, tabulación o punto y coma. Se asume SRS WGS84. Solo se importan geometrías de punto. La importación buscará en los encabezados de columna cualquier mención de «lat» y «lon» al principio del encabezado, sin distinción entre mayúsculas y minúsculas. Todas las demás columnas se importan como propiedades.",
    "Congratulations, your map has been created!": "¡Felicidades, tu mapa ha sido creado!",
    "Continue line": "Línea continua",
    "Coordinates": "Coordenadas",
    "copy": "copiar",
    "Credits": "Créditos",
    "Current map view": "Vista actual del mapa",
    "Current view instead of default map view?": "¿Vista actual en lugar de la vista de mapa predeterminada?",
    "Custom background": "Fondo personalizado",
    "Custom overlay": "Superposición personalizada",
    "dash array": "Matriz de guiones",
    "Data is browsable": "Los datos son navegables",
    "Datalayers": "Capas de datos",
    "Default interaction options": "Opciones de interacción predeterminadas",
    "Default properties": "Propiedades predeterminadas",
    "Default shape properties": "Propiedades de forma predeterminadas",
    "Default view": "Vista predeterminada",
    "Default zoom level": "Nivel de zoom predeterminado",
    "Default": "Predeterminado",
    "Default: name": "Predeterminado: nombre",
    "Define link to open in a new window on polygon click.": "Define un enlace para abrir en una nueva ventana al hacer clic en el polígono.",
    "define": "definir",
    "Delay between two transitions when in play mode": "Retraso entre dos transiciones en modo de reproducción",
    "Delete layer": "Eliminar capa",
    "Delete this feature": "Eliminar este elemento",
    "Delete this shape": "Eliminar esta forma",
    "Delete this vertex (Alt+Click)": "Eliminar este vértice (Alt+Clic)",
    "Delete": "Eliminar",
    "description": "descripción",
    "Direct link": "Enlace directo",
    "Directions from here": "Indicaciones desde aquí",
    "Display label": "Mostrar etiqueta",
    "Display measure": "Mostrar medición",
    "display name": "nombre para mostrar",
    "Display on load": "Mostrar al cargar",
    "Display the control to open OpenStreetMap editor": "Mostrar el control para abrir el editor de OpenStreetMap",
    "Display the embed control": "Mostrar el control de embebido",
    "Display the fullscreen control": "Mostrar el control de pantalla completa",
    "Display the locate control": "Mostrar el control de ubicación",
    "Display the measure control": "Mostrar el control de medición",
    "Display the search control": "Mostrar el control de búsqueda",
    "Display the tile layers control": "Mostrar el control de capas de teselas",
    "Display the zoom control": "Mostrar el control de zoom",
    "Do you want to display a caption bar?": "¿Quieres mostrar una barra de título?",
    "Do you want to display a minimap?": "¿Quieres mostrar un minimapa?",
    "Do you want to display a panel on load?": "¿Quieres mostrar un panel al cargar?",
    "Do you want to display caption menus?": "¿Quieres mostrar los menús de título?",
    "Do you want to display popup footer?": "¿Quieres mostrar el pie de página emergente?",
    "Do you want to display the scale control?": "¿Quieres mostrar el control de escala?",
    "Do you want to display the «more» control?": "¿Quieres mostrar el control «más»?",
    "Download": "Descargar",
    "Drag to reorder": "Arrastrar para reordenar",
    "Draw a marker": "Dibujar un marcador",
    "Draw a polygon": "Dibujar un polígono",
    "Draw a polyline": "Dibujar una polilínea",
    "Drawing": "Dibujo",
    "Drop": "Gota",
    "Dynamic properties": "Propiedades dinámicas",
    "Dynamic": "Dinámico",
    "Edit feature's layer": "Editar la capa del elemento",
    "Edit properties in a table": "Editar propiedades en una tabla",
    "Edit the title of the map": "Editar el título del mapa",
    "Edit this feature": "Editar este elemento",
    "Edit": "Editar",
    "Embed and link options": "Opciones de embebido y enlace",
    "Embed the map": "Embeber el mapa",
    "Emoji & Character": "Emoji y carácter",
    "Empty": "Vaciar",
    "Equidistant": "Equidistante",
    "Error in the overlay URL": "Error en la URL de superposición",
    "Error in the tilelayer URL": "Error en la URL de la capa de teselas",
    "Exit Fullscreen": "Salir de pantalla completa",
    "expanded": "expandido",
    "Extract shape to separate feature": "Extraer forma a un elemento separado",
    "Feature identifier key": "Clave identificadora del elemento",
    "Feature properties": "Propiedades del elemento",
    "Fetch data each time map view changes.": "Obtener datos cada vez que cambie la vista del mapa.",
    "fill color": "color de relleno",
    "fill opacity": "opacidad de relleno",
    "fill": "relleno",
    "Fit all data": "Ajustar a todos los datos",
    "Format": "Formato",
    "From zoom": "Desde zoom",
    "full backup": "copia de seguridad completa",
    "Generic": "Genérico",
    "GeoRSS (only link)": "GeoRSS (solo enlace)",
    "GeoRSS (title + image)": "GeoRSS (título + imagen)",
    "Go to \"{coords}\"": "Ir a \"{coords}\"",
    "Go to the homepage": "Ir a la página de inicio",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap intensity property": "Propiedad de intensidad del mapa de calor",
    "Heatmap radius": "Radio del mapa de calor",
    "Heatmap": "Mapa de calor",
    "height": "altura",
    "Help": "Ayuda",
    "hidden": "oculto",
    "Hide controls": "Ocultar controles",
    "Home": "Inicio",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Cuánto simplificar la polilínea en cada nivel de zoom (más = mejor rendimiento y apariencia más suave, menos = más preciso)",
    "icon opacity": "opacidad del icono",
    "Icon shape": "Forma del icono",
    "Icon symbol": "Símbolo del icono",
    "If false, the polygon or line will act as a part of the underlying map.": "Si es falso, el polígono o la línea actuarán como parte del mapa subyacente.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe con altura personalizada (en px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe con altura y ancho personalizados (en px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Imagen con ancho personalizado (en px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Imagen: {{https://image.url.com}}",
    "Import data": "Importar datos",
    "Import in a new layer": "Importar en una nueva capa",
    "Imports all umap data, including layers and settings.": "Importa todos los datos de uMap, incluyendo capas y configuraciones.",
    "Include full screen link?": "¿Incluir enlace a pantalla completa?",
    "Inherit": "Heredar",
    "inherit": "heredar",
    "Interaction options": "Opciones de interacción",
    "Invalid latitude or longitude": "Latitud o longitud inválida",
    "Invalid umap data in {filename}": "Datos de uMap inválidos en {filename}",
    "Invalid umap data": "Datos de uMap inválidos",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-medias",
    "Keep current visible layers": "Mantener las capas visibles actuales",
    "kilometers": "kilómetros",
    "km": "km",
    "Label direction": "Dirección de la etiqueta",
    "Label key": "Clave de etiqueta",
    "Labels are clickable": "Etiquetas cliqueables / en las que se puede hacer clic",
    "Latest feature": "Último elemento",
    "Latitude": "Latitud",
    "Layer properties": "Propiedades de la capa",
    "Layer": "Capa",
    "Licence": "Licencia",
    "licence": "licencia",
    "Limit bounds": "Límites",
    "Link to view the map": "Enlace para ver el mapa",
    "Link to…": "Enlace a...",
    "Link with text: [[https://example.com|text of the link]]": "Enlace con texto: [[https://example.com|text of the link]]",
    "Long credits": "Créditos largos",
    "Longitude": "Longitud",
    "Make main shape": "Convertir en forma principal",
    "Manage layers": "Administrar capas",
    "Manual": "Manual",
    "Map background credits": "Créditos del fondo del mapa",
    "Map has been attached to your account": "El mapa se ha adjuntado a tu cuenta",
    "Map has been saved!": "¡Mapa guardado!",
    "Map has been starred": "El mapa ha sido marcado con una estrella",
    "Map has been unstarred": "El mapa ha sido desmarcado",
    "Map user content has been published under licence": "El contenido del mapa del usuario ha sido publicado bajo licencia",
    "Map's editors": "Editores del mapa",
    "Map's owner": "Propietario del mapa",
    "max East": "Este máx.",
    "max North": "Norte máx.",
    "max South": "Sur máx.",
    "max West": "Oeste máx.",
    "max zoom": "zoom máximo",
    "Measure distances": "Medir distancias",
    "Merge lines": "Combinar líneas",
    "mi": "mi",
    "miles": "millas",
    "min zoom": "zoom mínimo",
    "More controls": "Más controles",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Debe ser un valor CSS válido (ej.: DarkBlue o #123456)",
    "name": "nombre",
    "nautical miles": "millas náuticas",
    "never": "nunca",
    "new window": "nueva ventana",
    "next": "siguiente",
    "NM": "NM",
    "No cache": "Sin caché",
    "No licence has been set": "No se ha establecido ninguna licencia",
    "No results": "Sin resultados",
    "no": "no",
    "No.": "Núm.",
    "None": "Ninguno",
    "Number of desired classes (default 5)": "Número de clases deseadas (5 por defecto)",
    "On the bottom": "En la parte inferior",
    "On the left": "A la izquierda",
    "On the right": "A la derecha",
    "On the top": "En la parte superior",
    "Only visible layers' data": "Solo datos de capas visibles",
    "opacity": "opacidad",
    "Opacity": "Opacidad",
    "Open current feature on load": "Abrir el elemento actual al cargar",
    "Open link in…": "Abrir enlace en…",
    "Open share & download panel": "Abrir panel de compartir y descargar",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abre esta extensión de mapa en un editor de mapas para proporcionar datos más precisos a OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Propiedad de intensidad opcional para mapa de calor",
    "Optional. Same as color if not set.": "Opcional. Igual que el color si no se establece.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Anular el radio de agrupamiento (80 por defecto)",
    "Override heatmap radius (default 25)": "Anular el radio del mapa de calor (25 por defecto)",
    "parent window": "ventana padre",
    "Paste your data here": "Pega tus datos aquí",
    "Permalink": "Enlace permanente",
    "Permanent credits background": "Fondo de créditos permanente",
    "Permanent credits": "Créditos permanentes",
    "Please be sure the licence is compliant with your use.": "Asegúrate de que la licencia sea compatible con tu uso.",
    "Please choose a format": "Elige un formato",
    "Please enter the name of the property": "Introduce el nombre de la propiedad",
    "Please enter the new name of this property": "Introduce el nuevo nombre de esta propiedad",
    "Please save the map first": "Guarda el mapa primero",
    "Popup (large)": "Ventana emergente (grande)",
    "Popup content style": "Estilo del contenido emergente",
    "Popup content template": "Plantilla de contenido emergente",
    "Popup shape": "Forma del elemento emergente",
    "Popup": "Ventana emergente / emergente",
    "Powered by uMap": "Desarrollado por uMap",
    "previous": "anterior",
    "Problem in the response": "Problema en la respuesta",
    "Properties imported:": "Propiedades importadas:",
    "Provide an URL here": "Proporciona una URL aquí",
    "Proxy request": "Solicitud proxy",
    "Quantiles": "Cuantiles",
    "Recent": "Recientes",
    "Remote data": "Datos remotos",
    "Remove shape from the multi": "Eliminar forma del multielemento",
    "Replace layer content": "Reemplazar el contenido de la capa",
    "Restore this version": "Restaurar esta versión",
    "Save current edits": "Guardar las ediciones actuales",
    "Save map": "Guardar mapa",
    "Save": "Guardar",
    "Saved center and zoom": "Centro y zoom guardados",
    "Search location": "Buscar ubicación",
    "Search": "Buscar",
    "Secret edit link:": "Enlace secreto de edición:",
    "See full screen": "Ver en pantalla completa",
    "See on OpenStreetMap": "Ver en OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Establécelo en falso para ocultar esta capa de la presentación de diapositivas, el explorador de datos, la navegación emergente…",
    "settings": "ajustes",
    "Shape properties": "Propiedades de la forma",
    "Share and download": "Compartir y descargar",
    "Share this link to open a customized map view": "Comparte este enlace para abrir una vista de mapa personalizada",
    "Short credits": "Créditos cortos",
    "Short link": "Enlace corto",
    "Show this layer in the caption": "Mostrar esta capa en la leyenda",
    "Show/hide layer": "Mostrar/ocultar capa",
    "Side panel": "Panel lateral",
    "Simple link: [[https://example.com]]": "Enlace simple: [[https://example.com]]",
    "Simplify": "Simplificar",
    "Skipping unknown geometry.type: {type}": "Omitiendo geometry.type desconocido: {type}",
    "Slideshow": "Presentación de diapositivas",
    "Sort key": "Clave de ordenación",
    "Split line": "Línea de división",
    "Star this map": "Marcar este mapa con una estrella",
    "Start a hole here": "Empezar un agujero aquí",
    "Start slideshow": "Iniciar presentación",
    "Stop editing": "Detener edición",
    "Stop slideshow": "Detener presentación",
    "Street": "Calle",
    "stroke": "trazo",
    "Supported scheme": "Esquema compatible",
    "Supported variables that will be dynamically replaced": "Variables compatibles que se reemplazarán dinámicamente",
    "Symbol": "Símbolo",
    "Table": "Tabla",
    "Text color for the cluster label": "Color del texto de la etiqueta del clúster",
    "Text formatting": "Formato de texto",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "El nombre de la propiedad para usar como etiqueta de elemento (ej.: \"nombre\"). También puedes usar propiedades entre llaves para usar más de una o mezclar con contenido estático (p. ej.: \"&lcub;nombre&rcub; en &lcub;lugar&rcub;\")",
    "The name of the property to use as feature unique identifier.": "El nombre de la propiedad a utilizar como identificador único del elemento.",
    "The zoom and center have been modified.": "Se han modificado el zoom y el centro.",
    "TMS format": "formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Usar si el servidor remoto no permite dominios cruzados (más lento)",
    "To zoom": "Para hacer zoom",
    "Toggle edit mode (⇧+Click)": "Alternar modo de edición (⇧+Clic)",
    "Toggle edit mode": "Alternar modo de edición",
    "Transfer shape to edited feature": "Transferir forma al elemento editado",
    "Transform to lines": "Transformar a líneas",
    "Transform to polygon": "Transformar a polígono",
    "Type a place name or coordinates": "Escribe un nombre de lugar o coordenadas",
    "Type char or paste emoji": "Escribe un carácter o pega un emoji",
    "Type of layer": "Tipo de capa",
    "Unable to detect format of file {filename}": "No se puede detectar el formato del archivo {filename}",
    "Untitled layer": "Capa sin título",
    "Untitled map": "Mapa sin título",
    "Update permissions and editors": "Actualizar permisos y editores",
    "Update permissions": "Actualizar permisos",
    "Update who can see and edit the map": "Actualizar quién puede ver y editar el mapa",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Usar límites actuales",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Utiliza marcadores de posición con propiedades de elemento entre llaves, por ejemplo,  &#123;nombre&#125;, que se reemplazarán dinámicamente con los valores correspondientes.",
    "User content credits": "Créditos de contenido del usuario",
    "User interface options": "Opciones de la interfaz de usuario",
    "User location": "Ubicación del usuario",
    "Verify remote URL": "Verificar URL remota",
    "Versions": "Versiones",
    "View Fullscreen": "Ver en pantalla completa",
    "View": "Ver",
    "Visibility: {status}": "Visibilidad: {status}",
    "weight": "grosor",
    "Where do we go from here?": "¿A dónde vamos desde aquí?",
    "Whether to display or not polygons paths.": "Si se deben mostrar o no las rutas de los polígonos.",
    "Whether to fill polygons with color.": "Si se deben rellenar los polígonos con color.",
    "Who can edit \"{layer}\"": "Quién puede editar \"{layer}\"",
    "Who can edit": "Quién puede editar",
    "Who can view": "Quién puede ver",
    "width": "ancho",
    "Will be displayed in the bottom right corner of the map": "Se mostrará en la esquina inferior derecha del mapa",
    "Will be permanently visible in the bottom left corner of the map": "Estará visible permanentemente en la esquina inferior izquierda del mapa",
    "Will be visible in the caption of the map": "Será visible en la leyenda del mapa",
    "yes": "sí",
    "Zoom in": "Acercar",
    "Zoom level for automatic zooms": "Nivel de zoom para zooms automáticos",
    "Zoom out": "Alejar",
    "Zoom to layer extent": "Zoom a la extensión de la capa",
    "Zoom to the next": "Zoom al siguiente",
    "Zoom to the previous": "Zoom al anterior",
    "Zoom to this feature": "Zoom a este elemento",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errores durante la importación: {message}",
    "{delay} seconds": "{delay} segundos",
    "{distance}&#8239;km": "{distance}&#8239;km",
    "{distance}&#8239;m": "{distance}&#8239;m",
    "{distance}&#8239;miles": "{distance}&#8239;millas",
    "{distance}&#8239;NM": "{distance}&#8239;NM",
    "{distance}&#8239;yd": "{distance}&#8239;yd",
    "Edit map name and caption": "Editar nombre y leyenda del mapa",
    "Map advanced properties": "Propiedades avanzadas del mapa",
    "Edit map details": "Editar detalles del mapa",
    "Back to browser": "Volver al navegador",
    "Toggle size": "Cambiar tamaño",
    "Display the caption control": "Mostrar el control de leyenda",
    "<empty value>": "<valor vacío>",
    "Min": "Mín.",
    "Max": "Máx.",
    "From": "Desde",
    "Until": "Hasta",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Ejemplo: clave1,clave2|Etiqueta 2,clave3|Etiqueta 3|casilla de verificación",
    "Edit in OpenStreetMap": "Editar en OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "No se pueden determinar las columnas de latitud y longitud.",
    "Back to layers": "Volver a las capas",
    "Filters": "Filtros",
    "Comma separated list of properties to use when filtering features by text input": "Lista de propiedades separadas por comas para usar al filtrar elementos por entrada de texto",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Lista de propiedades separadas por comas para usar para filtros (ej.: miclave,otraclave). Para controlar la etiqueta, agrégala después de un | (ej.: miclave|Mi Clave,otraclave|Otra Clave). Para controlar el tipo de campo de entrada, agrégalo después de otro | (ej.: miclave|Mi Clave|casilla de verificación,otraclave|Otra Clave|fechahora). Los valores permitidos para el tipo de campo de entrada son casilla de verificación (predeterminado), radio, número, fecha y fechahora.",
    "Search keys": "Claves de búsqueda",
    "Filters keys": "Claves de filtros",
    "Filter data": "Filtrar datos",
    "Search map features…": "Buscar elementos del mapa…",
    "Reset all": "Reiniciar todo",
    "Open browser": "Abrir navegador",
    "Open caption": "Abrir leyenda",
    "Your map has been created with an anonymous account!": "¡Tu mapa ha sido creado con una cuenta anónima!",
    "Real-time collaboration": "Colaboración en tiempo real",
    "Cannot parse data": "No se pueden analizar los datos",
    "Start typing...": "Empieza a escribir...",
    "No result": "Sin resultados",
    "Data browser": "Explorador de datos",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Al proporcionar una URL, uMap puede copiar los datos remotos en una capa o agregar esta URL como fuente remota de la capa. En ese caso, los datos siempre se obtendrán de esa URL y, por lo tanto, estarán actualizados, pero no será posible editarlos dentro de uMap.",
    "Overpass supported expressions": "Expresiones compatibles con Overpass",
    "key (eg. building)": "clave (ej. edificio)",
    "!key (eg. !name)": "!clave (ej. !nombre)",
    "key=value (eg. building=yes)": "clave=valor (ej. edificio=sí)",
    "key!=value (eg. building!=yes)": "clave!=valor (ej. edificio!=sí)",
    "key~value (eg. name~Grisy)": "clave~valor (ej. nombre~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "clave=\"valor|valor2\" (ej. nombre=\"París|Berlín\")",
    "More info about Overpass syntax": "Más información sobre la sintaxis de Overpass",
    "For more complex needs, see": "Para necesidades más complejas, consulta",
    "Choose data": "Elegir datos",
    "Choose the format": "Elegir el formato",
    "Choose the layer": "Elegir la capa",
    "Layer name": "Nombre de la capa",
    "Choose import mode": "Elegir modo de importación",
    "Copy into the layer": "Copiar en la capa",
    "Link to the layer as remote data": "Vincular a la capa como datos remotos",
    "Condition": "Condición",
    "key=value or key!=value": "clave=valor o clave!=valor",
    "Are you sure you want to delete this rule?": "¿Estás seguro de que quieres eliminar esta regla?",
    "empty rule": "regla vacía",
    "Conditional style rules": "Reglas de estilo condicionales",
    "Add rule": "Añadir regla",
    "Browser: data": "Navegador: datos",
    "Browser: layers": "Navegador: capas",
    "Browser: filters": "Navegador: filtros",
    "Enable real-time collaboration": "Habilitar la colaboración en tiempo real",
    "✅ Copied!": "✅ ¡Copiado!",
    "Choose a dataset": "Elegir un conjunto de datos",
    "Choose this dataset": "Elegir este conjunto de datos",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: datos temáticos de OpenStreetMap",
    "Choose a theme": "Elegir un tema",
    "Choose this data": "Elegir estos datos",
    "Search admin boundary": "Buscar límite administrativo",
    "Please choose a theme and a boundary first.": "Primero elige un tema y un límite.",
    "Expression": "Expresión",
    "Geometry mode": "Modo de geometría",
    "Only geometry centers": "Solo centros de geometría",
    "Search area": "Área de búsqueda",
    "Type area name, or let empty to load data in current map view": "Escribe el nombre del área o déjalo vacío para cargar datos en la vista actual del mapa",
    "Data successfully imported!": "¡Datos importados correctamente!",
    "Clear data": "Borrar datos",
    "Remove layers": "Eliminar capas",
    "Categorized": "Categorizado",
    "Alphabetical": "Alfabético",
    "Category property": "Propiedad de categoría",
    "Color palette": "Paleta de colores",
    "Categories": "Categorías",
    "Comma separated list of categories.": "Lista de categorías separadas por comas.",
    "Categories mode": "Modo de categorías",
    "Remove filter for this column": "Eliminar filtro para esta columna",
    "Add filter for this column": "Agregar filtro para esta columna",
    "Rename this column": "Cambiar el nombre de esta columna",
    "Delete this column": "Eliminar esta columna",
    "Name “{name}” should not contain a dot.": "El nombre \"{name}\" no debe contener un punto.",
    "This name already exists: “{name}”": "Este nombre ya existe: \"{name}\"",
    "Delete selected rows": "Eliminar filas seleccionadas",
    "Found {count} rows. Are you sure you want to delete all?": "Se encontraron {count} filas. ¿Estás seguro de que quieres eliminarlas todas?",
    "Expression is empty": "La expresión está vacía",
    "OK": "Aceptar",
    "Cancel": "Cancelar",
    "Attach map to a team": "Adjuntar mapa a un equipo",
    "Display the polygon inverted": "Mostrar el polígono invertido",
    "Proportional circles": "Círculos proporcionales",
    "Property name to compute circles": "Nombre de la propiedad para calcular círculos",
    "Min circle radius": "Radio mínimo del círculo",
    "Max circle radius": "Radio máximo del círculo",
    "Display the open browser control": "Mostrar el control de abrir el navegador",
    "Copy as GeoJSON": "Copiar como GeoJSON",
    "Please zoom in to edit the geometry": "Acerca el zoom para editar la geometría",
    "New map": "Nuevo mapa",
    "My maps": "Mis mapas",
    "My teams": "Mis equipos",
    "My profile": "Mi perfil",
    "Type new owner's username": "Escribe el nombre de usuario del nuevo propietario",
    "Type editor's username": "Escribe el nombre de usuario del editor",
    "Map": "Mapa",
    "Manage collaborators": "Administrar colaboradores",
    "show/hide all layers": "mostrar/ocultar todas las capas",
    "zoom to data extent": "zoom a la extensión de los datos",
    "download visible data": "descargar datos visibles",
    "Import helpers": "Ayudas para importar",
    "Import helpers will fill the URL field for you.": "Las ayudas para importar completarán el campo de URL por ti.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Guardar borrador",
    "No data has been found for import": "No se han encontrado datos para importar",
    "Successfully imported {count} feature(s)": "{count} elemento(s) importado(s) con éxito",
    "Disconnected": "Desconectado",
    "You must be logged in": "Debes iniciar sesión",
    "on hover": "al pasar el cursor",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "No se pueden cargar datos remotos para la capa \"{layer}\" con la URL \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "No se pueden analizar los datos remotos para la capa \"{layer}\" con la URL \"{url}\"",
    "Import failed: invalid data": "Falló la importación: datos no válidos",
    "Anonymous": "Anónimo",
    "created at {date}": "creado el {date}",
    "modified at {date}": "modificado el {date}",
    "Default zoom": "Zoom predeterminado",
    "Default latitude": "Latitud predeterminada",
    "Default longitude": "Longitud predeterminada",
    "Edit map default view": "Editar vista predeterminada del mapa",
    "Use current center and zoom": "Usar el centro y zoom actuales",
    "Layer permalink": "Enlace permanente de la capa",
    "Back to home": "Volver al inicio",
    "Home logo": "Logo de inicio",
    "Add this geometry to my map": "Agregar esta geometría a mi mapa",
    "Add this place to my map": "Agregar este lugar a mi mapa",
    "Cancel last edit": "Cancelar la última edición",
    "Redo last edit": "Rehacer la última edición",
    "Links": "Enlaces",
    "Images": "Imágenes",
    "Iframes": "Iframes",
    "Tags": "Etiquetas",
    "Geocode": "Geocodificar",
    "Display the back to home icon": "Mostrar el ícono de volver al inicio",
    "Do you want to display layer switcher in caption bar?": "¿Quieres mostrar el selector de capas en la barra de título?",
    "Simplify all geometries to points": "Simplificar todas las geometrías a puntos",
    "Back to list": "Volver a la lista",
    "Toggle rule": "Alternar regla",
    "Delete rule": "Eliminar regla",
    "Cannot save layer, please try again in a few minutes.": "No se puede guardar la capa, por favor intenta de nuevo en unos minutos.",
    "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.": "Activa la edición colaborativa en vivo en este mapa. Otros usuarios deben recargar el mapa después de cambiar esta configuración.",
    "More help resources": "Más recursos de ayuda",
    "This map is a template": "Este mapa es una plantilla",
    "Add text along path": "Agregar texto a lo largo del trazo",
    "Text color": "Color del texto",
    "Text offset": "Desplazamiento del texto",
    "Text position": "Posición del texto",
    "start": "inicio",
    "center": "centro",
    "end": "final",
    "Text repeat": "Repetir texto",
    "Text rotate": "Rotar texto",
    "Text size": "Tamaño del texto",
    "Load map template": "Cargar plantilla de mapa",
    "My templates": "Mis plantillas",
    "From staff": "Del staff",
    "From community": "De la comunidad",
    "You must select a template.": "Debes seleccionar una plantilla.",
    "Line decoration": "Decoración de línea",
    "Reuse this template": "Reutilizar esta plantilla",
    "Create a new map using this template": "Crear un nuevo mapa usando esta plantilla",
    "Save template": "Guardar plantilla",
    "Load template": "Cargar plantilla",
    "Loading a template will apply predefined styles and settings to your map": "Cargar una plantilla aplicará estilos y configuraciones predefinidas a tu mapa",
    "Load template with data": "Cargar plantilla con datos",
    "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".": "Aún no tienes ninguna plantilla registrada. Puedes agregar una creando un nuevo mapa y marcándolo como \"plantilla\".",
    "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.": "Aún no hay una plantilla recomendada. Las plantillas recomendadas son las destacadas por los administradores de uMap.",
    "There is no public template yet.": "Aún no hay plantillas públicas.",
    "Explore": "Explorar",
    "Import data from public open data portals": "Importar datos desde portales públicos de datos abiertos",
    "Choose a portal": "Elegir un portal",
    "Limit results to current map view": "Limitar los resultados a la vista actual del mapa",
    "Please choose an instance first.": "Por favor elige una instancia primero."
}
L.registerLocale("es", locale)
L.setLocale("es")
