# Generated by Django 5.1.7 on 2025-04-17 09:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0027_map_tags"),
    ]

    operations = [
        migrations.AddField(
            model_name="map",
            name="is_template",
            field=models.BooleanField(
                default=False,
                help_text="This map is a template map.",
                verbose_name="save as template",
            ),
        ),
    ]
