const locale = {
    "(area: {measure})": "(terület: {measure})",
    "(length: {measure})": "(távolság: {measure})",
    "# one hash for main heading": "# egy számjel: fő címsor",
    "## two hashes for second heading": "## két számjel: második címsor",
    "### three hashes for third heading": "### három számjel: harmadik címsor",
    "**double star for bold**": "**két csillag: félkövér**",
    "*single star for italic*": "*egy csillag: dőlt*",
    "--- for a horizontal rule": "--- vízszintes vonal",
    "1 day": "1 nap",
    "1 hour": "1 óra",
    "5 min": "5 perc",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Vesszővel tagolt számsor, amely meghatározza a szaggatott vonalak mintázatát. Például 5,10,15 Ha nem világos, próbálkozz!",
    "About": "Térkép névjegye",
    "Action not allowed :(": "Nem engedélyezett művelet :(",
    "Activate slideshow mode": "Diavetítésmód aktiválása",
    "Add a layer": "Réteg hozzáadása",
    "Add a line to the current multi": "Vonal hozzáadása a jelenlegi alakzatcsoporthoz",
    "Add a new property": "Új tulajdonság hozzáadása",
    "Add a polygon to the current multi": "Sokszög hozzáadása a jelenlegi alakzatcsoporthoz",
    "Add image URL": "Kép URL-je",
    "Advanced actions": "Speciális műveletek",
    "Advanced properties": "Speciális tulajdonságok",
    "All data and settings of the map": "A térkép összes adata és beállítása",
    "All properties are imported.": "Minden tulajdonság importálva lett.",
    "Allow interactions": "Interakció engedélyezése",
    "Allow scroll wheel zoom?": "Engedélyezi-e a görgetést nagyításkor?",
    "always": "mindig",
    "Animated transitions": "Animált áttűnések",
    "Are you sure you want to clone this map and all its datalayers?": "Biztosan klónozza a térképet és az összes adatrétegét?",
    "Are you sure you want to delete this map?": "Biztosan törölni szeretné ezt a térképet?",
    "Are you sure you want to delete this property on all the features?": "Biztosan törölni szeretné ezt a tulajdonságot az összes objektumról?",
    "Are you sure you want to restore this version?": "Biztosan ezt a változatot akarja helyreállítani?",
    "Attach the map to my account": "Térkép csatolása a fiókomhoz",
    "attribution": "szerzőmegjelölés",
    "Auto": "Automatikus",
    "Automatic": "Automatikus",
    "Autostart when map is loaded": "Automatikus indulás a térkép betöltése után",
    "Back to preview": "Vissza az előnézethez",
    "Background overlay url": "Háttérbeli fedőréteg URL-je",
    "Ball": "Gombostű",
    "Bring feature to center": "Objektum középre hozása",
    "Browse data": "Adatok böngészése",
    "by": "- készítette:",
    "Cache proxied request": "Proxy keresztül továbbított gyorsítótárkérés",
    "Caption": "Leírás",
    "Center map on your location": "A térkép közepének igazítása a saját pozícióhoz",
    "Change tilelayers": "Mozaikrétegek módosítása",
    "Change": "Módosítás",
    "Choose the data format": "Adatformátum kiválasztása",
    "Choropleth breakpoints": "Kartogram töréspontjai",
    "Choropleth classes": "Kartogram kategóriái",
    "Choropleth color palette": "Kartogram színskálája",
    "Choropleth mode": "Kartogram mód",
    "Choropleth property value": "Kartogram tulajdonságértékei",
    "Choropleth": "Kartogram",
    "Circle": "Kör",
    "clear": "alaphelyzet",
    "Click last point to finish shape": "Az alakzat befejezéséhez kattintson az utolsó pontra",
    "Click to add a marker": "Jelölő hozzáadásához kattintson",
    "Click to continue drawing": "Kattintson a rajzolás folytatásához",
    "Click to edit": "Kattintson a szerkesztéshez",
    "Click to start drawing a line": "Kattintson egy vonal rajzolásához",
    "Click to start drawing a polygon": "Kattintson egy sokszög rajzolásához",
    "Clone of {name}": "{name} klónozása",
    "Clone this feature": "Objektum klónozása",
    "Clone this map": "Térkép klónozása",
    "Clone": "Klónozás",
    "Close": "Bezárás",
    "Clustered": "Csoportosított",
    "Clustering radius": "Csoportosítás sugara",
    "collapsed": "összecsukva",
    "color": "szín",
    "Comma separated list of numbers, including min and max values.": "Vesszővel tagolt számsor, közte a legkisebb és a legnagyobb értékek.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "A jellemzők sorba rendezéséhez használandó tulajdonságok vesszővel tagolt sora. A sorba rendezés megfordításához tegyen mínusz jelet (-) elé. Például: kulcs,-másikkulcs.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Vesszővel, pontosvesszővel vagy tabulátorral tagolt értékek a WGS84 referenciarendszer szerint. Csak a pontok pozíciója importálódik. Az import során az oszlopfejlécekben, a címsor kezdetén található „lat” és „long” említések vétetenek figyelembe; kis- vagy nagybetű nem számít. Az összes többi oszlop tulajdonságként importálódik.",
    "Congratulations, your map has been created!": "Gratulálunk, a térképe elkészült!",
    "Continue line": "Vonal folytatása",
    "Coordinates": "Koordináták",
    "copy": "másolás",
    "Credits": "Alkotók",
    "Current map view": "Jelenlegi térképnézet",
    "Current view instead of default map view?": "Használja-e a jelenlegi nézetet az alapértelmezett helyett?",
    "Custom background": "Egyedi háttér",
    "Custom overlay": "Egyedi fedőréteg",
    "dash array": "Szaggatottság mintázata",
    "Data is browsable": "Az adatok böngészhetők",
    "Datalayers": "Adatrétegek",
    "Default interaction options": "Alapértelmezett interakciós beállítások",
    "Default properties": "Alapértelmezett tulajdonságok",
    "Default shape properties": "Alapértelmezett alakzattulajdonságok",
    "Default view": "Alapértelmezett nézet",
    "Default zoom level": "Alapértelmezett nagyítási szint",
    "Default": "Alapértelmezett",
    "Default: name": "Alapértelmezett: név",
    "Define link to open in a new window on polygon click.": "A sokszögre kattintva új ablakban megnyíló link meghatározása.",
    "define": "meghatározás",
    "Delay between two transitions when in play mode": "Az áttűnések közötti késés lejátszási üzemmódban",
    "Delete layer": "Réteg törlése",
    "Delete this feature": "Objektum törlése",
    "Delete this shape": "Alakzat törlése",
    "Delete this vertex (Alt+Click)": "Sarokpont törlése (Alt+Klikk)",
    "Delete": "Törlés",
    "description": "leírás",
    "Direct link": "Közvetlen link",
    "Directions from here": "Irányok innen",
    "Display label": "Felirat megjelenítése",
    "Display measure": "Távolságmérő megjelenítése",
    "display name": "név megjelenítése",
    "Display on load": "Megjelenítés betöltéskor",
    "Display the control to open OpenStreetMap editor": "Az OpenStreetMap szerkesztő megnyitása vezérlő megjelenítése",
    "Display the embed control": "Beágyazás vezérlő megjelenítése",
    "Display the fullscreen control": "Teljes képernyő vezérlő megjelenítése",
    "Display the locate control": "Saját pozícióhoz igazítás vezérlő megjelenítése",
    "Display the measure control": "Mérés vezérlő megjelenítése",
    "Display the search control": "Keresés vezérlő megjelenítése",
    "Display the tile layers control": "Mozaikrétegek vezérlő megjelenítése",
    "Display the zoom control": "Nagyítás vezérlő megjelenítése",
    "Do you want to display a caption bar?": "Szeretné megjeleníteni a leírást tartalmazó sávot?",
    "Do you want to display a minimap?": "Szeretne megjeleníteni egy kis térképet?",
    "Do you want to display a panel on load?": "Betöltéskor szeretne-e megjeleníteni egy panelt?",
    "Do you want to display caption menus?": "Szeretné megjeleníteni a térkép címsávmenüjét?",
    "Do you want to display popup footer?": "Szeretn-e megjeleníteni egy előugró láblécet?",
    "Do you want to display the scale control?": "Szeretné megjeleníteni a méretarány vezérlőt?",
    "Do you want to display the «more» control?": "Szeretné megjeleníteni a „továbbiak” vezérlőt?",
    "Download": "Letöltés",
    "Drag to reorder": "Az átrendezéshez húzza át",
    "Draw a marker": "Jelölő rajzolása",
    "Draw a polygon": "Sokszög rajzolása",
    "Draw a polyline": "Töröttvonal rajzolása",
    "Drawing": "Rajzolás",
    "Drop": "Csepp",
    "Dynamic properties": "Dinamikus tulajdonságok",
    "Dynamic": "Dinamikus",
    "Edit feature's layer": "Objektum rétegének szerkesztése",
    "Edit properties in a table": "Tulajdonságok szerkesztése táblázatban",
    "Edit the title of the map": "Térkép címének szerkesztése",
    "Edit this feature": "Objektum szerkesztése",
    "Edit": "Szerkesztés",
    "Embed and link options": "Beágyazási és linkelési beállítások",
    "Embed the map": "Térkép beágyazása",
    "Emoji & Character": "Emoji vagy karakter",
    "Empty": "Kiürítés",
    "Equidistant": "Azonos távolságok",
    "Error in the overlay URL": "Hiba a fedőréteg URL-jében",
    "Error in the tilelayer URL": "Hiba a mozaikréteg URL-jében",
    "Exit Fullscreen": "Kilépés a teljes képernyős nézetből",
    "expanded": "kiterjesztett",
    "Extract shape to separate feature": "Alakzat kiemelése objektum széválasztásához",
    "Feature identifier key": "Objektumazonosító kulcs",
    "Feature properties": "Objektum tulajdonságai",
    "Fetch data each time map view changes.": "Adatok beolvasása a térkép nézetének minden egyes változásánál.",
    "fill color": "kitöltés színe",
    "fill opacity": "kitöltés átlátszósága",
    "fill": "kitöltés",
    "Fit all data": "Legyen látható az összes adat",
    "Format": "Formátum",
    "From zoom": "Ettől a nagyítási szinttől",
    "full backup": "teljes biztonsági másolat",
    "Generic": "Általános",
    "GeoRSS (only link)": "GeoRSS (csak link)",
    "GeoRSS (title + image)": "GeoRSS (cím + kép)",
    "Go to \"{coords}\"": "Ugrás ide: {coords}",
    "Go to the homepage": "Ugrás a főoldalra",
    "Go to «{feature}»": "Ugrás ide: «{feature}»",
    "Heatmap intensity property": "Intenzitástérkép tulajdonságai",
    "Heatmap radius": "Intenzitástérkép sugara",
    "Heatmap": "Intenzitástérkép",
    "height": "magasság",
    "Help": "Súgó",
    "hidden": "rejtett",
    "Hide controls": "Vezérlők elrejtése",
    "Home": "uMap kezdőlap",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Mennyire egyszerűsödjék egy töröttvonal az egyes nagyítási fokozatoknál (jobban = jobb teljesítmény és simább kinézet, kevésbé = nagyobb pontosság)",
    "icon opacity": "Ikon átlátszósága",
    "Icon shape": "Ikon alakja",
    "Icon symbol": "Ikonszimbólum",
    "If false, the polygon or line will act as a part of the underlying map.": "Ha hamis, a sokszög vagy vonal az alapul szolgáló térkép részeként viselkedik.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "iFrame egyedi magassággal (képpont): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "iFrame egyedi magassággal és szélességgel (képpont): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iFrame",
    "Iframe: {{{https://iframe.url.com}}}": "iFrame: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Kép egyedi szélességgel (képpont): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Kép: {{https://image.url.com}}",
    "Import data": "Adatok importálása",
    "Import in a new layer": "Importálás új rétegbe",
    "Imports all umap data, including layers and settings.": "Minden uMap-adatot (többek között a rétegeket és a beállításokat is) importálja.",
    "Include full screen link?": "Tartalmazzon-e teljes képernyős nézetre vezető linket?",
    "Inherit": "Öröklés",
    "inherit": "öröklés",
    "Interaction options": "Interakció beállításai",
    "Invalid latitude or longitude": "Érvénytelen szélesség vagy hosszúság",
    "Invalid umap data in {filename}": "Érvénytelen uMap-adatok: {filename}",
    "Invalid umap data": "Érvénytelen uMap-adatok",
    "Jenks-Fisher": "Fisher-Jenks algoritmus",
    "K-means": "K-középpont",
    "Keep current visible layers": "A jelenleg látható rétegek megtartása",
    "kilometers": "kilométer",
    "km": "km",
    "Label direction": "Felirat iránya",
    "Label key": "Felirathoz használt kulcs",
    "Labels are clickable": "Kattintható feliratok",
    "Latest feature": "Legutóbbi objektum",
    "Latitude": "Szélesség",
    "Layer properties": "Réteg tulajdonságai",
    "Layer": "Réteg",
    "Licence": "Licenc",
    "licence": "licenc",
    "Limit bounds": "Térkép szélei",
    "Link to view the map": "Link a térkép megtekintéséhez",
    "Link to…": "Link…",
    "Link with text: [[https://example.com|text of the link]]": "Link szöveggel: [[https://peldaul.hu|a link példaszövege]]",
    "Long credits": "Alkotók részletesen",
    "Longitude": "Hosszúság",
    "Make main shape": "Legyen főalakzat",
    "Manage layers": "Rétegek kezelése",
    "Manual": "Manuális",
    "Map background credits": "Térképháttér alkotói",
    "Map has been attached to your account": "A térkép az ön fiókjához csatoltatott",
    "Map has been saved!": "Térkép mentve",
    "Map has been starred": "Térkép megcsillagozva",
    "Map has been unstarred": "Térkép csillagozása visszavonva",
    "Map user content has been published under licence": "A térkép felhasználói tartalma licenc szerint lett közzétéve",
    "Map's editors": "Térkép szerkesztői",
    "Map's owner": "Térkép tulajdonosa",
    "max East": "Keletre eddig:",
    "max North": "Északra eddig:",
    "max South": "Délre eddig:",
    "max West": "Nyugatra eddig:",
    "max zoom": "legnagyobb nagyítás",
    "Measure distances": "Távolságmérés",
    "Merge lines": "Vonalak egyesítése",
    "mi": "mf",
    "miles": "mérföld",
    "min zoom": "legkisebb nagyítás",
    "More controls": "További vezérlők",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Érvényes CSS-értéknek kell lennie (pl. DarkBlue vagy #123456)",
    "name": "név",
    "nautical miles": "tengeri mérföld",
    "never": "soha",
    "new window": "új ablak",
    "next": "következő",
    "NM": "tengeri mérföld",
    "No cache": "Nincs gyorsítótár",
    "No licence has been set": "Licenc még nincs megadva",
    "No results": "Nincs eredmény",
    "no": "nincs",
    "No.": "sz.",
    "None": "Semmi",
    "Number of desired classes (default 5)": "Kívánt kategóriák száma (alapértelmezés: 5)",
    "On the bottom": "Lent",
    "On the left": "Balra",
    "On the right": "Jobbra",
    "On the top": "Fent",
    "Only visible layers' data": "Csak a látható rétegek adatai",
    "opacity": "átlátszóság",
    "Opacity": "Átlátszóság",
    "Open current feature on load": "Jelenlegi objektum megnyitása betöltéskor",
    "Open link in…": "Link megnyitása itt:",
    "Open share & download panel": "„Megosztás & letöltés” panel megnyitása",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "A térképkivágás megnyitása egy térképszerkesztőben, hogy az OpenStreetMapbe pontosabb adatokat lehessen előállítani",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Intenzitástérkép nem kötelező tulajdonsága",
    "Optional. Same as color if not set.": "Nem kötelező. Ha nincs beállítva, akkor ugyanaz, mint a szín.",
    "Optional.": "Nem kötelező.",
    "Override clustering radius (default 80)": "Csoportosítás sugarának felülírása (alapértelmezett: 80)",
    "Override heatmap radius (default 25)": "Intenzitástérkép sugarának felülírása (alapértelmezett: 25)",
    "parent window": "szülőablak",
    "Paste your data here": "Illessze be ide az adatokat",
    "Permalink": "Permalink",
    "Permanent credits background": "Háttér a mindig látható alkotók mögött",
    "Permanent credits": "Mindig látható alkotók",
    "Please be sure the licence is compliant with your use.": "Győződjön meg róla, hogy a licenc megfelel a térkép felhasználásának.",
    "Please choose a format": "Válassza ki a formátumot",
    "Please enter the name of the property": "Adja meg a tulajdonság nevét",
    "Please enter the new name of this property": "Adja meg a tulajdonság új nevét",
    "Please save the map first": "Először mentse a térképet",
    "Popup (large)": "Felugró (nagy)",
    "Popup content style": "Felugró tartalom stílusa",
    "Popup content template": "Előugró tartalom sablonja",
    "Popup shape": "Felugró ablak alakja",
    "Popup": "Felugró",
    "Powered by uMap": "Üzemeltető: uMap",
    "previous": "előző",
    "Problem in the response": "Hiba a válaszban",
    "Properties imported:": "Importált tulajdonságok:",
    "Provide an URL here": "Itt adjon meg egy URL-t",
    "Proxy request": "Proxykérés",
    "Quantiles": "Kvantilisek",
    "Recent": "Legutóbbi",
    "Remote data": "Távoli adatok",
    "Remove shape from the multi": "Alakzat eltávolítása a jelenlegi alakzatcsoportból",
    "Replace layer content": "Réteg tartalmának lecserélése",
    "Restore this version": "Ennek a változatnak a visszaállítása",
    "Save current edits": "Jelenlegi szerkesztések mentése",
    "Save map": "Térkép mentése",
    "Save": "Mentés",
    "Saved center and zoom": "Elmentett középpont és nagyítás",
    "Search location": "Hely keresése",
    "Search": "Keresés",
    "Secret edit link:": "Titkos szerkesztési link:",
    "See full screen": "Teljes képernyős nézet megtekintése",
    "See on OpenStreetMap": "Megtekintés az OpenStreetMapen",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Állítsa hamisra, hogy elrejtse ezt a réteget a diavetítésből, az adatböngészőből, az előugró navigációból stb.",
    "settings": "beállítások",
    "Shape properties": "Alakzat tulajdonságai",
    "Share and download": "Megosztás és letöltés",
    "Share this link to open a customized map view": "Link megosztása testreszabott térképnézet megnyitásához",
    "Short credits": "Alkotók röviden",
    "Short link": "Rövid link",
    "Show this layer in the caption": "Réteg megjelenítése a címsávban",
    "Show/hide layer": "Réteg megjelenítése/elrejtése",
    "Side panel": "Oldalsó panel",
    "Simple link: [[https://example.com]]": "Egyszerű link: [[https://peldaul.hu]]",
    "Simplify": "Egyszerűsítés",
    "Skipping unknown geometry.type: {type}": "Ismeretlen ({type}) alakzattípus kihagyása",
    "Slideshow": "Diavetítés",
    "Sort key": "Sorba rendezéshez használt kulcs",
    "Split line": "Vonal elvágása",
    "Star this map": "Térkép megcsillagozása",
    "Start a hole here": "Lyuk rajzolása itt",
    "Start slideshow": "Diavetítés indítása",
    "Stop editing": "Szerkesztés befejezése",
    "Stop slideshow": "Diavetítés befejezése",
    "Street": "Utca",
    "stroke": "körvonal",
    "Supported scheme": "Támogatott séma",
    "Supported variables that will be dynamically replaced": "Támogatott változók, amelyek dinamikusan behelyettesítődnek",
    "Symbol": "Jelkép",
    "Table": "Táblázat",
    "Text color for the cluster label": "Csoportcímke szövegének színe",
    "Text formatting": "Szövegformázás",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "A tulajdonság neve, amelyet az objektum felirataként fog megjelenni (pl.: „név”). A tulajdonságokat kapcsos zárójelben is használhatja, ha többet szeretne használni, vagy statikus tartalommal keverné (pl.: &lcub;név&rcub; itt: &lcub;hely&rcub;).",
    "The name of the property to use as feature unique identifier.": "A tulajdonság neve, amely az objektum egyedi azonosítójaként lesz felhasználva.",
    "The zoom and center have been modified.": "A nagyítás és a középpont módosult.",
    "TMS format": "TMS-formátum",
    "To use if remote server doesn't allow cross domain (slower)": "Akkor használja, ha a távoli kiszolgáló nem engedélyezi a tartományok közötti (cross-domain) átvitelt (lassabb)",
    "To zoom": "Eddig a nagyítási szintig",
    "Toggle edit mode (⇧+Click)": "Szerkesztési mód be-/kikapcsolása (⇧+kattintás)",
    "Toggle edit mode": "Szerkesztési mód be-/kikapcsolása",
    "Transfer shape to edited feature": "Alakzat átalakítása szerkesztett objektummá",
    "Transform to lines": "Átalakítás vonallá",
    "Transform to polygon": "Átalakítás sokszöggé",
    "Type a place name or coordinates": "Helynév vagy koordináták megadása",
    "Type char or paste emoji": "Karakter megadása vagy emoji beillesztése",
    "Type of layer": "Réteg típusa",
    "Unable to detect format of file {filename}": "A(z) {filename} fájl formátumának megállapítása nem sikerült",
    "Untitled layer": "Cím nélküli réteg",
    "Untitled map": "Cím nélküli térkép",
    "Update permissions and editors": "Jogosultságok és szerkesztők frissítése",
    "Update permissions": "Jogosultságok frissítése",
    "Update who can see and edit the map": "Annak frissítése, hogy ki láthatja és szerkesztheti a térképet",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Jelenlegi nézet használata",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Olyan helyőrzőket használjon, amelyeknél az objektumtulajdonságok zárójelben vannak, például &#123;name&#125;. A megfelelő értékek dinamikusan behelyettesítődnek a tulajdonságok helyébe.",
    "User content credits": "Felhasználói tartalom alkotói",
    "User interface options": "Felhasználói felület tulajdonságai",
    "User location": "Felhasználó pozíciója",
    "Verify remote URL": "Távoli URL ellenőrzése",
    "Versions": "Verziók",
    "View Fullscreen": "Megjelenítés teljes képernyőn",
    "View": "Megtekintés",
    "Visibility: {status}": "Láthatóság: {status}",
    "weight": "vastagság",
    "Where do we go from here?": "Merre tovább?",
    "Whether to display or not polygons paths.": "Megjelenjenek-e a sokszög oldalai?",
    "Whether to fill polygons with color.": "Ki legyen-e színezve a sokszög?",
    "Who can edit \"{layer}\"": "Ki szerkesztheti ezt a réteget: {layer}?",
    "Who can edit": "Ki szerkesztheti?",
    "Who can view": "Ki láthatja?",
    "width": "szélesség",
    "Will be displayed in the bottom right corner of the map": "A térkép jobb alsó sarkában fog megjelenni",
    "Will be permanently visible in the bottom left corner of the map": "Mindig látható lesz a térkép bal alsó sarkában",
    "Will be visible in the caption of the map": "A térkép címsávjában fog megjelenni",
    "yes": "igen",
    "Zoom in": "Nagyítás",
    "Zoom level for automatic zooms": "Nagyítási szint automatikus nagyításoknál",
    "Zoom out": "Kicsinyítés",
    "Zoom to layer extent": "Nagyítás a teljes rétegre",
    "Zoom to the next": "Nagyítás a következőre",
    "Zoom to the previous": "Nagyítás az előzőre",
    "Zoom to this feature": "Nagyítás erre az objektumra",
    "{area}&#8239;acres": "{area} acre",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mf&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yard&sup2;",
    "{count} errors during import: {message}": "{count} hiba történt az importálás közben: {message}",
    "{delay} seconds": "{delay} másodperc",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} mf",
    "{distance}&#8239;NM": "{distance} tengeri mf.",
    "{distance}&#8239;yd": "{distance} yard",
    "Edit map name and caption": "Térkép nevének és leírásának szerkesztése",
    "Map advanced properties": "Térkép speciális tulajdonságai",
    "Edit map details": "Térkép adatainak szerkesztése",
    "Back to browser": "Vissza a böngészőbe",
    "Toggle size": "Méret átkapcsolása",
    "Display the caption control": "A 'leírás' vezérlő megjelenítése",
    "<empty value>": "<empty value>",
    "Min": "Legalább",
    "Max": "Legfeljebb",
    "From": "Ettől:",
    "Until": "Eddig:",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Példa: kulcs1,kulcs2|Réteg 2,kulcs3|Réteg 3|jelölőnégyzet",
    "Edit in OpenStreetMap": "Szerkesztés az OpenStreetMapen",
    "Cannot determine latitude and longitude columns.": "Nem lehet meghatározni a szélességet és hosszúságot tartalmazó oszlopokat.",
    "Back to layers": "Vissza a rétegekhez",
    "Filters": "Szűrők",
    "Comma separated list of properties to use when filtering features by text input": "A tulajdonságok vesszővel elválasztott listája, amelyet akkor kell használni, ha az objektumokat szöveges bevitellel szűrjük.",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "A szűrőkhöz használandó tulajdonságok vesszővel elválasztott listája (pl.: kulcs,másikkulcs). Feliratként való megjelenítéshez a | után adja meg a feliratot (pl.: kulcs|Egyik kulcs,másikkulcs|Másik kulcs). A beviteli mező típusának meghatározásához egy másik | után adja meg a mező típusát (pl.: kulcs|Egyik kulcs|checkbox,másikkulcs|Másik kulcs|datetime). A beviteli mező típusának megengedett értékei: checkbox (jelölőnégyzet, alapértelmezett), radio (rádiógomb), number (szám), date (dátum) és datetime (dátum és idő).",
    "Search keys": "Keresőkulcsok",
    "Filters keys": "Szűrőkulcsok",
    "Filter data": "Adatok szűrése",
    "Search map features…": "Térképobjektum keresése…",
    "Reset all": "Minden alaphelyzetbe állítása",
    "Open browser": "Böngésző megnyitása",
    "Open caption": "Leírás megnyitása",
    "Your map has been created with an anonymous account!": "A térképét egy névtelen fiókkal hozták létre.",
    "Real-time collaboration": "Valós idejű együttműködés",
    "Cannot parse data": "Nem lehet elemezni az adatokat",
    "Start typing...": "Kezdjen el gépelni…",
    "No result": "Nem találtunk semmit",
    "Data browser": "Adatböngésző",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "URL megadásakor a uMap vagy bemásolja a távoli adatokat egy rétegbe, vagy hozzáadja az URL-t a réteg távoli forrásaként. Ebben az esetben az adatok mindig erről az URL-címről lesznek lekérve, és így naprakészek lesznek, a uMap-en belül viszont nem lehet majd szerkeszteni őket.",
    "Overpass supported expressions": "Overpass által támogatott kifejezések",
    "key (eg. building)": "kulcs (pl. building)",
    "!key (eg. !name)": "!kulcs (pl. !name)",
    "key=value (eg. building=yes)": "kulcs=érték (pl. building=yes)",
    "key!=value (eg. building!=yes)": "kulcs!=érték (pl. building!=yes)",
    "key~value (eg. name~Grisy)": "kulcs~érték (pl. név~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "kulcs=\"érték|érték2\" (pl. name=\"Szeged|Budapest\")",
    "More info about Overpass syntax": "További tudnivalók az Overpass szintaxisáról",
    "For more complex needs, see": "Összetettebb lekérdezésekhez lásd",
    "Choose data": "Adatok kiválasztása",
    "Choose the format": "Formátum kiválasztása",
    "Choose the layer": "Réteg kiválasztása",
    "Layer name": "Réteg neve",
    "Choose import mode": "Importálás módjának kiválasztása",
    "Copy into the layer": "Másolás a rétegre",
    "Link to the layer as remote data": "Réteg belinkelése távoli adatként",
    "Condition": "Feltétel",
    "key=value or key!=value": "kulcs=érték vagy kulcs!=érték",
    "Are you sure you want to delete this rule?": "Biztosan törölni szeretné ezt a szabályt?",
    "empty rule": "üres szabály",
    "Conditional style rules": "Feltételes stílusszabályok",
    "Add rule": "Szabály hozzáadása",
    "Browser: data": "Böngésző: adatok",
    "Browser: layers": "Böngésző: rétegek",
    "Browser: filters": "Böngésző: szűrők",
    "Enable real-time collaboration": "Valós idejű együttműködés engedélyezése",
    "✅ Copied!": "✅ lemásolva",
    "Choose a dataset": "Adatkészlet kiválasztása",
    "Choose this dataset": "Ezen adatkészlet kiválasztása",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: tematikus adatok az OpenStreetMap-ről",
    "Choose a theme": "Téma kiválasztása",
    "Choose this data": "Ezen adatok kiválasztása",
    "Search admin boundary": "Közigazgatási határ keresése",
    "Please choose a theme and a boundary first.": "Először válasszon ki egy témát és egy határt.",
    "Expression": "Kifejezés",
    "Geometry mode": "Alakzat mód",
    "Only geometry centers": "Csak az alakzatok középpontja",
    "Search area": "Terület keresése",
    "Type area name, or let empty to load data in current map view": "Adja meg a terület nevét vagy hagyja üresen a jelenlegi térképnézet adatainak betöltéséhez",
    "Data successfully imported!": "Adatok sikeresen importálva",
    "Clear data": "Adatok törlése",
    "Remove layers": "Rétegek eltávolítása",
    "Categorized": "Kategóriák szerint",
    "Alphabetical": "Ábécésorrendben",
    "Category property": "Kategória tulajdonsága",
    "Color palette": "Színskála",
    "Categories": "Kategóriák",
    "Comma separated list of categories.": "Kategóriák vesszővel elválasztott listája.",
    "Categories mode": "Kategóriák mód",
    "Remove filter for this column": "Szűrő eltávolítása az oszlopban",
    "Add filter for this column": "Szűrő hozzáadása az oszlophoz",
    "Rename this column": "Oszlop átnevezése",
    "Delete this column": "Oszlop törlése",
    "Name “{name}” should not contain a dot.": "A névben ({name}) nem lehet pont.",
    "This name already exists: “{name}”": "„{name}” név már van",
    "Delete selected rows": "Kijelölt sorok törlése",
    "Found {count} rows. Are you sure you want to delete all?": "{count} sort találtunk. Biztosan törölni szeretné az összeset?",
    "Expression is empty": "A kifejezés üres",
    "OK": "OK",
    "Cancel": "Mégse",
    "Attach map to a team": "Térkép csoporthoz rendelése",
    "Display the polygon inverted": "Poligon inverz megjelenítése",
    "Proportional circles": "Arányos körök",
    "Property name to compute circles": "Tulajdonságnév a körök kiszámításához",
    "Min circle radius": "Kör legkisebb sugara",
    "Max circle radius": "Kör legnagyobb sugara",
    "Display the open browser control": "'Böngésző megnyitása' vezérlő megjelenítése",
    "Copy as GeoJSON": "Másolás GeoJSON-ként",
    "Please zoom in to edit the geometry": "Az alakzat szerkesztéséhez nagyítson",
    "New map": "Új térkép",
    "My maps": "Térképeim",
    "My teams": "Csoportjaim",
    "My profile": "Profilom",
    "Type new owner's username": "Add meg az új tulajdonos felhasználónevét",
    "Type editor's username": "Add meg a szerkesztő felhasználónevét",
    "Map": "Térkép",
    "Manage collaborators": "Együttműködők kezelése",
    "show/hide all layers": "összes réteg megjelenítése/elrejtése",
    "zoom to data extent": "nagyítás az adatok kiterjedésére",
    "download visible data": "látható adatok letöltése",
    "Import helpers": "Importálássegítők",
    "Import helpers will fill the URL field for you.": "Az importálássegítők kitöltik neked az URL-mezőt.",
    "Wikipedia": "Wikipédia",
    "Save draft": "Piszkozat mentése",
    "No data has been found for import": "Nem található adat az importáláshoz",
    "Successfully imported {count} feature(s)": "{count} objektum sikeresen importálva",
    "Disconnected": "Kapcsolat megszakadt",
    "You must be logged in": "Be kell jelentkeznie",
    "on hover": "rámutatáskor",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Nem lehet betölteni a {layer} réteg távoli adatait a {url} URL-ről.",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Nem lehet elemezni a {layer} réteg távoli adatait a {url} URL-ről.",
    "Import failed: invalid data": "Importálás sikertelen: az adatok érvénytelenek",
    "Anonymous": "Névtelen",
    "created at {date}": "létrehozva: {date}",
    "modified at {date}": "módosítva: {date}",
    "Default zoom": "Alapértelmezett nagyítás",
    "Default latitude": "Alapértelmezett szélesség",
    "Default longitude": "Alapértelmezett hosszúság",
    "Edit map default view": "Térkép alapértelmezett nézetének szerkesztése",
    "Use current center and zoom": "A jelenlegi középpont és nagyítás használata",
    "Layer permalink": "Réteg permalinkje",
    "Back to home": "Vissza a kezdőlapra",
    "Home logo": "Kezdőlap logó",
    "Add this geometry to my map": "Alakzat hozzáadása a térképemhez",
    "Add this place to my map": "Hely hozzáadása a térképemhez",
    "Cancel last edit": "Legutóbbi szerkesztés visszavonása",
    "Redo last edit": "Legutóbbi szerkesztés újbóli elvégzése",
    "Links": "Linkek",
    "Images": "Képek",
    "Iframes": "iFrame-ek",
    "Tags": "Címkék",
    "Geocode": "Geocode",
    "Display the back to home icon": "Vissza a kezdőlapra ikon megjelenítése",
    "Do you want to display layer switcher in caption bar?": "Szeretnél megjeleníteni egy rétegkapcsolót a címsávban?",
    "Simplify all geometries to points": "Minden alakzat egyszerűsítése pontokra",
    "Back to list": "Vissza a listához",
    "Toggle rule": "Szabály átkapcsolása",
    "Delete rule": "Szabály törlése",
    "Cannot save layer, please try again in a few minutes.": "Nem sikerül elmenteni a réteget; próbáld meg újra pár perc múlva.",
    "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.": "Közös élő szerkesztést aktiválása ezen a térképen. A beállítás módosítása után a többi felhasználónak újra be kell töltenie a térképet.",
    "More help resources": "More help resources",
    "This map is a template": "This map is a template",
    "Add text along path": "Add text along path",
    "Text color": "Text color",
    "Text offset": "Text offset",
    "Text position": "Text position",
    "start": "start",
    "center": "center",
    "end": "end",
    "Text repeat": "Text repeat",
    "Text rotate": "Text rotate",
    "Text size": "Text size",
    "Load map template": "Load map template",
    "Use a template to initialize your map": "Use a template to initialize your map",
    "My templates": "My templates",
    "From staff": "From staff",
    "From community": "From community",
    "Include template data, if any": "Include template data, if any",
    "Load this template": "Load this template",
    "Open": "Open",
    "You must select a template.": "You must select a template.",
    "Line decoration": "Line decoration",
    "Reuse this template": "Reuse this template",
    "Create a new map using this template": "Create a new map using this template",
    "Save template": "Save template",
    "Load template": "Load template"
}
L.registerLocale("hu", locale)
L.setLocale("hu")
