const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# jedna mriežka pre hlavný nadpis",
    "## two hashes for second heading": "## dve mriežky pre nadpis druhej úrovne",
    "### three hashes for third heading": "## tri mriežky pre nadpis tretej úrovne",
    "**double star for bold**": "**všetko medzi dvoma hviezdičkami je tučně**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 day",
    "1 hour": "1 hour",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Čiarkami oddelený zoznam čísel, ktorý popisuje vzor prerušovanej čiary. Napr. \"5, 10, 15\".",
    "About": "O uMap",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Activate slideshow mode",
    "Add a layer": "Pridať vrstvu",
    "Add a line to the current multi": "Pridať čiaru k aktuálnemu multi",
    "Add a new property": "Pridať novú vlastnosť",
    "Add a polygon to the current multi": "Pridať polygón k aktuálnemu multi",
    "Add image URL": "Add image URL",
    "Advanced actions": "Pokročilé akcie",
    "Advanced properties": "Pokročilé vlastnosti",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Všetky vlastnosti sú naimportované.",
    "Allow interactions": "Povoliť interakcie",
    "Allow scroll wheel zoom?": "Povoliť približovanie kolieskom myši?",
    "always": "vždy",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "Určite chcete vytvoriť kópiu celej tejto mapy a všetkých jej vrstiev?",
    "Are you sure you want to delete this map?": "Ste si istí, že chcete vymazať túto mapu?",
    "Are you sure you want to delete this property on all the features?": "Ste si istí že chcete vymazať túto vlastnosť na všetkých objektoch?",
    "Are you sure you want to restore this version?": "Určite chcete obnoviť túto verziu?",
    "Attach the map to my account": "Attach the map to my account",
    "attribution": "autorstvo",
    "Auto": "Automatická",
    "Automatic": "Automaticky",
    "Autostart when map is loaded": "Aut. spustenie pri načítaní mapy",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Špendlík",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Prezerať údaje",
    "by": "od",
    "Cache proxied request": "Cache proxied request",
    "Caption": "Nadpis",
    "Center map on your location": "Vycentrovať mapu na vašu polohu",
    "Change tilelayers": "Zmeniť pozadie mapy",
    "Change": "Change",
    "Choose the data format": "Zvoľte formát údajov",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Kruh",
    "clear": "vyčistiť",
    "Click last point to finish shape": "Kliknite na posledný bod pre dokončenie tvaru",
    "Click to add a marker": "Kliknutím pridáte značku",
    "Click to continue drawing": "Kliknutím môžete pokračovať v kreslení",
    "Click to edit": "Kliknutím upravte",
    "Click to start drawing a line": "Kliknutím začnete kresliť čiaru",
    "Click to start drawing a polygon": "Kliknutím začnete kresliť polygón",
    "Clone of {name}": "Kópia {name}",
    "Clone this feature": "Vytvoriť kópiu objektu",
    "Clone this map": "Vytvoriť kópiu tejto mapy",
    "Clone": "Vytvoriť kópiu",
    "Close": "Zatvoriť",
    "Clustered": "Zhluková",
    "Clustering radius": "Polomer zhlukovania",
    "collapsed": "zbalené",
    "color": "farba",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Hodnoty oddelené čiarkou, tabulátorom, alebo bodkočiarkou. Predpokladá sa SRS WGS84 a sú importované iba polohy bodov. Import hľadá záhlavie stĺpcov začínajúcich na \"lat\" a \"lon\" a tie považuje za súradnice (na veľkosti písmien nezáleži). Ostatné stĺpce sú importované ako vlastnosti.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Pokračovať v čiare",
    "Coordinates": "Súradnice",
    "copy": "copy",
    "Credits": "Poďakovania",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Aktuálne zobrazenie namiesto štandardného zobrazenia mapy?",
    "Custom background": "Vlastné pozadie",
    "Custom overlay": "Custom overlay",
    "dash array": "štýl prerušovanej čiary",
    "Data is browsable": "Data is browsable",
    "Datalayers": "Datalayers",
    "Default interaction options": "Predvolené možnosti interakcie",
    "Default properties": "Predvolené vlastnosti",
    "Default shape properties": "Predvolené vlastnosti tvaru",
    "Default view": "Default view",
    "Default zoom level": "Predvolené priblíženie",
    "Default": "Predvolené",
    "Default: name": "Štandardná hodnota: názov",
    "Define link to open in a new window on polygon click.": "Definujte odkaz na otvorenie, ktorý otvorí nové okno po kliknutí na polygón.",
    "define": "definovať",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete layer": "Vymazať vrstvu",
    "Delete this feature": "Vymazať tento objekt",
    "Delete this shape": "Vymazať tento tvar",
    "Delete this vertex (Alt+Click)": "Vymazať tento bod (Alt+Klik)",
    "Delete": "Vymazať",
    "description": "popis",
    "Direct link": "Direct link",
    "Directions from here": "Navigovať odtiaľto",
    "Display label": "Zobraziť popis",
    "Display measure": "Display measure",
    "display name": "zobraziť názov",
    "Display on load": "Zobraziť pri štarte",
    "Display the control to open OpenStreetMap editor": "Zobraziť ovládanie na otvorenie editora OpenStreetMap",
    "Display the embed control": "Zobraziť ovládanie vkladania",
    "Display the fullscreen control": "Zobraziť ovládanie celej obrazovky",
    "Display the locate control": "Zobraziť ovládanie polohy",
    "Display the measure control": "Zobraziť ovládanie merania",
    "Display the search control": "Zobraziť ovládanie vyhľadávania",
    "Display the tile layers control": "Zobraziť ovládanie dlaždíc vrstiev",
    "Display the zoom control": "Zobraziť ovládanie priblíženia",
    "Do you want to display a caption bar?": "Chcete zobraziť lištu s nadpismi?",
    "Do you want to display a minimap?": "Chcete zobraziť minimapu?",
    "Do you want to display a panel on load?": "Prajete si zobraziť panel pri štarte?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Chcete zobraziť v bubline navigačný panel?",
    "Do you want to display the scale control?": "Chcete zobraziť mierku mapy?",
    "Do you want to display the «more» control?": "Prajete si zobrazit  «viac» nastavení?",
    "Download": "Download",
    "Drag to reorder": "Presunutím zmeníte poradie",
    "Draw a marker": "Nakresliť značku miesta",
    "Draw a polygon": "Nakresliť polygon",
    "Draw a polyline": "Nakresliť krivku",
    "Drawing": "Drawing",
    "Drop": "Pustiť",
    "Dynamic properties": "Dynamické vlastnosti",
    "Dynamic": "Dynamicky",
    "Edit feature's layer": "Upraviť vrstvu objektu",
    "Edit properties in a table": "Upraviť vlastnosti v tabuľke",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Upraviť tento objekt",
    "Edit": "Upraviť",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Vložiť mapu na iný web",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Vyprázdniť",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Chyba URL dlaždicovej vrstvy",
    "Exit Fullscreen": "Ukončiť režim celej obrazovky",
    "expanded": "rozbalené",
    "Extract shape to separate feature": "Vyňať tvar do samostatného objektu",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Načítanie údajov pri každej zmene zobrazenia mapy.",
    "fill color": "farba výplne",
    "fill opacity": "priehľadnosť výplne",
    "fill": "výplň",
    "Fit all data": "Fit all data",
    "Format": "Formát",
    "From zoom": "Max. oddialenie",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (iba odkaz)",
    "GeoRSS (title + image)": "GeoRSS (názov + obrázok)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Prejsť na «{feature}»",
    "Heatmap intensity property": "Vlastnosti intenzity heatmapy",
    "Heatmap radius": "Polomer teplotnej mapy",
    "Heatmap": "Teplotná mapa",
    "height": "Výška",
    "Help": "Nápoveda",
    "hidden": "skryté",
    "Hide controls": "Skryť ovládacie prvky",
    "Home": "Domov",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Ako veľmi vyhladzovať a zjednodušovať pri oddialeni (väčšie = rýchlejša odozva a plynulejší vzhľad, menšie = presnejšie)",
    "icon opacity": "icon opacity",
    "Icon shape": "Tvar ikony",
    "Icon symbol": "Symbol ikony",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Import údajov",
    "Import in a new layer": "Importovať do novej vrstvy",
    "Imports all umap data, including layers and settings.": "Importuje všetky údaje umapy, vrátane vrstiev a nastavení.",
    "Include full screen link?": "Zahrnúť odkaz na celú obrazovku?",
    "Inherit": "Predvolené",
    "inherit": "predvolené",
    "Interaction options": "Možnosti interakcie",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Neplatné údaje umapy v súbore {filename}",
    "Invalid umap data": "Neplatné údaje umapy",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Použiť pre aktuálne zobrazenie vrstiev",
    "kilometers": "kilometers",
    "km": "km",
    "Label direction": "Orientácia popisu",
    "Label key": "Kľúč popisu",
    "Labels are clickable": "Popis je klikateľný",
    "Latest feature": "Latest feature",
    "Latitude": "Zem. šírka",
    "Layer properties": "Vlastnosti vrstvy",
    "Layer": "Vrstva",
    "Licence": "Licencia",
    "licence": "licencia",
    "Limit bounds": "Obmedziť hranice",
    "Link to view the map": "Link to view the map",
    "Link to…": "Odkaz na…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Dlhý text autorstva",
    "Longitude": "Zem. dĺžka",
    "Make main shape": "Urobiť hlavným tvarom",
    "Manage layers": "Nastavenie vrstiev",
    "Manual": "Manual",
    "Map background credits": "Autor mapy pozadia",
    "Map has been attached to your account": "Map has been attached to your account",
    "Map has been saved!": "Mapa bola uložená!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Použivateľské údaje sú zverejnené pod licenciou",
    "Map's editors": "Map's editors",
    "Map's owner": "Map's owner",
    "max East": "max. Východ",
    "max North": "max. Sever",
    "max South": "max. Juh",
    "max West": "max. Západ",
    "max zoom": "max. priblíženie",
    "Measure distances": "Measure distances",
    "Merge lines": "Spojiť čiary",
    "mi": "mi",
    "miles": "miles",
    "min zoom": "max. oddialenie",
    "More controls": "Viac ovládacích prvkov",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Musí byť platná hodnota CSS (napr.: DarkBlue or #123456)",
    "name": "názov",
    "nautical miles": "nautical miles",
    "never": "nikdy",
    "new window": "nové okno",
    "next": "ďalší",
    "NM": "NM",
    "No cache": "No cache",
    "No licence has been set": "Nebola nastavená žiadna licencia",
    "No results": "Žiadne výsledky",
    "no": "nie",
    "No.": "No.",
    "None": "Žiadny",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "V spodnej časti",
    "On the left": "Naľavo",
    "On the right": "Napravo",
    "On the top": "V hornej časti",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "priehľadnosť",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Otvoriť odkaz v…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Otvoriť túto mapovú oblasť v mapovom editore pre presnenie dát v OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Voliteľné vlastnosti intenzity pre heatmapu",
    "Optional. Same as color if not set.": "Nepovinné. Rovnaké ako farba, ak nie je nastavené.",
    "Optional.": "Optional.",
    "Override clustering radius (default 80)": "Prepísať polomer zhlukovania (predvolené 80)",
    "Override heatmap radius (default 25)": "Prepísať polomer teplotnej mapy (predvolené 25)",
    "parent window": "nadradené okno",
    "Paste your data here": "Paste your data here",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Prosíme uistite sa, že licencia je v zhode s tým ako mapu používate.",
    "Please choose a format": "Prosím, zvoľte formát",
    "Please enter the name of the property": "Prosím, zadajte názov vlastnosti",
    "Please enter the new name of this property": "Prosím, zadajte nový názov tejto vlastnosti",
    "Please save the map first": "Please save the map first",
    "Popup (large)": "Popup (large)",
    "Popup content style": "Popup content style",
    "Popup content template": "Šablóna obsahu bubliny",
    "Popup shape": "Popup shape",
    "Popup": "Popup",
    "Powered by uMap": "Powered by uMap",
    "previous": "predchádzajúci",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Importované vlastnosti:",
    "Provide an URL here": "Sem vložte odkaz URL",
    "Proxy request": "Požiadavky cez proxy",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Vzdialené údaje",
    "Remove shape from the multi": "Odobrať tvar z multi",
    "Replace layer content": "Nahradiť obsah vrstvy",
    "Restore this version": "Obnoviť túto verziu",
    "Save current edits": "Uložiť nedávne zmeny",
    "Save map": "Save map",
    "Save": "Uložiť",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Vyhľadať polohu",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Na celú obrazovku",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Vlastnosti tvaru",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Krátky text autorstva",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Ukázať/skryť vrstvu",
    "Side panel": "Bočný panel",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Zjednodušiť",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Slideshow": "Prezentácia",
    "Sort key": "Kľúč radenia",
    "Split line": "Rozdelit čiaru",
    "Star this map": "Star this map",
    "Start a hole here": "Tu začať dieru",
    "Start slideshow": "Spustiť prezentáciu",
    "Stop editing": "Ukončiť úpravy",
    "Stop slideshow": "Zastaviť prezentáciu",
    "Street": "Street",
    "stroke": "linka",
    "Supported scheme": "Podporovaná schéma",
    "Supported variables that will be dynamically replaced": "Podporované premenné, ktoré budú automaticky nahradené",
    "Symbol": "Symbol",
    "Table": "Tabuľka",
    "Text color for the cluster label": "Farba textu pre popis zhluku",
    "Text formatting": "Formátovanie textu",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "Formát TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Použiť keď vzdialený server nepovoľuje cross-domain (pomalšie)",
    "To zoom": "Max. priblíženie",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Preniesť tvar do upravovaného objektu",
    "Transform to lines": "Transformuj na čiary",
    "Transform to polygon": "Transformuj na mnohouholník",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Typ vrstvy",
    "Unable to detect format of file {filename}": "Nepodarilo sa rozpoznať formát súboru {filename}",
    "Untitled layer": "Nepomenovaná vrstva",
    "Untitled map": "Nepomenovaná mapa",
    "Update permissions and editors": "Nastaviť prístupové práva a prispievateľov",
    "Update permissions": "Update permissions",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Použiť aktuálne hranice",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Použite zástupné znaky s vlastnosťami objektov medzi zloženými zátvorkami, napr. &#123;name&#125;, a budú dynamicky nahradené zodpovedajúcimi hodnotami.",
    "User content credits": "Autor používateľského obsahu",
    "User interface options": "Možnosti používateľského rozhrania",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Verzie",
    "View Fullscreen": "Zobraziť na celú obrazovky",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "šírka linky",
    "Where do we go from here?": "Kam sa dá odtiaľto dostať?",
    "Whether to display or not polygons paths.": "Či sa má alebo nemá zobraziť cesty polygónov.",
    "Whether to fill polygons with color.": "Či sa má vyplniť polygón farbou.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Who can edit",
    "Who can view": "Who can view",
    "width": "Šírka",
    "Will be displayed in the bottom right corner of the map": "Bude zobrazené s mapou vpravo dole",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Bude zobrazené v nadpise mapy",
    "yes": "áno",
    "Zoom in": "Priblížiť",
    "Zoom level for automatic zooms": "Úroveň priblíženia pre automatické približovanie",
    "Zoom out": "Oddialiť",
    "Zoom to layer extent": "Prispôsobiť priblíženie vrstve",
    "Zoom to the next": "Priblížiť k ďalšiemu",
    "Zoom to the previous": "Priblížiť k predošlému",
    "Zoom to this feature": "Priblížiť na tento objekt",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "Počet chýb počas importu {count}: {message}",
    "{delay} seconds": "{delay} seconds",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Display the back to home icon",
    "Do you want to display layer switcher in caption bar?": "Do you want to display layer switcher in caption bar?",
    "Simplify all geometries to points": "Simplify all geometries to points",
    "Back to list": "Back to list",
    "Toggle rule": "Toggle rule",
    "Delete rule": "Delete rule",
    "Cannot save layer, please try again in a few minutes.": "Cannot save layer, please try again in a few minutes."
}
L.registerLocale("sk_SK", locale)
L.setLocale("sk_SK")
