const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# ana başlık için bir hash",
    "## two hashes for second heading": "# # ana başlık için iki hash",
    "### three hashes for third heading": "### ana başlık için üç hash",
    "**double star for bold**": "**kalınlaştırma için iki yıldız**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 gün",
    "1 hour": "1 saat",
    "5 min": "5 dakika",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".",
    "About": "Hakkında",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Slayt gösterisi modunu etkinleştir",
    "Add a layer": "Bir katman ekle",
    "Add a line to the current multi": "Mevcut çokluya bir satır ekle",
    "Add a new property": "Yeni bir özellik ekle",
    "Add a polygon to the current multi": "Mevcut çokluya bir çokgen ekle",
    "Add image URL": "Add image URL",
    "Advanced actions": "Gelişmiş eylemler",
    "Advanced properties": "Gelişmiş özellikler",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Tüm özellikler içe aktarılır.",
    "Allow interactions": "Etkileşimlere izin ver",
    "Allow scroll wheel zoom?": "Kaydırma tekerleği yakınlaştırmasına izin verilsin mi?",
    "always": "her zaman",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "Bu haritayı ve tüm veri katmanlarını klonlamak istediğinizden emin misiniz?",
    "Are you sure you want to delete this map?": "Bu haritayı silmek istediğinizden emin misiniz?",
    "Are you sure you want to delete this property on all the features?": "Bu özelliği tüm nesnelerde silmek istediğinizden emin misiniz?",
    "Are you sure you want to restore this version?": "Bu sürümü geri yüklemek istediğinizden emin misiniz?",
    "Attach the map to my account": "Haritayı hesabıma ekle",
    "attribution": "atıf",
    "Auto": "Otomatik",
    "Automatic": "Otomatik",
    "Autostart when map is loaded": "Harita yüklendiğinde otomatik başlat",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Top",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Verilere göz at",
    "by": "tarafından",
    "Cache proxied request": "Önbellek proxy isteği",
    "Caption": "Başlık",
    "Center map on your location": "Bulunduğunuz yere göre haritayı ortala",
    "Change tilelayers": "Haritalama katmanlarını değiştir",
    "Change": "Change",
    "Choose the data format": "Veri biçimini seçin",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Daire",
    "clear": "temizle",
    "Click last point to finish shape": "Şekli bitirmek için son noktaya tıklayın",
    "Click to add a marker": "Bir işaretleyici eklemek için tıklayın",
    "Click to continue drawing": "Çizime devam etmek için tıklayın",
    "Click to edit": "Düzenlemek için tıkla",
    "Click to start drawing a line": "Çizgi çizmeye başlamak için tıkla",
    "Click to start drawing a polygon": "Çokgen çizmeye başlamak için tıkla",
    "Clone of {name}": "{name} kopyası",
    "Clone this feature": "Bu özelliği kopyala",
    "Clone this map": "Bu haritayı kopyala",
    "Clone": "Kopyala",
    "Close": "Kapat",
    "Clustered": "Kümelenmiş",
    "Clustering radius": "Kümeleme yarıçapı",
    "collapsed": "çökmüş",
    "color": "renk",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Çizgiye devam et",
    "Coordinates": "Koordinatlar",
    "copy": "copy",
    "Credits": "Krediler",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Varsayılan harita görünümü yerine mevcut görünüm?",
    "Custom background": "Varsayılan arkaplan",
    "Custom overlay": "Custom overlay",
    "dash array": "dash array",
    "Data is browsable": "Veriler göz atılabilir",
    "Datalayers": "Datalayers",
    "Default interaction options": "Varsayılan etkileşim seçenekleri",
    "Default properties": "Varsayılan özellikler",
    "Default shape properties": "Varsayılan şekil özellikleri",
    "Default view": "Default view",
    "Default zoom level": "Varsayılan yakınlaştırma seviyesi",
    "Default": "Varsayılan",
    "Default: name": "Varsayılan: adı",
    "Define link to open in a new window on polygon click.": "Poligona tıklayınca yeni bir pencerede açılacak bağlantıyı tanımlayın.",
    "define": "belirt",
    "Delay between two transitions when in play mode": "Oynatma modundayken iki geçiş arasında gecikme",
    "Delete layer": "Katmanı sil",
    "Delete this feature": "Bu özelliği sil",
    "Delete this shape": "Bu şekli sil",
    "Delete this vertex (Alt+Click)": "Delete this vertex (Alt+Click)",
    "Delete": "Sil",
    "description": "açıklama",
    "Direct link": "Direct link",
    "Directions from here": "Directions from here",
    "Display label": "Etiketi görüntüle",
    "Display measure": "Ölçüyü göster",
    "display name": "görünen ad",
    "Display on load": "Yüklerken görüntüle",
    "Display the control to open OpenStreetMap editor": "OpenStreetMap editörünü açmak için denetimi görüntüle",
    "Display the embed control": "Yerleştirme denetim görüntüle",
    "Display the fullscreen control": "Tam ekran denetimini görüntüle",
    "Display the locate control": "Konum denetimini görüntüle",
    "Display the measure control": "Ölçüm denetimini görüntüle",
    "Display the search control": "Arama denetimini görüntüle",
    "Display the tile layers control": "Döşeme katmanları kontrolünü göster",
    "Display the zoom control": "Yakınlaştırma denetimini görüntüle",
    "Do you want to display a caption bar?": "Başlık çubuğunu görüntülemek istiyor musunuz?",
    "Do you want to display a minimap?": "Bir minimap görüntülemek istiyor musunuz?",
    "Do you want to display a panel on load?": "Yükleme sırasında bir panel görüntülemek istiyor musunuz?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Açılır altbilgi görüntülemek istiyor musunuz?",
    "Do you want to display the scale control?": "Ölçek kontrolünü görüntülemek istiyor musunuz?",
    "Do you want to display the «more» control?": "«Daha fazla» denetim görüntülemek istiyor musunuz?",
    "Download": "İndir",
    "Drag to reorder": "Yeniden sıralamak için sürükle",
    "Draw a marker": "Bir işaretleyici çiz",
    "Draw a polygon": "Bir çokgen çiz",
    "Draw a polyline": "Çoklu çizgi çiz",
    "Drawing": "Drawing",
    "Drop": "Bırak",
    "Dynamic properties": "Dinamik özellikler",
    "Dynamic": "Dinamik",
    "Edit feature's layer": "Özellikler katmanını düzenle",
    "Edit properties in a table": "Özellikleri bir tabloda düzenle",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Bu özelliği düzenle",
    "Edit": "Düzenle",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Haritayı yerleştir",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Boşalt",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Katman URL'sinde hata",
    "Exit Fullscreen": "Tam ekrandan çık",
    "expanded": "genişletilmiş",
    "Extract shape to separate feature": "Özelliği ayırmak için şekli ayıklayın",
    "Feature identifier key": "Nesne tanımlayıcı anahtarı",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Harita görünümü her değiştiğinde verileri alın.",
    "fill color": "dolgu rengi",
    "fill opacity": "dolgu şeffaflığı",
    "fill": "doldur",
    "Fit all data": "Fit all data",
    "Format": "Format",
    "From zoom": "Yakınlaştırmadan",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (sadece bağlantı)",
    "GeoRSS (title + image)": "GeoRSS (başlık + resim)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "«{feature}» git",
    "Heatmap intensity property": "Isı haritası yoğunluk özelliği",
    "Heatmap radius": "Isı haritası yarıçapı",
    "Heatmap": "Isı haritası",
    "height": "yükseklik",
    "Help": "Yardım",
    "hidden": "saklı",
    "Hide controls": "Kontrolleri gizle",
    "Home": "Ana sayfa",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "icon opacity": "icon opacity",
    "Icon shape": "Simge şekli",
    "Icon symbol": "Simge sembolu",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "İçeri veri aktar",
    "Import in a new layer": "Yeni katman aktar",
    "Imports all umap data, including layers and settings.": "Katmanlar ve özellikler dahil olmak üzere bütün umap verisini ekle.",
    "Include full screen link?": "Tam ekran bağlantısını ekle?",
    "Inherit": "Devral",
    "inherit": "Devralır",
    "Interaction options": "Etkileşim seçenekleri",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "{filename}'de geçersiz umap verisi",
    "Invalid umap data": "Geçersiz umap verisi",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Şuan görünen katmanları tut",
    "kilometers": "kilometre",
    "km": "km",
    "Label direction": "Etiket yönü",
    "Label key": "Etiketin anahtarı",
    "Labels are clickable": "Etiketler tıklanabilir",
    "Latest feature": "Latest feature",
    "Latitude": "Enlem",
    "Layer properties": "Katman özellikleri",
    "Layer": "Katman",
    "Licence": "Lisans",
    "licence": "lisans",
    "Limit bounds": "Sınırı sınırlandır",
    "Link to view the map": "Link to view the map",
    "Link to…": "Şuna bağlantı...",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Uzun krediler",
    "Longitude": "Boylam",
    "Make main shape": "Ana şekil yap",
    "Manage layers": "Katmanları yönet",
    "Manual": "Manual",
    "Map background credits": "Map background credits",
    "Map has been attached to your account": "Harita hesabınıza bağlandı",
    "Map has been saved!": "Harita kaydedildi!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Harita kullanıcı içeriği lisans altında yayınlandı",
    "Map's editors": "Haritanın editörü",
    "Map's owner": "Haritanın sahibi",
    "max East": "max Doğu",
    "max North": "max Kuzey",
    "max South": "max Güney",
    "max West": "max Batı",
    "max zoom": "max yakınlaştır",
    "Measure distances": "Mesafeleri ölçün",
    "Merge lines": "Çizgileri birleştir",
    "mi": "mi",
    "miles": "mil",
    "min zoom": "min yakınlaştırma",
    "More controls": "Daha fazla kontrol",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Geçerli CSS değeri olmalı (örneğin: DarkBlue ya da #123456)",
    "name": "adı",
    "nautical miles": "deniz mil",
    "never": "asla",
    "new window": "yeni pencere",
    "next": "sonraki",
    "NM": "NM",
    "No cache": "Önbellek yok",
    "No licence has been set": "Hiçbir lisans ayarlanmadı",
    "No results": "Sonuç yok",
    "no": "hayır",
    "No.": "No.",
    "None": "Hiçbiri",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "Altta",
    "On the left": "Solda",
    "On the right": "Sağda",
    "On the top": "Üstte",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "şeffaflık",
    "Opacity": "Opacity",
    "Open current feature on load": "Mevcut yüklemede olan nesneyi aç",
    "Open link in…": "Bağlantıyı şurada aç",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "OpenStreetMap'e daha doğru veri sağlayabilmek için bu harita kapsamını bir harita düzenleyicide aç",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Isı haritası için isteğe bağlı yoğunluk özelliği",
    "Optional. Same as color if not set.": "İsteğe bağlı. Eğer ayarlanmazsa renk ile aynı.",
    "Optional.": "İsteğe bağlı.",
    "Override clustering radius (default 80)": "Kümeleme yarıçapını geçersiz kıl (varsayılan 80)",
    "Override heatmap radius (default 25)": "Isı haritası yarıçapını geçersiz kıl (varsayılan 25)",
    "parent window": "üst pencere",
    "Paste your data here": "Paste your data here",
    "Permalink": "Kalıcı bağlantı",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Lütfen lisansın kullanımınızla uyumlu olduğundan emin olun.",
    "Please choose a format": "Lütfen bir biçim seçin",
    "Please enter the name of the property": "Lütfen bu özelliğin adını girin",
    "Please enter the new name of this property": "Lütfen bu özelliğin yeni adını girin",
    "Please save the map first": "Lütfen önce haritayı kaydedin",
    "Popup (large)": "Açılır pencere (büyük)",
    "Popup content style": "Pop-up içerik stili",
    "Popup content template": "Pop-up içerik şablonu",
    "Popup shape": "Pop-up şekli",
    "Popup": "Açılır pencere",
    "Powered by uMap": "Powered by uMap",
    "previous": "önceki",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "İçe aktarılan özellikler:",
    "Provide an URL here": "Buraya bir URL girin",
    "Proxy request": "Proxy isteği",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Uzaktan veriler",
    "Remove shape from the multi": "Şekli çokludan kaldır",
    "Replace layer content": "Katman içeriğini değiştir",
    "Restore this version": "Bu sürümü geri yükleyin",
    "Save current edits": "Şimdiki düzenlemeleri kaydet",
    "Save map": "Save map",
    "Save": "Kaydet",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Konum ara",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Tam ekranda gör",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Bu katmanı slayt gösterisinden, veri tarayıcısından, pop-up gezinmeden gizlemek için yanlış olarak ayarlayın ...",
    "settings": "settings",
    "Shape properties": "Şekil özellikleri",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Kısa krediler",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Katmanı göster/gizle",
    "Side panel": "Yan panel",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Basitleştir",
    "Skipping unknown geometry.type: {type}": "Bilinmeyen geometri tipini atlama: {type}",
    "Slideshow": "Slayt gösterisi",
    "Sort key": "Kısa anahtar",
    "Split line": "Çizgiyi böl",
    "Star this map": "Star this map",
    "Start a hole here": "Burada bir delik aç",
    "Start slideshow": "Slayt gösterisini başlat",
    "Stop editing": "Düzenlemeyi durdur",
    "Stop slideshow": "Slayt gösterisini durdur",
    "Street": "Street",
    "stroke": "stroke",
    "Supported scheme": "Desteklenen şema",
    "Supported variables that will be dynamically replaced": "Dinamik olarak değiştirilecek desteklenen değişkenler",
    "Symbol": "Symbol",
    "Table": "Tablo",
    "Text color for the cluster label": "Küme etiketi için metin rengi",
    "Text formatting": "Metin biçimlendirme",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Nesne özgün tanımlayıcısı olarak kullanılacak özelliğin adı",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMS formatı",
    "To use if remote server doesn't allow cross domain (slower)": "Uzak sunucu etki alanları arası izin vermiyorsa kullanmak için (daha yavaş)",
    "To zoom": "Yakınlaştırmak için",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Şekli düzenlenmiş özelliğe transfer et",
    "Transform to lines": "Çizgilere dönüştür",
    "Transform to polygon": "Çokgene dönüştür",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Katmanın tipi",
    "Unable to detect format of file {filename}": "Dosyanın biçimi belirlenemedi {filename}",
    "Untitled layer": "Adlandırılmamış katman",
    "Untitled map": "Adlandırılmamış harita",
    "Update permissions and editors": "İzinleri ve düzenleyicileri güncelleyin",
    "Update permissions": "İzinleri güncelle",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Geçerli sınırları kullan",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Parantezler arasında nesne özelliklerine sahip yer tutucuları kullanın, örneğin. &#123;isim&#125;, dinamik olarak karşılık gelen değerlerle değiştirilecektir.",
    "User content credits": "Kullanıcı içerik kredisi",
    "User interface options": "Kullanıcı arayüzü seçenekleri",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Sürümler",
    "View Fullscreen": "Tam ekranda görüntüle",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "kalınlık",
    "Where do we go from here?": "Buradan sonra nereye gidiyoruz?",
    "Whether to display or not polygons paths.": "Çokgen yolların görüntülenip görüntülenmeyeceği",
    "Whether to fill polygons with color.": "Çokgenleri renkle doldur ya da doldurma",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Kim düzenleyebilir",
    "Who can view": "Kim görüntüleyebilir",
    "width": "genişlik",
    "Will be displayed in the bottom right corner of the map": "Haritanın sağ alt köşesinde görüntülenecek",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Haritanın başlığında görüntülenecek",
    "yes": "evet",
    "Zoom in": "Yakınlaştır",
    "Zoom level for automatic zooms": "Otomatik yakınlaştırma için yakınlaştırma seviyesi",
    "Zoom out": "Uzaklaştır",
    "Zoom to layer extent": "Katman genişliğine yakınlaştır",
    "Zoom to the next": "Bir sonrakine yakınlaştır",
    "Zoom to the previous": "Bir öncekine yakınlaştır",
    "Zoom to this feature": "Bu nesneyi yakınlaştır",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{sayı} içe aktarma sırasında hatalar: {mesaj}",
    "{delay} seconds": "{gecikme} saniye",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Display the back to home icon",
    "Do you want to display layer switcher in caption bar?": "Do you want to display layer switcher in caption bar?",
    "Simplify all geometries to points": "Simplify all geometries to points",
    "Back to list": "Back to list",
    "Toggle rule": "Toggle rule",
    "Delete rule": "Delete rule",
    "Cannot save layer, please try again in a few minutes.": "Cannot save layer, please try again in a few minutes."
}
L.registerLocale("tr", locale)
L.setLocale("tr")
