const locale = {
    "(area: {measure})": "(areal: {measure})",
    "(length: {measure})": "(længde: {measure})",
    "# one hash for main heading": "# et hashtag for hovedoverskrift",
    "## two hashes for second heading": "## to hashtags for andet overskriftniveau",
    "### three hashes for third heading": "### tre hashtags for tredje overskriftsniveau",
    "**double star for bold**": "**dobbeltstjerne for fed skrift**",
    "*single star for italic*": "*enkeltstjerne for kursiv*",
    "--- for a horizontal rule": "--- for en vandret streg",
    "1 day": "1 dag",
    "1 hour": "1 time",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "En kommasepareret liste af tal, der definerer mønstret for stiplet streg. F.eks.: \"5, 10, 15\".",
    "About": "Om",
    "Action not allowed :(": "Handling ikke tilladt :(",
    "Activate slideshow mode": "Aktiver fremvisningstilstand",
    "Add a layer": "Tilføj et lag",
    "Add a line to the current multi": "Tilføj en linje til nuværende multi",
    "Add a new property": "Tilføj en ny egenskab",
    "Add a polygon to the current multi": "Tilføj en polygon til aktuel multi",
    "Add image URL": "Tilføj billed-URL",
    "Advanced actions": "Avancerede handlinger",
    "Advanced properties": "Avancerede egenskaber",
    "All data and settings of the map": "Alle kortets data og indstillinger",
    "All properties are imported.": "Alle egenskaber er importeret.",
    "Allow interactions": "Tillad interaktioner",
    "Allow scroll wheel zoom?": "Tillad zoom med scrollhjul?",
    "always": "altid",
    "Animated transitions": "Animerede overgange",
    "Are you sure you want to clone this map and all its datalayers?": "Er du sikker på du vil klone dette kort og alle dets datalag?",
    "Are you sure you want to delete this map?": "Er du sikker på, at du vil slette dette kort?",
    "Are you sure you want to delete this property on all the features?": "Er du sikker på du vil slette denne egenskab på alle objekter?",
    "Are you sure you want to restore this version?": "Er du sikker på, at du vil genskabe denne version?",
    "Attach the map to my account": "Knyt kortet til min konto",
    "attribution": "kreditering",
    "Auto": "Auto",
    "Automatic": "Automatisk",
    "Autostart when map is loaded": "Start automatisk, når kortet indlæses",
    "Back to preview": "Tilbage til forhåndsvisning",
    "Background overlay url": "URL til baggrundsoverlejring",
    "Ball": "Knappenål",
    "Bring feature to center": "Centrer objektet",
    "Browse data": "Gennemse data",
    "by": "af",
    "Cache proxied request": "Gem forespørgsler via proxy i cache",
    "Caption": "Korttekst",
    "Center map on your location": "Centrer kort på din placering",
    "Change tilelayers": "Skift fliselag",
    "Change": "Ændr",
    "Choose the data format": "Vælg dataformat",
    "Choropleth breakpoints": "Koroplet-brudpunkter",
    "Choropleth classes": "Koroplet-klasser",
    "Choropleth color palette": "Koroplet-farvepalette",
    "Choropleth mode": "Koroplet-tilstand",
    "Choropleth property value": "Koroplet-egenskabsværdi",
    "Choropleth": "Koroplet",
    "Circle": "Cirkel",
    "clear": "nulstil",
    "Click last point to finish shape": "Klik på det det sidste punkt for at afslutte figur",
    "Click to add a marker": "Klik for at tilføje en markør",
    "Click to continue drawing": "Klik for at fortsætte indtegning",
    "Click to edit": "Klik for at redigere",
    "Click to start drawing a line": "Klik for at starte indtegning af linje",
    "Click to start drawing a polygon": "Klik for at starte indtegning af polygon",
    "Clone of {name}": "Klon af {name}",
    "Clone this feature": "Klon dette objekt",
    "Clone this map": "Klon dette kort",
    "Clone": "Klon",
    "Close": "Luk",
    "Clustered": "Klynget",
    "Clustering radius": "Klyngeradius",
    "collapsed": "sammenklappet",
    "color": "farver",
    "Comma separated list of numbers, including min and max values.": "Kommasepareret liste af tal, inklusive min- og max-værdier.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Kommasepareret liste over egenskaber, der skal bruges til at sortere objekter. For at vende sorteringen skal du sætte et minustegn (-) før. F.eks. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma, tabulering eller semikolon adskiller værdier. SRS WGS84 er underforstået. Kun punktgeometri importeres. Importen vil kigge efter kolonner, der indeholder varianter af \"lat\" eller \"lon\" i begyndelsen af overskriften, uden at tage hensyn til små og store bogstaver. Alle andre kolonner importeres som egenskaber.",
    "Congratulations, your map has been created!": "Tillykke, dit kort er nu oprettet!",
    "Continue line": "Fortsæt linje",
    "Coordinates": "Koordinater",
    "copy": "kopier",
    "Credits": "Kreditering",
    "Current map view": "Nuværende kortvisning",
    "Current view instead of default map view?": "Nuværende kortudsnit i stedet for standardkortvisning?",
    "Custom background": "Tilpasset baggrund",
    "Custom overlay": "Tilpasset overlejring",
    "dash array": "stiplet række",
    "Data is browsable": "Data kan gennemses",
    "Datalayers": "Datalag",
    "Default interaction options": "Standardindstillinger for interaktion",
    "Default properties": "Standardegenskaber",
    "Default shape properties": "Standardegenskaber for figur",
    "Default view": "Standardvisning",
    "Default zoom level": "Standard zoomniveau",
    "Default": "Standard",
    "Default: name": "Standard: navn",
    "Define link to open in a new window on polygon click.": "Definer link der åbnes i et nyt vindue ved klik på polygon.",
    "define": "definer",
    "Delay between two transitions when in play mode": "Forsinkelse mellem to overgange i afspilningstilstand",
    "Delete layer": "Slet lag",
    "Delete this feature": "Slet dette objekt",
    "Delete this shape": "Slet denne figur",
    "Delete this vertex (Alt+Click)": "Slet denne vertex (Alt+Click)",
    "Delete": "Slet",
    "description": "beskrivelse",
    "Direct link": "Direkte link",
    "Directions from here": "Rute herfra",
    "Display label": "Vis etikette",
    "Display measure": "Vis opmåling",
    "display name": "visningsnavn",
    "Display on load": "Vis ved indlæsning",
    "Display the control to open OpenStreetMap editor": "Vis kontrollen til åbning af OpenStreetMap-editoren",
    "Display the embed control": "Vis indlejringskontrollen",
    "Display the fullscreen control": "Vis fuldskærmskontrollen",
    "Display the locate control": "Vis lokaliseringskontrollen",
    "Display the measure control": "Vis opmålingskontrollen",
    "Display the search control": "Vis søgekontrollen",
    "Display the tile layers control": "Vis fliselagskontrollen",
    "Display the zoom control": "Vis zoomkontrollen",
    "Do you want to display a caption bar?": "Vil du vise en bjælke med korttekst?",
    "Do you want to display a minimap?": "Vil du vise et miniaturekort?",
    "Do you want to display a panel on load?": "Vil du vise et panel ved indlæsning?",
    "Do you want to display caption menus?": "Vil du vise korttekstmenuer?",
    "Do you want to display popup footer?": "Vil du vise popup-fodnoten?",
    "Do you want to display the scale control?": "Vil du vise målestokskontrollen?",
    "Do you want to display the «more» control?": "Vil du vise \"mere\"-kontrollen?",
    "Download": "Download",
    "Drag to reorder": "Træk for at ændre rækkefølge",
    "Draw a marker": "Tegn en markør",
    "Draw a polygon": "Tegn en polygon",
    "Draw a polyline": "Tegn en polygonlinje",
    "Drawing": "Tegner",
    "Drop": "Dråbe",
    "Dynamic properties": "Dynamiske egenskaber",
    "Dynamic": "Dynamisk",
    "Edit feature's layer": "Rediger objekts lag",
    "Edit properties in a table": "Rediger egenskaberne i en tabel",
    "Edit the title of the map": "Rediger titlen på kortet",
    "Edit this feature": "Rediger dette objekt",
    "Edit": "Rediger",
    "Embed and link options": "Indlejrings- og linkmuligheder",
    "Embed the map": "Indlejr kortet",
    "Emoji & Character": "Emoji og tegn",
    "Empty": "Ryd",
    "Equidistant": "Lige langt væk",
    "Error in the overlay URL": "Fejl i URL til overlejring",
    "Error in the tilelayer URL": "Fejl i URL til fliselag",
    "Exit Fullscreen": "Afslut fuldskærm",
    "expanded": "udvidet",
    "Extract shape to separate feature": "Udtræk figur for at adskille objekt",
    "Feature identifier key": "Identifikationsnøgle for objekt",
    "Feature properties": "Egenskaber for objekt",
    "Fetch data each time map view changes.": "Hent data hver gang kortvisningen ændres.",
    "fill color": "udfyldningsfarve",
    "fill opacity": "udfyldnings gennemsigtighed",
    "fill": "udfyldning",
    "Fit all data": "Tilpas alle data",
    "Format": "Format",
    "From zoom": "Fra zoom",
    "full backup": "fuld backup",
    "Generic": "Generisk",
    "GeoRSS (only link)": "GeoRSS (kun link)",
    "GeoRSS (title + image)": "GeoRSS (titel + billede)",
    "Go to \"{coords}\"": "Gå til \"{coords}\"",
    "Go to the homepage": "Gå til startsiden",
    "Go to «{feature}»": "Gå til \"{feature}\"",
    "Heatmap intensity property": "Heatmaps intensitetsegenskaber",
    "Heatmap radius": "Heatmaps radius",
    "Heatmap": "Heatmap",
    "height": "højde",
    "Help": "Hjælp",
    "hidden": "skjult",
    "Hide controls": "Skjul kontroller",
    "Home": "Startside",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Hvor meget polylinjen skal forenkles på hvert zoomniveau (mere = bedre ydeevne og jævnere udseende, mindre = mere præcist)",
    "icon opacity": "Ikonets gennemsigtighed",
    "Icon shape": "Ikonfacon",
    "Icon symbol": "Ikonsymbol",
    "If false, the polygon or line will act as a part of the underlying map.": "Hvis slået fra, vil polygonen eller linjen fungere som en del af det underliggende kort.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe med tilpasset højde (i px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe med brugerdefineret højde og bredde (i px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Billede med tilpasset bredde (i px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Billede: {{https://image.url.com}}",
    "Import data": "Importer data",
    "Import in a new layer": "Importerer i et nyt lag",
    "Imports all umap data, including layers and settings.": "Importerer alle umap-data, inklusiv lag og indstillinger,",
    "Include full screen link?": "Inkluder fuldskærmslink?",
    "Inherit": "Nedarv",
    "inherit": "nedarv",
    "Interaction options": "Interaktionsindstillinger",
    "Invalid latitude or longitude": "Ugyldig bredde- eller længdegrad",
    "Invalid umap data in {filename}": "Ugydige umap-data i {filename}",
    "Invalid umap data": "Ugyldige umap-data",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Behold nuværende synlige lag",
    "kilometers": "kilometer",
    "km": "km",
    "Label direction": "Etiketteretning",
    "Label key": "Etikette-nøgle",
    "Labels are clickable": "Etiketter er klikbare",
    "Latest feature": "Seneste objekt",
    "Latitude": "Længdegrader",
    "Layer properties": "Lags egenskaber",
    "Layer": "Lag",
    "Licence": "Licens",
    "licence": "licens",
    "Limit bounds": "Afgrænsning",
    "Link to view the map": "Link til at se kortet",
    "Link to…": "Link til…",
    "Link with text: [[https://example.com|text of the link]]": "Link med tekst: [[https://example.com|tekst for link]]",
    "Long credits": "Lang kreditering",
    "Longitude": "Breddegrader",
    "Make main shape": "Gør til primær figur",
    "Manage layers": "Håndter lag",
    "Manual": "Manuel",
    "Map background credits": "Baggrundskortkreditering",
    "Map has been attached to your account": "Kortet er blevet knyttet til din konto",
    "Map has been saved!": "Kortet er blevet gemt!",
    "Map has been starred": "Kort er blevet stjernemarkeret",
    "Map has been unstarred": "Stjerne er fjernet fra kort",
    "Map user content has been published under licence": "Kortets brugerindholdet er udgivet under licensen",
    "Map's editors": "Kortets redaktører",
    "Map's owner": "Kortets ejer",
    "max East": "max øst",
    "max North": "max nord",
    "max South": "max syd",
    "max West": "max vest",
    "max zoom": "max zoom",
    "Measure distances": "Opmål afstande",
    "Merge lines": "Flet linjer",
    "mi": "mi",
    "miles": "miles",
    "min zoom": "min. zoom",
    "More controls": "Vis flere kontroller",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Skal være en gyldig CSS-værdi (fx: DarkBlue eller #123456)",
    "name": "navn",
    "nautical miles": "sømil",
    "never": "aldrig",
    "new window": "nyt vindue",
    "next": "næste",
    "NM": "NM",
    "No cache": "Ingen cache",
    "No licence has been set": "Ingen licens angivet",
    "No results": "Ingen resultater",
    "no": "nej",
    "No.": "Nej.",
    "None": "Ingen",
    "Number of desired classes (default 5)": "Antal ønskede klasser (standard 5)",
    "On the bottom": "I bunden",
    "On the left": "Til venstre",
    "On the right": "Til højre",
    "On the top": "I toppen",
    "Only visible layers' data": "Kun synlige lags data",
    "opacity": "gennemsigtighed",
    "Opacity": "Gennemsigtighed",
    "Open current feature on load": "Åbn aktuelt objekt ved indlæsning",
    "Open link in…": "Åbn link i…",
    "Open share & download panel": "Åbn panelet for deling og download",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Åbn dette kort i en korteditor for at levere mere nøjagtige data til OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Valgfri intensitetsegenskaber for heatmap",
    "Optional. Same as color if not set.": "Valgfri. Samme som farve, hvis ikke angivet.",
    "Optional.": "Valgfri.",
    "Override clustering radius (default 80)": "Overskriv klyngeradius (standard 80)",
    "Override heatmap radius (default 25)": "Overskriv heatmapradius (standard 25)",
    "parent window": "forældervindue",
    "Paste your data here": "Indsæt dine data her",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanent kreditering baggrund",
    "Permanent credits": "Permanent kreditering",
    "Please be sure the licence is compliant with your use.": "Sørg for, at licensen er kompatibel med din anvendelse.",
    "Please choose a format": "Vælg et format",
    "Please enter the name of the property": "Angiv egenskabens navn",
    "Please enter the new name of this property": "Angiv egenskabens nye navn",
    "Please save the map first": "Gem først kortet",
    "Popup (large)": "Popup (stor)",
    "Popup content style": "Popup-indholdsstil",
    "Popup content template": "Popup-indholdsskabelon",
    "Popup shape": "Popup-facon",
    "Popup": "Popup",
    "Powered by uMap": "Drevet af uMap",
    "previous": "forrige",
    "Problem in the response": "Problem i svaret",
    "Properties imported:": "Egenskaber importeret:",
    "Provide an URL here": "Indsæt en URL her",
    "Proxy request": "Proxy-forespørgsel",
    "Quantiles": "Kvantiler",
    "Recent": "Seneste",
    "Remote data": "Fjerndata",
    "Remove shape from the multi": "Fjern figur fra multi",
    "Replace layer content": "Erstat lags indhold",
    "Restore this version": "Genskab denne version",
    "Save current edits": "Gem nuværende redigeringer",
    "Save map": "Gem kort",
    "Save": "Gem",
    "Saved center and zoom": "Gem centrum og zoom",
    "Search location": "Søg efter lokalitet",
    "Search": "Søg",
    "Secret edit link:": "Hemmeligt redigeringslink:",
    "See full screen": "Se i fuld skærm",
    "See on OpenStreetMap": "Se på OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Slå den fra for at skjule dette lag fra fremvisning, databrowseren, popup-navigeringen…",
    "settings": "indstillinger",
    "Shape properties": "Figuregenskaber",
    "Share and download": "Del og download",
    "Share this link to open a customized map view": "Del dette link for at åbne en tilpasset kortvisning",
    "Short credits": "Korte krediteringer",
    "Short link": "Forkortet link",
    "Show this layer in the caption": "Vis dette lag i kortteksten",
    "Show/hide layer": "Vis/skjul lag",
    "Side panel": "Sidepanel",
    "Simple link: [[https://example.com]]": "Simpelt link: [[https://example.com]]",
    "Simplify": "Simplificer",
    "Skipping unknown geometry.type: {type}": "Springer over ukendt geometry.type: {type}",
    "Slideshow": "Fremvisning",
    "Sort key": "Sorteringsnøgle",
    "Split line": "Opdel linje",
    "Star this map": "Stjernemarker dette kort",
    "Start a hole here": "Start et hul her",
    "Start slideshow": "Start fremvisning",
    "Stop editing": "Stop redigering",
    "Stop slideshow": "Stop fremvisning",
    "Street": "Gade",
    "stroke": "streg",
    "Supported scheme": "Understøttet format",
    "Supported variables that will be dynamically replaced": "Understøttede variabler, der bliver udskiftet dynamisk",
    "Symbol": "Symbol",
    "Table": "Tabel",
    "Text color for the cluster label": "Tekstfarve for klyngeetikette",
    "Text formatting": "Tekstformatering",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Navnet på den egenskab, der skal bruges som objektetikette (f.eks.: \"nom\"). Du kan også bruge egenskaber inden for parentes til at bruge mere end én eller blande med statisk indhold (f.eks.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Navnet på den egenskab, der skal bruges som objektets unikke identifikator.",
    "The zoom and center have been modified.": "Zoom og centrum er blevet ændret.",
    "TMS format": "TMS-format",
    "To use if remote server doesn't allow cross domain (slower)": "Anvendes hvis fjernserver ikke tillader krydsdomæne (langsommere)",
    "To zoom": "Til zoom",
    "Toggle edit mode (⇧+Click)": "Skift redigeringstilstand (⇧+Klik)",
    "Toggle edit mode": "Skift redigeringstilstand",
    "Transfer shape to edited feature": "Overfør figur til redigeret objekt",
    "Transform to lines": "Omdan til linjer",
    "Transform to polygon": "Omdan til polygon",
    "Type a place name or coordinates": "Indtast et stednavn eller koordinater",
    "Type char or paste emoji": "Indtast tegn eller indsæt emoji",
    "Type of layer": "Lagtype",
    "Unable to detect format of file {filename}": "Kunne ikke genkende formatet på filen {filename}",
    "Untitled layer": "Unavngivet lag",
    "Untitled map": "Unavngivet kort",
    "Update permissions and editors": "Opdater indstillinger og redaktører",
    "Update permissions": "Opdater tilladelser",
    "Update who can see and edit the map": "Opdater, hvem der kan se og redigere kortet",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Brug nuværende kortudsnit",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Brug pladsholdere med objektegenskaberne mellem tuborgklammer, fx &#123;navn&#125;, så vil de dynamatisk blive erstattet med de tilhørende værdier.",
    "User content credits": "Brugerindhold-kreditering",
    "User interface options": "Brugerfladeindstillinger",
    "User location": "Brugerplacering",
    "Verify remote URL": "Bekræft ekstern URL",
    "Versions": "Versioner",
    "View Fullscreen": "Fuldskærmsvisning",
    "View": "Vis",
    "Visibility: {status}": "Synlighed: {status}",
    "weight": "vægtning",
    "Where do we go from here?": "Hvad gør vi nu?",
    "Whether to display or not polygons paths.": "Hvorvidt der vises eller ikke vises polygonstier.",
    "Whether to fill polygons with color.": "Hvorvidt polygoner udfyldes med farve.",
    "Who can edit \"{layer}\"": "Hvem kan redigere \"{layer}\"",
    "Who can edit": "Hvem kan redigere",
    "Who can view": "Hvem kan se",
    "width": "bredde",
    "Will be displayed in the bottom right corner of the map": "Vil blive vist i kortets nederste højre hjørne",
    "Will be permanently visible in the bottom left corner of the map": "Vil være permanent synlig i nederste venstre hjørne af kortet",
    "Will be visible in the caption of the map": "Vil være synlig i tekstfeltet på kortet",
    "yes": "ja",
    "Zoom in": "Zoom ind",
    "Zoom level for automatic zooms": "Zoomniveau for automatisk zooming",
    "Zoom out": "Zoom ud",
    "Zoom to layer extent": "Zoom til lags udstrækning",
    "Zoom to the next": "Zoom til næste",
    "Zoom to the previous": "Zoom til forrige",
    "Zoom to this feature": "Zoom til dette objekt",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} fejl under import: {message}",
    "{delay} seconds": "{delay} sekunder",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Rediger kortnavn og tekst",
    "Map advanced properties": "Kortets avancerede egenskaber",
    "Edit map details": "Rediger kortdetaljer",
    "Back to browser": "Tilbage til browser",
    "Toggle size": "Skift størrelse",
    "Display the caption control": "Vis korttekstkontrollen",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Maks",
    "From": "Fra",
    "Until": "Indtil",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Eksempel: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Rediger i OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Kan ikke bestemme bredde- og længdegradskolonner.",
    "Back to layers": "Tilbage til lag",
    "Filters": "Filtre",
    "Comma separated list of properties to use when filtering features by text input": "Kommasepareret liste over egenskaber, der skal bruges til at filtrere objekter efter tekstinput",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Kommasepareret liste over egenskaber, der skal bruges til filtre (f.eks.: mykey,otherkey). For at kontrollere etiketten skal du tilføje den efter en | (F.eks.: mykey|My Key,otherkey|Other Key). For at styre inputfeltets type skal du tilføje det efter en anden | (F.eks.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Tilladte værdier for inputfelt-typen er checkbox (standard), radio, number, date og datetime.",
    "Search keys": "Søg nøgler",
    "Filters keys": "Filtrerer nøgler",
    "Filter data": "Filtrer data",
    "Search map features…": "Søg kortobjekter…",
    "Reset all": "Nulstil alt",
    "Open browser": "Åbn browser",
    "Open caption": "Åbn korttekst",
    "Your map has been created with an anonymous account!": "Dit kort er blevet oprettet med en anonym konto!",
    "Real-time collaboration": "Samarbejde i realtid",
    "Cannot parse data": "Kan ikke fortolke data",
    "Start typing...": "Begynd at skrive...",
    "No result": "Intet resultat",
    "Data browser": "Data-browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Når du angiver en URL, kan uMap kopiere fjerndataene i et lag eller tilføje denne URL som fjernkilde til laget. I så fald vil data altid blive hentet fra denne URL og dermed være opdaterede, men det vil ikke være muligt at redigere dem i uMap.",
    "Overpass supported expressions": "Understøttede Overpass-udtryk",
    "key (eg. building)": "key (f.eks. building)",
    "!key (eg. !name)": "!key (f.eks. !name)",
    "key=value (eg. building=yes)": "key=value (f.eks. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (f.eks. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (f.eks. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (f.eks. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "Mere info om Overpass-syntaks",
    "For more complex needs, see": "For mere komplekse behov, se",
    "Choose data": "Vælg data",
    "Choose the format": "Vælg formatet",
    "Choose the layer": "Vælg laget",
    "Layer name": "Lagnavn",
    "Choose import mode": "Vælg importtype",
    "Copy into the layer": "Kopier ind i laget",
    "Link to the layer as remote data": "Link til laget som fjerndata",
    "Condition": "Tilstand",
    "key=value or key!=value": "key=value eller key!=value",
    "Are you sure you want to delete this rule?": "Er du sikker på, at du vil slette denne regel?",
    "empty rule": "tom regel",
    "Conditional style rules": "Betingede stilregler",
    "Add rule": "Tilføj regel",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: lag",
    "Browser: filters": "Browser: filtre",
    "Enable real-time collaboration": "Aktiver samarbejde i realtid",
    "✅ Copied!": "✅ Kopieret!",
    "Choose a dataset": "Vælg et datasæt",
    "Choose this dataset": "Vælg dette datasæt",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: tematiske data fra OpenStreetMap",
    "Choose a theme": "Vælg et tema",
    "Choose this data": "Vælg disse data",
    "Search admin boundary": "Søg admin-grænse",
    "Please choose a theme and a boundary first.": "Vælg først et tema og en afgrænsning.",
    "Expression": "Udtryk",
    "Geometry mode": "Geometri-tilstand",
    "Only geometry centers": "Kun geometricentre",
    "Search area": "Søgeområde",
    "Type area name, or let empty to load data in current map view": "Indtast områdenavn, eller lad det være tomt for at indlæse data i den aktuelle kortvisning",
    "Data successfully imported!": "Data importeret!",
    "Clear data": "Ryd data",
    "Remove layers": "Fjern lag",
    "Categorized": "Kategoriseret",
    "Alphabetical": "Alfabetisk",
    "Category property": "Kategori-egenskab",
    "Color palette": "Farvepalette",
    "Categories": "Kategorier",
    "Comma separated list of categories.": "Kommasepareret liste over kategorier.",
    "Categories mode": "Kategori-tilstand",
    "Remove filter for this column": "Fjern filter for denne kolonne",
    "Add filter for this column": "Tilføj filter for denne kolonne",
    "Rename this column": "Omdøb denne kolonne",
    "Delete this column": "Slet denne kolonne",
    "Name “{name}” should not contain a dot.": "Navnet “{name}” må ikke indeholde et punktum.",
    "This name already exists: “{name}”": "Dette navn findes allerede: “{name}”",
    "Delete selected rows": "Slet valgte rækker",
    "Found {count} rows. Are you sure you want to delete all?": "Fandt {count} rækker. Er du sikker på, at du vil slette alt?",
    "Expression is empty": "Udtryk er tomt",
    "OK": "OK",
    "Cancel": "Annuller",
    "Attach map to a team": "Tilknyt kort til et team",
    "Display the polygon inverted": "Vis polygonen spejlvendt",
    "Proportional circles": "Proportionelle cirkler",
    "Property name to compute circles": "Egenskabsnavn til beregning af cirkler",
    "Min circle radius": "Min. cirkelradius",
    "Max circle radius": "Maks. cirkelradius",
    "Display the open browser control": "Vis kontrollen til at åbne browser",
    "Copy as GeoJSON": "Kopier som GeoJSON",
    "Please zoom in to edit the geometry": "Zoom ind for at redigere geometrien",
    "New map": "Nyt kort",
    "My maps": "Mine kort",
    "My teams": "Mine teams",
    "My profile": "Min profil",
    "Type new owner's username": "Indtast den nye ejers brugernavn",
    "Type editor's username": "Indtast redaktørs brugernavn",
    "Map": "Kort",
    "Manage collaborators": "Administrer samarbejdspartnere",
    "show/hide all layers": "vis/skjul alle lag",
    "zoom to data extent": "zoom til dataomfang",
    "download visible data": "download synlige data",
    "Import helpers": "Import-hjælpere",
    "Import helpers will fill the URL field for you.": "Import-hjælpere udfylder URL-feltet for dig.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Gem kladde",
    "No data has been found for import": "Der er ikke fundet nogen data til import",
    "Successfully imported {count} feature(s)": "Importerede {count} objekt(er)",
    "Disconnected": "Afbrudt",
    "You must be logged in": "Du skal være logget ind",
    "on hover": "ved hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Kan ikke indlæse fjerndata for laget \"{layer}\" med url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Kan ikke fortolke fjerndata for laget \"{layer}\" med url \"{url}\"",
    "Import failed: invalid data": "Import mislykkedes: ugyldige data",
    "Anonymous": "Anonym",
    "created at {date}": "oprettet den {date}",
    "modified at {date}": "ændret den {date}",
    "Default zoom": "Standard-zoom",
    "Default latitude": "Standard-breddegrad",
    "Default longitude": "Standard-længdegrad",
    "Edit map default view": "Rediger kortets standardvisning",
    "Use current center and zoom": "Brug nuværende centrum og zoom",
    "Layer permalink": "Lag permalink",
    "Back to home": "Tilbage til startside",
    "Home logo": "Startside-logo",
    "Add this geometry to my map": "Tilføj denne geometri til mit kort",
    "Add this place to my map": "Tilføj dette sted til mit kort",
    "Cancel last edit": "Annuller seneste redigering",
    "Redo last edit": "Gentag seneste redigering",
    "Links": "Links",
    "Images": "Billeder",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geokode",
    "Display the back to home icon": "Vis ikonet for startsiden",
    "Do you want to display layer switcher in caption bar?": "Vil du vise lagskifter i korttekstbjælken?",
    "Simplify all geometries to points": "Simplificér alle geometrier til punkter",
    "Back to list": "Tilbage til liste",
    "Toggle rule": "Skift regel",
    "Delete rule": "Slet regel",
    "Cannot save layer, please try again in a few minutes.": "Kan ikke gemme laget, prøv igen om et par minutter.",
    "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.": "Aktivér fælles live-redigering på dette kort. Andre brugere skal genindlæse kortet, efter at denne indstilling er ændret.",
    "More help resources": "Flere ressourcer til hjælp",
    "This map is a template": "Dette kort er en skabelon",
    "Add text along path": "Tilføj tekst langs sti",
    "Text color": "Tekstfarve",
    "Text offset": "Tekstforskydning",
    "Text position": "Tekstposition",
    "start": "start",
    "center": "centrum",
    "end": "slut",
    "Text repeat": "Tekst-gentagelse",
    "Text rotate": "Tekst-rotation",
    "Text size": "Tekststørrelse",
    "Load map template": "Indlæs kortskabelon",
    "My templates": "Mine skabeloner",
    "From staff": "Fra medarbejdere",
    "From community": "Fra fællesskabet",
    "You must select a template.": "Du skal vælge en skabelon.",
    "Line decoration": "Linjeudsmykning",
    "Reuse this template": "Genbrug denne skabelon",
    "Create a new map using this template": "Opret et nyt kort ved hjælp af denne skabelon",
    "Save template": "Gem skabelon",
    "Load template": "Indlæs skabelon",
    "Loading a template will apply predefined styles and settings to your map": "Indlæsning af en skabelon vil anvende foruddefinerede stilarter og indstillinger på dit kort",
    "Load template with data": "Indlæs skabelon med data",
    "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".": "Du har ikke registreret nogen skabelon endnu. Du kan tilføje en ved at oprette et nyt kort og markere det som \"skabelon\".",
    "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.": "Der er ingen anbefalet skabelon endnu. Anbefalede skabeloner er dem, der er stjernemarkeret af uMap-administratorer.",
    "There is no public template yet.": "Der er ingen offentlig skabelon endnu.",
    "Explore": "Udforsk",
    "Import data from public open data portals": "Importer data fra offentlige åbne dataportaler",
    "Choose a portal": "Vælg en portal",
    "Limit results to current map view": "Begræns resultaterne til den aktuelle kortvisning",
    "Please choose an instance first.": "Vælg en instans først."
}
L.registerLocale("da", locale)
L.setLocale("da")
