{% extends "umap/content.html" %}

{% load i18n static %}

{% block head_title %}
  {% translate "My Dashboard" %} - {{ SITE_DESCRIPTION }}
{% endblock head_title %}
{% block maincontent %}
  {% include "umap/dashboard_menu.html" with selected="maps" %}
  {% trans "Search my maps" as submit_label %}
  {% trans "Map’s name" as label_title %}
  {% blocktranslate asvar download_label with count=maps.object_list|length trimmed %}
    Download {{ count }} maps
  {% endblocktranslate %}
  {% blocktranslate asvar empty_label %}You have no map yet.{% endblocktranslate %}
  {% translate "Create a map" as create_label %}
  {% translate "No map found." as empty_search_label %}
  {% include "umap/user_map_table.html" with submit_label=submit_label label_title=label_title download_label=download_label empty_label=empty_label create_label=create_label empty_search_label=empty_search_label %}
{% endblock maincontent %}
