const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# satu tanda pagar untuk tajuk utama",
    "## two hashes for second heading": "## dua tanda pagar untuk tajuk kedua",
    "### three hashes for third heading": "### tiga tanda pagar untuk tajuk ketiga",
    "**double star for bold**": "**bintang berganda untuk tulisan tebal**",
    "*single star for italic*": "*bintang tunggal untuk tulisan condong*",
    "--- for a horizontal rule": "--- untuk garis melintang",
    "1 day": "1 hari",
    "1 hour": "1 jam",
    "5 min": "5 minit",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Senarai berpisahkan koma bagi nombor yang menentukan corak sengkang lejang. Cth.: \"5, 10, 15\".",
    "About": "Perihalan",
    "Action not allowed :(": "Tindakan tidak dibenarkan :(",
    "Activate slideshow mode": "Aktifkan mod persembahan slaid",
    "Add a layer": "Tambah lapisan",
    "Add a line to the current multi": "Tambah garisan ke multi semasa",
    "Add a new property": "Tambah ciri-ciri baharu",
    "Add a polygon to the current multi": "Tambah poligon ke multi semasa",
    "Add image URL": "Tambah URL imej",
    "Advanced actions": "Tindakan lanjutan",
    "Advanced properties": "Ciri-ciri lanjutan",
    "All data and settings of the map": "Semua data dan tetapan peta",
    "All properties are imported.": "Semua ciri-ciri telah diimport.",
    "Allow interactions": "Benarkan interaksi",
    "Allow scroll wheel zoom?": "Benarkan zum dengan roda tatal?",
    "always": "sentiasa",
    "Animated transitions": "Transisi beranimasi",
    "Are you sure you want to clone this map and all its datalayers?": "Adakah anda ingin klon peta ini serta semua lapisan datanya?",
    "Are you sure you want to delete this map?": "Adakah anda ingin memadamkan peta ini?",
    "Are you sure you want to delete this property on all the features?": "Adakah anda ingin memadamkan ciri-ciri ini di kesemua sifat-sifat?",
    "Are you sure you want to restore this version?": "Adakah anda ingin memulihkan versi ini?",
    "Attach the map to my account": "Lampirkan peta ke akaun saya",
    "attribution": "atribusi",
    "Auto": "Auto",
    "Automatic": "Automatik",
    "Autostart when map is loaded": "Automula apabila peta dimuatkan",
    "Back to preview": "Kembali ke pralihat",
    "Background overlay url": "URL tindihan atas latar belakang",
    "Ball": "Bola",
    "Bring feature to center": "Bawa sifat ke tengah",
    "Browse data": "Layari data",
    "by": "oleh",
    "Cache proxied request": "Cache permintaan diproksi",
    "Caption": "Keterangan",
    "Center map on your location": "Ketengahkan peta ke kedudukan anda",
    "Change tilelayers": "Tukar lapisan jubin",
    "Change": "Tukar",
    "Choose the data format": "Pilih format data",
    "Choropleth breakpoints": "Titik putus koroplet",
    "Choropleth classes": "Kelas koroplet",
    "Choropleth color palette": "Palet warna koroplet",
    "Choropleth mode": "Mod koroplet",
    "Choropleth property value": "Nilai ciri koroplet",
    "Choropleth": "Koroplet",
    "Circle": "Bulatan",
    "clear": "kosongkan",
    "Click last point to finish shape": "Klik titik akhir untuk lengkapkan bentuk",
    "Click to add a marker": "Klik untuk tambahkan penanda",
    "Click to continue drawing": "Klik untuk terus melukis",
    "Click to edit": "Klik untuk menyunting",
    "Click to start drawing a line": "Klik untuk mula melukis garisan",
    "Click to start drawing a polygon": "Klik untuk mula melukis poligon",
    "Clone of {name}": "Klon {name}",
    "Clone this feature": "Klon sifat ini",
    "Clone this map": "Klon peta ini",
    "Clone": "Klon",
    "Close": "Tutup",
    "Clustered": "Berkelompok",
    "Clustering radius": "Jejari kelompok",
    "collapsed": "dijatuhkan",
    "color": "warna",
    "Comma separated list of numbers, including min and max values.": "Senarai nombor, dipisahkan dengan koma, termasuk nilai minimum dan maksimum.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Senarai ciri-ciri untuk digunakan bagi sifat isihan, dipisahkan dengan koma. Untuk mengundur isihan, letak tanda tolak (-) sebelumnya. Cth. kekuncisaya,-kekuncilain.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Nilai dipisahkan dengan koma, tab atau koma bertitik. SRS WGS84 diimplikasikan. Hanya geometri Titik diimport. Import akan lihat pada kepala lajur untuk sebarang sebutan «lat» dan «lon» di bahagian permulaan pengepala, tak peka besar huruf. Kesemua lajur lain diimport sebagai ciri-ciri.",
    "Congratulations, your map has been created!": "Tahniah, peta anda telah berjaya dicipta!",
    "Continue line": "Garis sambung",
    "Coordinates": "Koordinat",
    "copy": "salin",
    "Credits": "Penghargaan",
    "Current map view": "Paparan peta semasa",
    "Current view instead of default map view?": "Paparan semasa menggantikan paparan peta lalai?",
    "Custom background": "Latar belakang tersuai",
    "Custom overlay": "Tindihan atas tersuai",
    "dash array": "tatasusunan sengkang",
    "Data is browsable": "Data boleh layar",
    "Datalayers": "Lapisan data",
    "Default interaction options": "Pilihan interaksi lalai",
    "Default properties": "Ciri-ciri lalai",
    "Default shape properties": "Ciri-ciri bentuk lalai",
    "Default view": "Paparan lalai",
    "Default zoom level": "Tahap zum lalai",
    "Default": "Lalai",
    "Default: name": "Lalai: nama",
    "Define link to open in a new window on polygon click.": "Tetapkan pautan untuk buka dalam tetingkap baharu apabila poligon diklik",
    "define": "takrif",
    "Delay between two transitions when in play mode": "Lengah di antara dua transisi apabila dalam mod main",
    "Delete layer": "Padam lapisan",
    "Delete this feature": "Padam sifat ini",
    "Delete this shape": "Padam bentuk ini",
    "Delete this vertex (Alt+Click)": "Padam bucu ini (Alt+Klik)",
    "Delete": "Padam",
    "description": "keterangan",
    "Direct link": "Pautan terus",
    "Directions from here": "Arah dari sini",
    "Display label": "Label paparan",
    "Display measure": "Paparkan ukuran",
    "display name": "nama paparan",
    "Display on load": "Paparkan semasa dimuatkan",
    "Display the control to open OpenStreetMap editor": "Paparkan kawalan untuk buka penyunting OpenStreetMap",
    "Display the embed control": "Paparkan kawalan benaman",
    "Display the fullscreen control": "Paparkan kawalan skrin penuh",
    "Display the locate control": "Paparkan kawalan kesan kedudukan",
    "Display the measure control": "Paparkan kawalan pengukuran",
    "Display the search control": "Paparkan kawalan carian",
    "Display the tile layers control": "Paparkan kawalan lapisan jubin",
    "Display the zoom control": "Paparkan kawalan zum",
    "Do you want to display a caption bar?": "Adakah anda ingin paparkan bar keterangan?",
    "Do you want to display a minimap?": "Adakah anda ingin paparkan peta mini?",
    "Do you want to display a panel on load?": "Adakah anda ingin paparkan panel ketika dimuatkan?",
    "Do you want to display caption menus?": "Adakah anda ingin paparkan menu keterangan?",
    "Do you want to display popup footer?": "Adakah anda ingin paparkan pengaki timbul?",
    "Do you want to display the scale control?": "Adakah anda ingin paparkan kawalan skala?",
    "Do you want to display the «more» control?": "Adakah anda ingin paparkan kawalan «lebih lagi»?",
    "Download": "Muat turun",
    "Drag to reorder": "Seret untuk susun semula",
    "Draw a marker": "Lukis penanda",
    "Draw a polygon": "Lukis poligon",
    "Draw a polyline": "Lukis poligaris",
    "Drawing": "Lukisan",
    "Drop": "Jatuhkan",
    "Dynamic properties": "Ciri-ciri dinamik",
    "Dynamic": "Dinamik",
    "Edit feature's layer": "Sunting lapisan sifat",
    "Edit properties in a table": "Sunting ciri-ciri dalam jadual",
    "Edit the title of the map": "Sunting tajuk peta",
    "Edit this feature": "Sunting sifat ini",
    "Edit": "Sunting",
    "Embed and link options": "Pilihan benaman dan pautan",
    "Embed the map": "Benamkan peta",
    "Emoji & Character": "Emoji & Aksara",
    "Empty": "Kosongkan",
    "Equidistant": "Sama jarak",
    "Error in the overlay URL": "Ralat dalam URL tindihan atas",
    "Error in the tilelayer URL": "Ralat dalam URL lapisan jubin",
    "Exit Fullscreen": "Keluar Skrin Penuh",
    "expanded": "dikembangkan",
    "Extract shape to separate feature": "Sarikan bentuk untuk memisahkan sifat",
    "Feature identifier key": "Kekunci pengenalpastian sifat",
    "Feature properties": "Ciri-ciri sifat",
    "Fetch data each time map view changes.": "Ambil data setiap kali paparan peta berubah.",
    "fill color": "warna isian",
    "fill opacity": "kelegapan isian",
    "fill": "diisi",
    "Fit all data": "Sesuaikan semua data",
    "Format": "Format",
    "From zoom": "Dari zum",
    "full backup": "sandaran penuh",
    "Generic": "Generik",
    "GeoRSS (only link)": "GeoRSS (pautan sahaja)",
    "GeoRSS (title + image)": "GeoRSS (tajuk + imej)",
    "Go to \"{coords}\"": "Pergi ke \"{coords}\"",
    "Go to the homepage": "Pergi ke halaman utama",
    "Go to «{feature}»": "Pergi ke «{feature}»",
    "Heatmap intensity property": "Ciri-ciri keamatan peta tompokan",
    "Heatmap radius": "Jejari peta tompokan",
    "Heatmap": "Peta tompokan",
    "height": "tinggi",
    "Help": "Bantuan",
    "hidden": "disembunyikan",
    "Hide controls": "Sembunyikan kawalan",
    "Home": "Laman utama",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Berapa banyak untuk dipermudahkan bagi poligaris di setiap tahap zum (lebih banyak = lebih tinggi prestasi dan rupa lebih halus, lebih sedikit = lebih tepat)",
    "icon opacity": "kelegapan ikon",
    "Icon shape": "Bentuk ikon",
    "Icon symbol": "Simbol ikon",
    "If false, the polygon or line will act as a part of the underlying map.": "Jika tetapkan ke 'false', poligon atau garisan akan bertindak sebagai sebahagian daripada peta di bawah.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Import data",
    "Import in a new layer": "Import ke lapisan baharu",
    "Imports all umap data, including layers and settings.": "Import semua data umap, termasuk lapisan dan tetapan.",
    "Include full screen link?": "Sertakan pautan skrin penuh?",
    "Inherit": "Warisi",
    "inherit": "warisi",
    "Interaction options": "Pilihan interaksi",
    "Invalid latitude or longitude": "Latitud atau longitud tidak sah",
    "Invalid umap data in {filename}": "Data umap tidak sah dalam {filename}",
    "Invalid umap data": "Data umap tidak sah",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "Cara K",
    "Keep current visible layers": "Kekalkan lapisan yang kelihatan sekarang",
    "kilometers": "kilometer",
    "km": "km",
    "Label direction": "Arah label",
    "Label key": "Kekunci label",
    "Labels are clickable": "Label boleh diklik",
    "Latest feature": "Sifat terbaru",
    "Latitude": "Latitud",
    "Layer properties": "Ciri-ciri lapisan",
    "Layer": "Lapisan",
    "Licence": "Lesen",
    "licence": "lesen",
    "Limit bounds": "Had batas",
    "Link to view the map": "Pautan untuk melihat peta",
    "Link to…": "Pautkan ke…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Penghargaan penuh",
    "Longitude": "Longitud",
    "Make main shape": "Buatkan bentuk utama",
    "Manage layers": "Urus lapisan",
    "Manual": "Manual",
    "Map background credits": "Penghargaan latar belakang peta",
    "Map has been attached to your account": "Peta telah dilampirkan ke akaun anda",
    "Map has been saved!": "Peta telah disimpan!",
    "Map has been starred": "Peta telah ditandai bintang",
    "Map has been unstarred": "Peta telah dinyahtandai bintang",
    "Map user content has been published under licence": "Kandungan pengguna peta telah diterbitkan di bawah lesen",
    "Map's editors": "Penyunting peta",
    "Map's owner": "Pemilik peta",
    "max East": "Timur maksimum",
    "max North": "Utara maksimum",
    "max South": "Selatan maksimum",
    "max West": "Barat maksimum",
    "max zoom": "zum maksimum",
    "Measure distances": "Ukur jarak",
    "Merge lines": "Gabungkan garisan",
    "mi": "bt",
    "miles": "batu",
    "min zoom": "zum minimum",
    "More controls": "Lebih banyak kawalan",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Mestilah nilai CSS yang sah (cth.: DarkBlue atau #123456)",
    "name": "nama",
    "nautical miles": "batu nautika",
    "never": "tidak pernah",
    "new window": "tetingkap baharu",
    "next": "seterusnya",
    "NM": "NM",
    "No cache": "Tiada cache",
    "No licence has been set": "Tiada lesen ditetapkan",
    "No results": "Tiada hasil",
    "no": "tidak",
    "No.": "No.",
    "None": "Tiada",
    "Number of desired classes (default 5)": "Jumlah kelas yang diingini (lalainya 5)",
    "On the bottom": "Di bawah",
    "On the left": "Di kiri",
    "On the right": "Di kanan",
    "On the top": "Di atas",
    "Only visible layers' data": "Data lapisan yang kelihatan sahaja",
    "opacity": "kelegapan",
    "Opacity": "Kelegapan",
    "Open current feature on load": "Buka sifat semasa ketika dimuatkan",
    "Open link in…": "Buka pautan dalam…",
    "Open share & download panel": "Buka panel kongsi & muat turun",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Buka takat peta ini dalam penyunting peta untuk menyediakan data yang lebih tepat ke OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Ciri-ciri keamatan pilihan untuk peta tompokan",
    "Optional. Same as color if not set.": "Pilihan. Sama seperti warna jika tidak ditetapkan.",
    "Optional.": "Pilihan.",
    "Override clustering radius (default 80)": "Menggantikan jejari kelompok (nilai lalai 80)",
    "Override heatmap radius (default 25)": "Menggantikan jejari peta tompokan (nilai lalai 25)",
    "parent window": "tetingkap induk",
    "Paste your data here": "Tampalkan data anda di sini",
    "Permalink": "Pautan kekal",
    "Permanent credits background": "Latar penghargaan kekal",
    "Permanent credits": "Penghargaan kekal",
    "Please be sure the licence is compliant with your use.": "Sila pastikan lesen menurut kegunaan anda.",
    "Please choose a format": "Sila pilih format",
    "Please enter the name of the property": "Sila masukkan nama ciri-ciri",
    "Please enter the new name of this property": "Sila masukkan nama baharu bagi ciri-ciri ini",
    "Please save the map first": "Sila simpan peta terlebih dahulu",
    "Popup (large)": "Tetingkap timbul (besar)",
    "Popup content style": "Gaya kandungan tetingkap timbul",
    "Popup content template": "Templat kandungan tetingkap timbul",
    "Popup shape": "Bentuk tetingkap timbul",
    "Popup": "Tetingkap timbul",
    "Powered by uMap": "Dikuasakan oleh uMap",
    "previous": "sebelumnya",
    "Problem in the response": "Masalah dalam tindak balas",
    "Properties imported:": "Ciri-ciri diimport:",
    "Provide an URL here": "Sediakan URL di sini",
    "Proxy request": "Permintaan proksi",
    "Quantiles": "Kuantil",
    "Recent": "Terbaru",
    "Remote data": "Data jarak jauh",
    "Remove shape from the multi": "Buang bentuk daripada multi",
    "Replace layer content": "Gantikan kandungan lapisan",
    "Restore this version": "Pulihkan versi ini",
    "Save current edits": "Simpan suntingan semasa",
    "Save map": "Simpan peta",
    "Save": "Simpan",
    "Saved center and zoom": "Kedudukan tengah dan zum telah disimpan",
    "Search location": "Kedudukan carian",
    "Search": "Cari",
    "Secret edit link:": "Pautan suntingan rahsia:",
    "See full screen": "Lihat skrin penuh",
    "See on OpenStreetMap": "Lihat di OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Tetapkan ke 'false' untuk menyembunyikan lapisan ini daripada persembahan slaid, pelayar data, navigasi timbul…",
    "settings": "tetapan",
    "Shape properties": "Ciri-ciri bentuk",
    "Share and download": "Kongsi dan muat turun",
    "Share this link to open a customized map view": "Kongsi pautan ini untuk buka paparan peta tersuai",
    "Short credits": "Penghargaan pendek",
    "Short link": "Pautan pendek",
    "Show this layer in the caption": "Tunjuk lapisan ini dalam keterangan",
    "Show/hide layer": "Tunjuk/sembunyi lapisan",
    "Side panel": "Panel sisi",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Permudahkan",
    "Skipping unknown geometry.type: {type}": "Melangkau jenis geometri tidak diketahui: {type}",
    "Slideshow": "Persembahan slaid",
    "Sort key": "Kekunci isihan",
    "Split line": "Garisan pemisah",
    "Star this map": "Tandai bintang peta ini",
    "Start a hole here": "Mulakan lubang di sini",
    "Start slideshow": "Mulakan persembahan slaid",
    "Stop editing": "Berhenti menyunting",
    "Stop slideshow": "Berhenti persembahan slaid",
    "Street": "Jalan",
    "stroke": "lejang",
    "Supported scheme": "Skema disokong",
    "Supported variables that will be dynamically replaced": "Pemboleh ubah disokong yang akan digantikan secara dinamik",
    "Symbol": "Simbol",
    "Table": "Meja",
    "Text color for the cluster label": "Warna tulisan label kelompok",
    "Text formatting": "Format tulisan",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "Nama bagi ciri untuk digunakan sebagai label sifat (cth.: \"nom\"). Anda juga boleh gunakan ciri-ciri dalam kurungan dakap untuk guna lebih daripada satu ciri atau untuk gabung dengan kandungan statik (cth.: \"&lcub;name&rcub; di &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "Nama ciri-ciri untuk digunakan sebagai pengenalpastian unik sifat.",
    "The zoom and center have been modified.": "Zum dan kedudukan tengah telah diubah suai.",
    "TMS format": "Format TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Untuk digunakan jika pelayan jarak jauh tidak benarkan rentang domain (lebih perlahan)",
    "To zoom": "Untuk zum",
    "Toggle edit mode (⇧+Click)": "Togol mod suntingan (⇧+Klik)",
    "Toggle edit mode": "Togol mod suntingan",
    "Transfer shape to edited feature": "Pindah bentuk ke sifat yang disunting",
    "Transform to lines": "Jelmakan menjadi garisan",
    "Transform to polygon": "Jelmakan menjadi poligon",
    "Type a place name or coordinates": "Taip koordinat atau nama tempat",
    "Type char or paste emoji": "Taip aksara atau tampal emoji",
    "Type of layer": "Jenis lapisan",
    "Unable to detect format of file {filename}": "Tidak mampu mengesan format fail {filename}",
    "Untitled layer": "Lapisan tanpa tajuk",
    "Untitled map": "Peta tanpa tajuk",
    "Update permissions and editors": "Kemas kini kebenaran dan penyunting",
    "Update permissions": "Kemas kini kebenaran",
    "Update who can see and edit the map": "Kemas kini siapa boleh lihat dan sunting peta",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Guna batas semasa",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Guna pemegang tempat dengan ciri-ciri sifat di antara tanda kurung dakap, spt. &#123;name&#125;, mereka akan digantikan dengan nilai yang berkenaan secara dinamiknya.",
    "User content credits": "Penghargaan kandungan pengguna",
    "User interface options": "Pilihan antara muka pengguna",
    "User location": "Kedudukan pengguna",
    "Verify remote URL": "Sahkan URL jarak jauh",
    "Versions": "Versi",
    "View Fullscreen": "Lihat Skrin Penuh",
    "View": "Lihat",
    "Visibility: {status}": "Kebolehlihatan: {status}",
    "weight": "tebal",
    "Where do we go from here?": "Ke mana kita pergi dari sini?",
    "Whether to display or not polygons paths.": "Sama ada ingin paparkan laluan poligon ataupun tidak.",
    "Whether to fill polygons with color.": "Sama ada ingin isikan poligon dengan warna.",
    "Who can edit \"{layer}\"": "Siapa boleh sunting \"{layer}\"",
    "Who can edit": "Siapa boleh sunting",
    "Who can view": "Siapa boleh lihat",
    "width": "lebar",
    "Will be displayed in the bottom right corner of the map": "Akan dipaparkan di bucu kanan bawah peta",
    "Will be permanently visible in the bottom left corner of the map": "Akan dipaparkan secara kekal di bucu kiri bawah peta",
    "Will be visible in the caption of the map": "Akan kelihatan dalam keterangan peta",
    "yes": "ya",
    "Zoom in": "Zum masuk",
    "Zoom level for automatic zooms": "Tahap zum bagi zum automatik",
    "Zoom out": "Zum keluar",
    "Zoom to layer extent": "Zum ke batas lapisan",
    "Zoom to the next": "Zum ke seterusnya",
    "Zoom to the previous": "Zum ke sebelumnya",
    "Zoom to this feature": "Zum ke sifat ini",
    "{area}&#8239;acres": "{area} ekar",
    "{area}&#8239;ha": "{area} hektar",
    "{area}&#8239;m&sup2;": "{area} meter&sup2;",
    "{area}&#8239;mi&sup2;": "{area} batu&sup2;",
    "{area}&#8239;yd&sup2;": "{area} ela&sup2;",
    "{count} errors during import: {message}": "{count} ralat ketika import: {message}",
    "{delay} seconds": "{delay} saat",
    "{distance}&#8239;km": "{distance} kilometer",
    "{distance}&#8239;m": "{distance} meter",
    "{distance}&#8239;miles": "{distance} batu",
    "{distance}&#8239;NM": "{distance} batu nautika",
    "{distance}&#8239;yd": "{distance} ela",
    "Edit map name and caption": "Sunting nama dan kererangan peta",
    "Map advanced properties": "Ciri-ciri lanjutan peta",
    "Edit map details": "Sunting maklumat peta",
    "Back to browser": "Kembali ke pelayar",
    "Toggle size": "Togol saiz",
    "Display the caption control": "Paparkan kawalan keterangan",
    "<empty value>": "<nilai kosong>",
    "Min": "Minimum",
    "Max": "Maksimum",
    "From": "Mulai",
    "Until": "Sehingga",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Contoh: kekunci1,kekunci2|Label 2,kekunci3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Sunting di OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Tidak dapat menentukan lajur latitud dan longitud.",
    "Back to layers": "Kembali ke lapisan",
    "Filters": "Tapisan",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Display the back to home icon",
    "Do you want to display layer switcher in caption bar?": "Do you want to display layer switcher in caption bar?",
    "Simplify all geometries to points": "Simplify all geometries to points",
    "Back to list": "Back to list",
    "Toggle rule": "Toggle rule",
    "Delete rule": "Delete rule",
    "Cannot save layer, please try again in a few minutes.": "Cannot save layer, please try again in a few minutes."
}
L.registerLocale("ms", locale)
L.setLocale("ms")
