{% extends "umap/content.html" %}

{% load i18n %}

{% block head_title %}
  {% translate "Password change successful" %} - {{ SITE_DESCRIPTION }}
{% endblock head_title %}

{% block content %}
  <h2 class="section">
    {% trans "Password change successful" %}
  </h2>
  <p>
    {% trans "Your password was changed." %}
  </p>
  <p>
    <a href="{% url 'home' %}">Home</a>
  </p>
{% endblock content %}
