const locale = {
    "(area: {measure})": "(area: {measure})",
    "(length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# üks trell põhipealkirja jaoks",
    "## two hashes for second heading": "## kaks trelli teise pealkirja jaoks",
    "### three hashes for third heading": "### kolm trelli kolmanda pealkirja jaoks",
    "**double star for bold**": "**kaks tärni paksu kirja jaoks**",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 päev",
    "1 hour": "1 tund",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Komaga eraldatud numbriloend, mis määrab katkendjoone mustri, nt \"5, 10, 15\".",
    "About": "Teave",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "Aktiveeri slaidiesitluse režiim",
    "Add a layer": "Lisa kiht",
    "Add a line to the current multi": "Add a line to the current multi",
    "Add a new property": "Lisa uus omadus",
    "Add a polygon to the current multi": "Add a polygon to the current multi",
    "Add image URL": "Add image URL",
    "Advanced actions": "Täiendavad tegevused",
    "Advanced properties": "Täiendavad omadused",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "Kõik omadused imporditi.",
    "Allow interactions": "Luba interaktsioonid",
    "Allow scroll wheel zoom?": "Luba hiirerullikuga suurendamine?",
    "always": "alati",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to clone this map and all its datalayers?": "Oled sa kindel, et soovid kopeerida seda kaarti ja kõiki selle andmekihte?",
    "Are you sure you want to delete this map?": "Oled sa kindel, et soovid seda kaarti kustutada?",
    "Are you sure you want to delete this property on all the features?": "Oled sa kindel, et soovid kõigi elementide juurest selle omaduse kustutada?",
    "Are you sure you want to restore this version?": "Oled sa kindel, et soovid taastada selle versiooni?",
    "Attach the map to my account": "Manusta kaart minu kontole",
    "attribution": "attribution",
    "Auto": "Auto",
    "Automatic": "Automaatne",
    "Autostart when map is loaded": "Automaatne käivitus kaardi laadimisel",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "Nööpnõel",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "Andmete sirvimine",
    "by": "autorilt",
    "Cache proxied request": "Cache proxied request",
    "Caption": "Legend",
    "Center map on your location": "Sea oma asukoht keskpunktiks",
    "Change tilelayers": "Vaheta kaardi taust",
    "Change": "Change",
    "Choose the data format": "Vali andmevorming",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "Ring",
    "clear": "tühjenda",
    "Click last point to finish shape": "Klõpsa kujundi lõpetamiseks viimasel punktil",
    "Click to add a marker": "Klõpsa markeri lisamiseks",
    "Click to continue drawing": "Klõpsa joonistamise jätkamiseks",
    "Click to edit": "Klõpsa muutmiseks",
    "Click to start drawing a line": "Klõpsa joone alustamiseks",
    "Click to start drawing a polygon": "Klõpsa hulknurga alustamiseks",
    "Clone of {name}": "{name} koopia",
    "Clone this feature": "Kopeeri seda elementi",
    "Clone this map": "Kopeeri seda kaarti",
    "Clone": "Kopeeri",
    "Close": "Sulge",
    "Clustered": "Klasterdatud",
    "Clustering radius": "Clustering radius",
    "collapsed": "ahendatud",
    "color": "Värv",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line": "Jätka joont",
    "Coordinates": "Koordinaadid",
    "copy": "copy",
    "Credits": "Õigused",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "Praegune vaade vaikimisi vaate asemel?",
    "Custom background": "Kohandatud taust",
    "Custom overlay": "Custom overlay",
    "dash array": "katkendjoon",
    "Data is browsable": "Andmed on sirvitavad",
    "Datalayers": "Datalayers",
    "Default interaction options": "Interaktsiooni vaikesuvandid",
    "Default properties": "Vaikeomadused",
    "Default shape properties": "Kujundi vaikeomadused",
    "Default view": "Default view",
    "Default zoom level": "Vaikimisi suurendusaste",
    "Default": "Vaikesäte",
    "Default: name": "Vaikimisi: name",
    "Define link to open in a new window on polygon click.": "Define link to open in a new window on polygon click.",
    "define": "määra",
    "Delay between two transitions when in play mode": "Delay between two transitions when in play mode",
    "Delete layer": "Kustuta kiht",
    "Delete this feature": "Kustuta see element",
    "Delete this shape": "Kustuta see kujund",
    "Delete this vertex (Alt+Click)": "Kustuta see tipp (Alt+Klõps)",
    "Delete": "Kustuta",
    "description": "kirjeldus",
    "Direct link": "Direct link",
    "Directions from here": "Juhised siit",
    "Display label": "Kuva silt",
    "Display measure": "Kuva suurus",
    "display name": "display name",
    "Display on load": "Kuva laadimisel",
    "Display the control to open OpenStreetMap editor": "Kuva OpenStreetMap'i redaktori avamise nupp",
    "Display the embed control": "Kuva jagamise nupp",
    "Display the fullscreen control": "Kuva täisekraani nupp",
    "Display the locate control": "Kuva asukoha määramise nupp",
    "Display the measure control": "Kuva mõõtmise nupp",
    "Display the search control": "Kuva otsingunupp",
    "Display the tile layers control": "Kuva tausta vahetamise nupp",
    "Display the zoom control": "Kuva suurendamise nupp",
    "Do you want to display a caption bar?": "Kas soovid kuvada tiitelriba?",
    "Do you want to display a minimap?": "Kas soovid kuvada minikaarti?",
    "Do you want to display a panel on load?": "Kas soovid kuvada külgpaneeli laadimisel?",
    "Do you want to display caption menus?": "Do you want to display caption menus?",
    "Do you want to display popup footer?": "Kas soovid kuvada hüpikjalust?",
    "Do you want to display the scale control?": "Kas soovid kuvada mõõtkava?",
    "Do you want to display the «more» control?": "Kas soovid kuvada nuppu «rohkem»?",
    "Download": "Laadi alla",
    "Drag to reorder": "Lohista ümberreastamiseks",
    "Draw a marker": "Lisa marker",
    "Draw a polygon": "Joonista hulknurk",
    "Draw a polyline": "Draw a polyline",
    "Drawing": "Drawing",
    "Drop": "Tilk",
    "Dynamic properties": "Dünaamilised omadused",
    "Dynamic": "Dünaamiline",
    "Edit feature's layer": "Muuda elemendi kihti",
    "Edit properties in a table": "Muuda omadusi tabelis",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "Muuda seda elementi",
    "Edit": "Muuda",
    "Embed and link options": "Embed and link options",
    "Embed the map": "Manusta kaart",
    "Emoji & Character": "Emoji & Character",
    "Empty": "Tühjenda",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "Vigane tausta URL",
    "Exit Fullscreen": "Välju täisekraanist",
    "expanded": "laiendatud",
    "Extract shape to separate feature": "Ekstrakti kujund eraldi elemendiks",
    "Feature identifier key": "Feature identifier key",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "Fetch data each time map view changes.",
    "fill color": "täitevärv",
    "fill opacity": "täite läbipaistvus",
    "fill": "täide",
    "Fit all data": "Fit all data",
    "Format": "Vorming",
    "From zoom": "Suurendusastmest",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (ainult link)",
    "GeoRSS (title + image)": "GeoRSS (pealkiri + pilt)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "Mine «{feature}» juurde",
    "Heatmap intensity property": "Heatmap intensity property",
    "Heatmap radius": "Soojuskaardi raadius",
    "Heatmap": "Soojuskaart",
    "height": "kõrgus",
    "Help": "Abi",
    "hidden": "peidetud",
    "Hide controls": "Peida juhtnupud",
    "Home": "Avaleht",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)",
    "icon opacity": "icon opacity",
    "Icon shape": "Ikooni kuju",
    "Icon symbol": "Ikooni sümbol",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Image with custom width (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Impordi andmed",
    "Import in a new layer": "Impordi uuele kihile",
    "Imports all umap data, including layers and settings.": "Impordib kõik uMapi andmed, k.a kihid ja seaded.",
    "Include full screen link?": "Lisa täisekraani link?",
    "Inherit": "Päri",
    "inherit": "päri",
    "Interaction options": "Interaktsiooni suvandid",
    "Invalid latitude or longitude": "Invalid latitude or longitude",
    "Invalid umap data in {filename}": "Vigased uMapi andmed failis {filename}",
    "Invalid umap data": "Vigased uMapi andmed",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Keep current visible layers",
    "kilometers": "kilomeetrid",
    "km": "km",
    "Label direction": "Sildi suund",
    "Label key": "Sildi võti",
    "Labels are clickable": "Silte saab klõpsata",
    "Latest feature": "Latest feature",
    "Latitude": "Laius",
    "Layer properties": "Kihi omadused",
    "Layer": "Kiht",
    "Licence": "Litsents",
    "licence": "litsents",
    "Limit bounds": "Määra piirid",
    "Link to view the map": "Link to view the map",
    "Link to…": "Lingi…",
    "Link with text: [[https://example.com|text of the link]]": "Link with text: [[https://example.com|text of the link]]",
    "Long credits": "Long credits",
    "Longitude": "Pikkus",
    "Make main shape": "Muuda peamiseks kujundiks",
    "Manage layers": "Halda kihte",
    "Manual": "Manual",
    "Map background credits": "Kaardi tausta õigused",
    "Map has been attached to your account": "Kaart on lisatud kontole",
    "Map has been saved!": "Kaart on salvestatud!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "Map user content has been published under licence",
    "Map's editors": "Kaardi toimetajad",
    "Map's owner": "Kaardi omanik",
    "max East": "max East",
    "max North": "max North",
    "max South": "max South",
    "max West": "max West",
    "max zoom": "suurim suurendusaste",
    "Measure distances": "Vahemaade mõõtmine",
    "Merge lines": "Ühenda jooned",
    "mi": "mi",
    "miles": "miilid",
    "min zoom": "vähim suurendusaste",
    "More controls": "Rohkem juhtnuppe",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Peab olema kehtiv CSS väärtus (nt DarkBlue või #123456)",
    "name": "nimi",
    "nautical miles": "meremiilid",
    "never": "mitte kunagi",
    "new window": "uus aken",
    "next": "edasi",
    "NM": "NM",
    "No cache": "No cache",
    "No licence has been set": "Litsentsi pole määratud",
    "No results": "Tulemused puuduvad",
    "no": "ei",
    "No.": "No.",
    "None": "Mitte midagi",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "All",
    "On the left": "Vasakul",
    "On the right": "Paremal",
    "On the top": "Ülal",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "läbipaistvus",
    "Opacity": "Opacity",
    "Open current feature on load": "Open current feature on load",
    "Open link in…": "Ava link...",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open this map extent in a map editor to provide more accurate data to OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optional intensity property for heatmap",
    "Optional. Same as color if not set.": "Valikuline. Sama mis värv, kui pole määratud teisiti",
    "Optional.": "Valikuline.",
    "Override clustering radius (default 80)": "Override clustering radius (default 80)",
    "Override heatmap radius (default 25)": "Override heatmap radius (default 25)",
    "parent window": "emaaken",
    "Paste your data here": "Kleebi oma andmed siia",
    "Permalink": "Püsilink",
    "Permanent credits background": "Permanent credits background",
    "Permanent credits": "Permanent credits",
    "Please be sure the licence is compliant with your use.": "Please be sure the licence is compliant with your use.",
    "Please choose a format": "Vali palun vorming",
    "Please enter the name of the property": "Sisesta palun omaduse nimi",
    "Please enter the new name of this property": "Sisesta palun selle omaduse uus nimi",
    "Please save the map first": "Salvesta palun enne kaart",
    "Popup (large)": "Hüpik (suur)",
    "Popup content style": "Hüpiku sisu stiil",
    "Popup content template": "Hüpiku mall",
    "Popup shape": "Hüpiku kuju",
    "Popup": "Hüpik",
    "Powered by uMap": "Powered by uMap",
    "previous": "tagasi",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "Imporditud omadused:",
    "Provide an URL here": "Lisage siia URL",
    "Proxy request": "Proxy request",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "Kaugandmed",
    "Remove shape from the multi": "Remove shape from the multi",
    "Replace layer content": "Asenda kihi sisu",
    "Restore this version": "Taasta see versioon",
    "Save current edits": "Salvesta praegused muudatused",
    "Save map": "Save map",
    "Save": "Salvesta",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "Asukoha otsing",
    "Search": "Search",
    "Secret edit link:": "Secret edit link:",
    "See full screen": "Täisekraanvaade",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…",
    "settings": "settings",
    "Shape properties": "Kujundi omadused",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "Short credits",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "Näita/peida kiht",
    "Side panel": "Külgpaneel",
    "Simple link: [[https://example.com]]": "Simple link: [[https://example.com]]",
    "Simplify": "Lihtsustamine",
    "Skipping unknown geometry.type: {type}": "Skipping unknown geometry.type: {type}",
    "Slideshow": "Slaidiprogramm",
    "Sort key": "Sorteerimise võti",
    "Split line": "Split line",
    "Star this map": "Star this map",
    "Start a hole here": "Start a hole here",
    "Start slideshow": "Alusta slaidiprogrammi",
    "Stop editing": "Lõpeta muutmine",
    "Stop slideshow": "Lõpeta slaidiprogramm",
    "Street": "Street",
    "stroke": "piirjoon",
    "Supported scheme": "Supported scheme",
    "Supported variables that will be dynamically replaced": "Supported variables that will be dynamically replaced",
    "Symbol": "Symbol",
    "Table": "Tabel",
    "Text color for the cluster label": "Text color for the cluster label",
    "Text formatting": "Tekstivorming",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "The name of the property to use as feature unique identifier.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "TMS vorming",
    "To use if remote server doesn't allow cross domain (slower)": "To use if remote server doesn't allow cross domain (slower)",
    "To zoom": "Suurendusastmeni",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "Transfer shape to edited feature",
    "Transform to lines": "Muuda joonteks",
    "Transform to polygon": "Muuda hulknurgaks",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "Kihitüüp",
    "Unable to detect format of file {filename}": "{filename} failivormingu tuvastamine ebaõnnestus",
    "Untitled layer": "Nimeta kiht",
    "Untitled map": "Nimeta kaart",
    "Update permissions and editors": "Update permissions and editors",
    "Update permissions": "Update permissions",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Kasuta praegust vaadet",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.",
    "User content credits": "Kasutaja sisu õigused",
    "User interface options": "Kasutajaliidese suvandid",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "Versioonid",
    "View Fullscreen": "Täisekraanivaade",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "jämedus",
    "Where do we go from here?": "Kuhu läheb siit edasi?",
    "Whether to display or not polygons paths.": "Hulknurga piirjoonte näitamine.",
    "Whether to fill polygons with color.": "Hulknurkade täitmine värviga.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "Muutmisõigus",
    "Who can view": "Vaatamisõigus",
    "width": "laius",
    "Will be displayed in the bottom right corner of the map": "Kuvatakse kaardi alumises paremas nurgas",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Nähtav kaardi legendil",
    "yes": "jah",
    "Zoom in": "Suurenda",
    "Zoom level for automatic zooms": "Suurendusaste automaatse suurenduse korral",
    "Zoom out": "Vähenda",
    "Zoom to layer extent": "Suurenda kihi ulatuseni",
    "Zoom to the next": "Järgmine",
    "Zoom to the previous": "Eelmine",
    "Zoom to this feature": "Zoom to this feature",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} errors during import: {message}",
    "{delay} seconds": "{delay} sekundit",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Display the caption control": "Display the caption control",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns.",
    "Back to layers": "Back to layers",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Comma separated list of properties to use when filtering features by text input",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "Search keys": "Search keys",
    "Filters keys": "Filters keys",
    "Filter data": "Filter data",
    "Search map features…": "Search map features…",
    "Reset all": "Reset all",
    "Open browser": "Open browser",
    "Open caption": "Open caption",
    "Your map has been created with an anonymous account!": "Your map has been created with an anonymous account!",
    "Real-time collaboration": "Real-time collaboration",
    "Cannot parse data": "Cannot parse data",
    "Start typing...": "Start typing...",
    "No result": "No result",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.",
    "Overpass supported expressions": "Overpass supported expressions",
    "key (eg. building)": "key (eg. building)",
    "!key (eg. !name)": "!key (eg. !name)",
    "key=value (eg. building=yes)": "key=value (eg. building=yes)",
    "key!=value (eg. building!=yes)": "key!=value (eg. building!=yes)",
    "key~value (eg. name~Grisy)": "key~value (eg. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "key=\"value|value2\" (eg. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "More info about Overpass syntax",
    "For more complex needs, see": "For more complex needs, see",
    "Choose data": "Choose data",
    "Choose the format": "Choose the format",
    "Choose the layer": "Choose the layer",
    "Layer name": "Layer name",
    "Choose import mode": "Choose import mode",
    "Copy into the layer": "Copy into the layer",
    "Link to the layer as remote data": "Link to the layer as remote data",
    "Condition": "Condition",
    "key=value or key!=value": "key=value or key!=value",
    "Are you sure you want to delete this rule?": "Are you sure you want to delete this rule?",
    "empty rule": "empty rule",
    "Conditional style rules": "Conditional style rules",
    "Add rule": "Add rule",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: layers",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Enable real-time collaboration",
    "✅ Copied!": "✅ Copied!",
    "Choose a dataset": "Choose a dataset",
    "Choose this dataset": "Choose this dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematic data from OpenStreetMap",
    "Choose a theme": "Choose a theme",
    "Choose this data": "Choose this data",
    "Search admin boundary": "Search admin boundary",
    "Please choose a theme and a boundary first.": "Please choose a theme and a boundary first.",
    "Expression": "Expression",
    "Geometry mode": "Geometry mode",
    "Only geometry centers": "Only geometry centers",
    "Search area": "Search area",
    "Type area name, or let empty to load data in current map view": "Type area name, or let empty to load data in current map view",
    "Data successfully imported!": "Data successfully imported!",
    "Clear data": "Clear data",
    "Remove layers": "Remove layers",
    "Categorized": "Categorized",
    "Alphabetical": "Alphabetical",
    "Category property": "Category property",
    "Color palette": "Color palette",
    "Categories": "Categories",
    "Comma separated list of categories.": "Comma separated list of categories.",
    "Categories mode": "Categories mode",
    "Remove filter for this column": "Remove filter for this column",
    "Add filter for this column": "Add filter for this column",
    "Rename this column": "Rename this column",
    "Delete this column": "Delete this column",
    "Name “{name}” should not contain a dot.": "Name “{name}” should not contain a dot.",
    "This name already exists: “{name}”": "This name already exists: “{name}”",
    "Delete selected rows": "Delete selected rows",
    "Found {count} rows. Are you sure you want to delete all?": "Found {count} rows. Are you sure you want to delete all?",
    "Expression is empty": "Expression is empty",
    "OK": "OK",
    "Cancel": "Cancel",
    "Attach map to a team": "Attach map to a team",
    "Display the polygon inverted": "Display the polygon inverted",
    "Proportional circles": "Proportional circles",
    "Property name to compute circles": "Property name to compute circles",
    "Min circle radius": "Min circle radius",
    "Max circle radius": "Max circle radius",
    "Display the open browser control": "Display the open browser control",
    "Copy as GeoJSON": "Copy as GeoJSON",
    "Please zoom in to edit the geometry": "Please zoom in to edit the geometry",
    "New map": "New map",
    "My maps": "My maps",
    "My teams": "My teams",
    "My profile": "My profile",
    "Type new owner's username": "Type new owner's username",
    "Type editor's username": "Type editor's username",
    "Map": "Map",
    "Manage collaborators": "Manage collaborators",
    "show/hide all layers": "show/hide all layers",
    "zoom to data extent": "zoom to data extent",
    "download visible data": "download visible data",
    "Import helpers": "Import helpers",
    "Import helpers will fill the URL field for you.": "Import helpers will fill the URL field for you.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Save draft",
    "No data has been found for import": "No data has been found for import",
    "Successfully imported {count} feature(s)": "Successfully imported {count} feature(s)",
    "Disconnected": "Disconnected",
    "You must be logged in": "You must be logged in",
    "on hover": "on hover",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Cannot load remote data for layer \"{layer}\" with url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"",
    "Import failed: invalid data": "Import failed: invalid data",
    "Anonymous": "Anonymous",
    "created at {date}": "created at {date}",
    "modified at {date}": "modified at {date}",
    "Default zoom": "Default zoom",
    "Default latitude": "Default latitude",
    "Default longitude": "Default longitude",
    "Edit map default view": "Edit map default view",
    "Use current center and zoom": "Use current center and zoom",
    "Layer permalink": "Layer permalink",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Display the back to home icon",
    "Do you want to display layer switcher in caption bar?": "Do you want to display layer switcher in caption bar?",
    "Simplify all geometries to points": "Simplify all geometries to points",
    "Back to list": "Back to list",
    "Toggle rule": "Toggle rule",
    "Delete rule": "Delete rule",
    "Cannot save layer, please try again in a few minutes.": "Cannot save layer, please try again in a few minutes."
}
L.registerLocale("et", locale)
L.setLocale("et")
