{% load umap_tags static %}

{% include "umap/messages.html" %}
<div id="map">
</div>
<!-- djlint:off -->
<script id="map-settings" data-settings="{{ map_settings|escape }}"></script>
<script defer type="module">
    {% autoescape off %}
    import Umap from '{% static "umap/js/modules/umap.js" %}'
    {% endautoescape %}
    U.SETTINGS = JSON.parse(document.getElementById('map-settings').dataset.settings)
    U.MAP = new Umap("map", U.SETTINGS)
</script>
<!-- djlint:on -->
