const locale = {
    "(area: {measure})": "(área: {measure})",
    "(length: {measure})": "(lonxitude: {measure})",
    "# one hash for main heading": "# un cancelo para a cabeceira principal",
    "## two hashes for second heading": "## dous cancelos para a cabeceira secundaria",
    "### three hashes for third heading": "### tres cancelos para a cabeceira terciaria",
    "**double star for bold**": "**dous asteriscos para pór letra grosa**",
    "*single star for italic*": "*un único asterisco para pór letra itálica*",
    "--- for a horizontal rule": "--- para pór unha liña horizontal",
    "1 day": "1 día",
    "1 hour": "1 hora",
    "5 min": "5 min",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Unha listaxe separada por comas que define o patrón de trazos de guión. ex.: «5, 10, 15».",
    "About": "Sobre",
    "Action not allowed :(": "Acción non permitida :(",
    "Activate slideshow mode": "Activar o modo diaporama",
    "Add a layer": "Engadir unha capa",
    "Add a line to the current multi": "Engadir unha liña para o multielemento actual",
    "Add a new property": "Engadir unha nova propiedade",
    "Add a polygon to the current multi": "Engadir un polígono para o multielemento actual",
    "Add image URL": "Engadir o URL da imaxe",
    "Advanced actions": "Accións avanzadas",
    "Advanced properties": "Propiedades avanzadas",
    "All data and settings of the map": "Todos os datos e axustes do mapa",
    "All properties are imported.": "Todas as propiedades son importadas.",
    "Allow interactions": "Permitir interaccións",
    "Allow scroll wheel zoom?": "Permitir o zoom coa roda do rato?",
    "always": "sempre",
    "Animated transitions": "Transicións animadas",
    "Are you sure you want to clone this map and all its datalayers?": "Confirmas que queres clonar este mapa e todas as súas capas de datos?",
    "Are you sure you want to delete this map?": "Confirmas que queres eliminar este mapa?",
    "Are you sure you want to delete this property on all the features?": "Confirmas que queres eliminar esta propiedade en todos os elementos?",
    "Are you sure you want to restore this version?": "Confirmas que queres restabelecer esta versión?",
    "Attach the map to my account": "Incorporar o mapa á miña conta",
    "attribution": "atribución",
    "Auto": "Automático",
    "Automatic": "Automático",
    "Autostart when map is loaded": "Iniciar automaticamente cando o mapa estea cargado",
    "Back to preview": "Volver á vista previa",
    "Background overlay url": "URL de superposición de fondo",
    "Ball": "Bóla",
    "Bring feature to center": "Levar o elemento ao centro",
    "Browse data": "Navegar polos datos",
    "by": "por",
    "Cache proxied request": "Solicitude de proxy da memoria tobo",
    "Caption": "Lenda",
    "Center map on your location": "Centrar o mapa na túa posición",
    "Change tilelayers": "Cambiar as capas de teselas",
    "Change": "Cambiar",
    "Choose the data format": "Escoller o formato de datos",
    "Choropleth breakpoints": "Puntos de ruptura de coropletas",
    "Choropleth classes": "Clases de coropletas",
    "Choropleth color palette": "Paleta de cores de coropletas",
    "Choropleth mode": "Modo de coropletas",
    "Choropleth property value": "Valor da propiedade da coropleta",
    "Choropleth": "Cloropetas",
    "Circle": "Círculo",
    "clear": "limpar",
    "Click last point to finish shape": "Preme no derradeiro punto para rematar a forma",
    "Click to add a marker": "Preme para engadir un marcador",
    "Click to continue drawing": "Preme para seguir debuxando",
    "Click to edit": "Preme para editar",
    "Click to start drawing a line": "Preme para comezar a debuxar unha liña",
    "Click to start drawing a polygon": "Preme para comezar a debuxar un polígono",
    "Clone of {name}": "Clonado de {name}",
    "Clone this feature": "Clonar este elemento",
    "Clone this map": "Clonar este mapa",
    "Clone": "Clonar",
    "Close": "Pechar",
    "Clustered": "Agrupados",
    "Clustering radius": "Raio de agrupamento",
    "collapsed": "contraído",
    "color": "cor",
    "Comma separated list of numbers, including min and max values.": "Lista de números separados por comas, incluídos os valores mínimo e máximo.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Lista de propiedades separadas por comas a empregar para ordenar elementos. Para inverter a ordenación, pon un signo menos (-) antes. ex.: amiñaclave,-outraclave.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Valores separados por comas, tabulacións ou puntos e coma. SRS WGS84 está implícito. Só se importan xeometrías de puntos. A importación buscará nas cabeceiras das columnas calquera mención de «lat» e «lon» ao comezo da cabeceira, sen distinción entre maiúsculas e minúsculas. Todas as demais columnas impórtanse como propiedades.",
    "Congratulations, your map has been created!": "Parabéns! O teu mapa foi creado!",
    "Continue line": "Liña continua",
    "Coordinates": "Coordenadas",
    "copy": "copia",
    "Credits": "Recoñecementos",
    "Current map view": "Vista do mapa actual",
    "Current view instead of default map view?": "Vista actual en troques da vista predeterminada?",
    "Custom background": "Fondo personalizado",
    "Custom overlay": "Superposición personalizada",
    "dash array": "matriz de guións",
    "Data is browsable": "Os datos son navegábeis",
    "Datalayers": "Capas de datos",
    "Default interaction options": "Opcións de interacción predeterminadas",
    "Default properties": "Propiedades predeterminadas",
    "Default shape properties": "Propiedades de forma predeterminadas",
    "Default view": "Vista predeterminada",
    "Default zoom level": "Nivel de zoom predeterminado",
    "Default": "Predeterminado",
    "Default: name": "Predeterminado: nome",
    "Define link to open in a new window on polygon click.": "Defina unha ligazón para abrir nunha nova xanela ao premer no polígono.",
    "define": "definir",
    "Delay between two transitions when in play mode": "Atraso entre dúas transicións cando está en modo de reprodución",
    "Delete layer": "Eliminar capa",
    "Delete this feature": "Eliminar este elemento",
    "Delete this shape": "Eliminar esta forma",
    "Delete this vertex (Alt+Click)": "Eliminar este vértice (Alt+Premer)",
    "Delete": "Eliminar",
    "description": "descrición",
    "Direct link": "Ligazón directa",
    "Directions from here": "Direccións desde aquí",
    "Display label": "Amosar a etiqueta",
    "Display measure": "Amosar a medida",
    "display name": "amosar o nome",
    "Display on load": "Amosar ao cargar",
    "Display the control to open OpenStreetMap editor": "Amosar o control para abrir o editor de OpenStreetMap",
    "Display the embed control": "Amosar o control de incrustado",
    "Display the fullscreen control": "Amosar o control de pantalla completa",
    "Display the locate control": "Amosar o control de posición",
    "Display the measure control": "Amosar o control de medida",
    "Display the search control": "Amosar o control de procura",
    "Display the tile layers control": "Amosar o control de capas de teselas",
    "Display the zoom control": "Amosar o control do zoom",
    "Do you want to display a caption bar?": "Queres amosar unha barra de lendas?",
    "Do you want to display a minimap?": "Queres amosar un minimapa?",
    "Do you want to display a panel on load?": "Queres amosar un panel ao cargar?",
    "Do you want to display caption menus?": "Queres amosar o menú de subtítulos?",
    "Do you want to display popup footer?": "Queres amosar a xanela emerxente no rodapé?",
    "Do you want to display the scale control?": "Queres amosar o control de escala?",
    "Do you want to display the «more» control?": "Queres amosar o control «máis»?",
    "Download": "Descargar",
    "Drag to reorder": "Arrastrar para reordenar",
    "Draw a marker": "Debuxar un marcador",
    "Draw a polygon": "Debuxa un polígono",
    "Draw a polyline": "Debuxa unha poliliña",
    "Drawing": "Debuxo",
    "Drop": "Gota",
    "Dynamic properties": "Propiedades dinámicas",
    "Dynamic": "Dinámico",
    "Edit feature's layer": "Editar a capa do elemento",
    "Edit properties in a table": "Editar as propiedades nunha táboa",
    "Edit the title of the map": "Editar o título do mapa",
    "Edit this feature": "Editar este elemento",
    "Edit": "Editar",
    "Embed and link options": "Opcións de incrustación e ligazón",
    "Embed the map": "Incrustar o mapa",
    "Emoji & Character": "Emojis e personaxes",
    "Empty": "Baleirar",
    "Equidistant": "Equidistante",
    "Error in the overlay URL": "Hai un erro no URL de superposición",
    "Error in the tilelayer URL": "Hai un erro no URL da capa de teselas",
    "Exit Fullscreen": "Saír da pantalla completa",
    "expanded": "expandido",
    "Extract shape to separate feature": "Extraer a forma para separar o elemento",
    "Feature identifier key": "Chave identificadora do elemento",
    "Feature properties": "Propiedades do elemento",
    "Fetch data each time map view changes.": "Obter os datos cada vez que cambia a vista do mapa.",
    "fill color": "cor de recheo",
    "fill opacity": "reencher a opacidade",
    "fill": "reencher",
    "Fit all data": "Axustar todos os datos",
    "Format": "Formato",
    "From zoom": "Dende o zoom",
    "full backup": "copia de seguranza completa",
    "Generic": "Xenérico",
    "GeoRSS (only link)": "GeoRSS (só ligazón)",
    "GeoRSS (title + image)": "GeoRSS (título + imaxe)",
    "Go to \"{coords}\"": "Ir a «{coords}»",
    "Go to the homepage": "Ir á páxina de inicio",
    "Go to «{feature}»": "Ir a «{feature}»",
    "Heatmap intensity property": "Propiedade da intensidade do mapa de calor",
    "Heatmap radius": "Raio do mapa de calor",
    "Heatmap": "Mapa de calor",
    "height": "altura",
    "Help": "Axuda",
    "hidden": "agochar",
    "Hide controls": "Agochar os controis",
    "Home": "Inicio",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Canto se simplificará a poliliña en cada nivel de zoom (máis = mellor comportamento e aparencia máis feble, menos = máis preciso)",
    "icon opacity": "opacidade da icona",
    "Icon shape": "Forma da icona",
    "Icon symbol": "Símbolo da icona",
    "If false, the polygon or line will act as a part of the underlying map.": "Se é falso, o polígono ou a liña actuará coma parte do mapa subxacente.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe con altura personalizada (en px): {{{https://iframe.url.com|height}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe con altura e largura personalizadas (en px): {{{https://iframe.url.com|height*width}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Imaxe con largo personalizado (en px):",
    "Image: {{https://image.url.com}}": "Image: {{https://image.url.com}}",
    "Import data": "Importar datos",
    "Import in a new layer": "Importar nunha nova capa",
    "Imports all umap data, including layers and settings.": "Importar todos os datos de umap, incluíndo capas e axustes.",
    "Include full screen link?": "Engadir a ligazón de pantalla completa?",
    "Inherit": "Herdar",
    "inherit": "herdar",
    "Interaction options": "Opcións de interacción",
    "Invalid latitude or longitude": "Latitude ou lonxitude incorrecta",
    "Invalid umap data in {filename}": "Dato umap incorrecto en {filename}",
    "Invalid umap data": "Dato umap inorrecto",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-medias",
    "Keep current visible layers": "Gardar capas visíbeis actuais",
    "kilometers": "quilómetros",
    "km": "km",
    "Label direction": "Dirección da etiqueta",
    "Label key": "Etiqueta da clave",
    "Labels are clickable": "Pódese premer nas etiquetas",
    "Latest feature": "Elemento máis recente",
    "Latitude": "Latitude",
    "Layer properties": "Propiedades da capa",
    "Layer": "Capa",
    "Licence": "Licenza",
    "licence": "licenza",
    "Limit bounds": "Limites máximos",
    "Link to view the map": "Ligazón para ver o mapa",
    "Link to…": "Ligazón cara a…",
    "Link with text: [[https://example.com|text of the link]]": "Ligazón con texto: [[https://example.com|texto da ligazón]]",
    "Long credits": "Recoñecementos extensos",
    "Longitude": "Lonxitude",
    "Make main shape": "Facer a forma principal",
    "Manage layers": "Xestionar capas",
    "Manual": "Manual",
    "Map background credits": "Recoñecementos do mapa de fondo",
    "Map has been attached to your account": "O mapa foi incorporado á súa conta",
    "Map has been saved!": "O mapa foi gardado!",
    "Map has been starred": "O mapa foi destacado con estrela",
    "Map has been unstarred": "Retiróuselle ao mapa o destaque con estrela",
    "Map user content has been published under licence": "O contido do mapa do usuario foi publicado baixo a licenza",
    "Map's editors": "Editores do mapa",
    "Map's owner": "Propietario do mapa",
    "max East": "máximo Leste",
    "max North": "máximo Norte",
    "max South": "máximo Sur",
    "max West": "máximo Oeste",
    "max zoom": "zoom máximo",
    "Measure distances": "Medir distancias",
    "Merge lines": "Combinar liñas",
    "mi": "mi",
    "miles": "millas",
    "min zoom": "zoom mínimo",
    "More controls": "Máis controis",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Ten que ser un valor CSS válido (p. ex.: DarkBlue ou #123456)",
    "name": "nome",
    "nautical miles": "millas náuticas",
    "never": "nunca",
    "new window": "nova xanela",
    "next": "seguinte",
    "NM": "M",
    "No cache": "Sen memoria tobo",
    "No licence has been set": "Non foi definida ningunha licenza",
    "No results": "Sen resultados",
    "no": "non",
    "No.": "Núm.",
    "None": "Ningún",
    "Number of desired classes (default 5)": "Número de clases desexadas (predeterminado 5)",
    "On the bottom": "Na parte de embaixo",
    "On the left": "Á esquerda",
    "On the right": "Á dereita",
    "On the top": "Na parte de enriba",
    "Only visible layers' data": "Só os datos das capas visíbeis",
    "opacity": "opacidade",
    "Opacity": "Opacidade",
    "Open current feature on load": "Abrir o elemento actual na carga",
    "Open link in…": "Abrir a ligazón en…",
    "Open share & download panel": "Abrir o panel de compartición e descarga",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Abrir esta extensión do mapa nun editor de mapas para fornecer datos máis precisos a OpenStreetMap",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Propiedade de intensidade opcional para o mapa de calor",
    "Optional. Same as color if not set.": "Opcional. A mesma cor se non se define.",
    "Optional.": "Opcional.",
    "Override clustering radius (default 80)": "Sobrescribir o raio de agrupamento (predeterminado 80)",
    "Override heatmap radius (default 25)": "Sobreescribir o raio do mapa de calor (predeterminado 25)",
    "parent window": "xanela principal",
    "Paste your data here": "Pega os teus datos aquí",
    "Permalink": "Ligazón permanente",
    "Permanent credits background": "Fondo dos recoñecementos permanentes",
    "Permanent credits": "Recoñecementos permanentes",
    "Please be sure the licence is compliant with your use.": "Asegúrate de que a licenza sexa compatíbel co uso que lle vas dar.",
    "Please choose a format": "Escolle un formato",
    "Please enter the name of the property": "Introduce o nome da propiedade",
    "Please enter the new name of this property": "Introduce o novo nome desta propiedade",
    "Please save the map first": "Garda o mapa primeiro",
    "Popup (large)": "Xanela emerxente (grande)",
    "Popup content style": "Estilo do contido da xanela emerxente",
    "Popup content template": "Modelo do contido da xanela emerxente",
    "Popup shape": "Forma da xanela emerxente",
    "Popup": "Xanela emerxente",
    "Powered by uMap": " Desanvolvido por uMap",
    "previous": "anterior",
    "Problem in the response": "Produciuse un problema na resposta",
    "Properties imported:": "Propiedades importadas:",
    "Provide an URL here": "Fornece un URL aquí",
    "Proxy request": "Petición ao proxy",
    "Quantiles": "Cuantiles",
    "Recent": "Recente",
    "Remote data": "Datos remotos",
    "Remove shape from the multi": "Eliminar a forma do multielemento",
    "Replace layer content": "Substitúe o contido da capa",
    "Restore this version": "Restabelecer esta versión",
    "Save current edits": "Gardar as edicións actuais",
    "Save map": "Gardar o mapa",
    "Save": "Gardar",
    "Saved center and zoom": "Gardar o centrado e nivel de zoom",
    "Search location": "Buscar posición",
    "Search": "Buscar",
    "Secret edit link:": "Ligazón de edición secreta:",
    "See full screen": "Ver a pantalla completa",
    "See on OpenStreetMap": "Ver en OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Defíneo como falso para agochar esta capa do diaporama (slideshow), do navegador de datos e da navegación da xanela emerxente…",
    "settings": "axustes",
    "Shape properties": "Propiedades da forma",
    "Share and download": "Compartición e descarga",
    "Share this link to open a customized map view": "Comparte esta ligazón para abrir unha vista de mapa personalizada",
    "Short credits": "Recoñecementos breves",
    "Short link": "Ligazón curta",
    "Show this layer in the caption": "Amosar esta capa na lenda",
    "Show/hide layer": "Amosar/agochar capa",
    "Side panel": "Panel lateral",
    "Simple link: [[https://example.com]]": "Ligazón sinxela: [[http://example.com]]",
    "Simplify": "Simplificar",
    "Skipping unknown geometry.type: {type}": "Omitindo o «geometry.type» descoñecido: {type}",
    "Slideshow": "Diaporama",
    "Sort key": "Clave de ordenación",
    "Split line": "Liña de división",
    "Star this map": "Destacar este mapa con estrela",
    "Start a hole here": "Comezar un buraco aquí",
    "Start slideshow": "Comezar o diaporama",
    "Stop editing": "Deixar de editar",
    "Stop slideshow": "Deter o diaporama",
    "Street": "Rúa",
    "stroke": "trazo",
    "Supported scheme": "Esquema admitido",
    "Supported variables that will be dynamically replaced": "Variábeis admitidas que serán substituídas de xeito dinámico",
    "Symbol": "Símbolo",
    "Table": "Táboa",
    "Text color for the cluster label": "Cor do texto para a etiqueta do agrupamento",
    "Text formatting": "Formato do texto",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "O nome da propiedade que vai ser empregado como etiqueta do elemento (p. ex.: «nom»). Tamén podes usar propiedades entre corchetes para usar máis dunha ou mesturar con contido estático (p. ex.: «&lcub;name&rcub; en &lcub;place&rcub;»)",
    "The name of the property to use as feature unique identifier.": "O nome da propiedade que se utilizará como identificador único do elemento.",
    "The zoom and center have been modified.": "O nivel de zoom e o centrado foron modificados.",
    "TMS format": "formato TMS",
    "To use if remote server doesn't allow cross domain (slower)": "Para empregar se o servidor remoto non permite dominios cruzados (máis lento)",
    "To zoom": "Para o zoom",
    "Toggle edit mode (⇧+Click)": "Alternar o modo de edición (⇧+Premer)",
    "Toggle edit mode": "Alternar o modo de edición",
    "Transfer shape to edited feature": "Transferir a forma ao elemento editado",
    "Transform to lines": "Transformar a liñas",
    "Transform to polygon": "Transformar a polígono",
    "Type a place name or coordinates": "Escribe un nome de lugar ou coordenadas",
    "Type char or paste emoji": "Escribe un carácter ou pega un emoji",
    "Type of layer": "Tipo de capa",
    "Unable to detect format of file {filename}": "Non é posíbel detectar o formato de ficheiro {filename}",
    "Untitled layer": "Capa sen título",
    "Untitled map": "Mapa sen título",
    "Update permissions and editors": "Actualizar permisos e editores",
    "Update permissions": "Actualizar permisos",
    "Update who can see and edit the map": "Actualiza quen pode ver e editar o mapa",
    "Url": "Url",
    "URL": "URL",
    "Use current bounds": "Empregar os límites actuais",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Empregar marcadores de substitución con propiedades do elemento entre parénteses, exemplo &#123;name&#125;, serán substituídos de xeito dinámico polos valores correspondentes.",
    "User content credits": "Recoñecementos do contido do usuario",
    "User interface options": "Opcións da interface de usuario",
    "User location": "Posición do usuario",
    "Verify remote URL": "Verifica o URL remoto",
    "Versions": "Versións",
    "View Fullscreen": "Ver en pantalla completa",
    "View": "Ver",
    "Visibility: {status}": "Visibilidade: {status}",
    "weight": "largo",
    "Where do we go from here?": "Cara onde imos?",
    "Whether to display or not polygons paths.": "Se queres amosar ou non as rutas dos polígonos.",
    "Whether to fill polygons with color.": "Se queres rechear os polígonos con cor.",
    "Who can edit \"{layer}\"": "Quen pode editar «{layer}»",
    "Who can edit": "Quen pode editar",
    "Who can view": "Quen pode ver",
    "width": "largo",
    "Will be displayed in the bottom right corner of the map": "Amosarase no canto inferior esquerdo do mapa",
    "Will be permanently visible in the bottom left corner of the map": "Será visíbel permanentemente no canto inferior esquerdo do mapa",
    "Will be visible in the caption of the map": "Será visíbel na lenda do mapa",
    "yes": "si",
    "Zoom in": "Achegar",
    "Zoom level for automatic zooms": "Nivel de zoom para achegamentos automáticos",
    "Zoom out": "Afastar",
    "Zoom to layer extent": "Zoom ata que se vexan os datos da capa",
    "Zoom to the next": "Achegar ata o seguinte",
    "Zoom to the previous": "Achegar ata o anterior",
    "Zoom to this feature": "Achegar a este elemento",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} erros durante a importación: {message}",
    "{delay} seconds": "{delay} segundos",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} millas",
    "{distance}&#8239;NM": "{distance} M",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Editar o nome e a lenda do mapa",
    "Map advanced properties": "Propiedades avanzadas do mapa",
    "Edit map details": "Editar os detalles do mapa",
    "Back to browser": "Volver ao navegador",
    "Toggle size": "Alternar o tamaño",
    "Display the caption control": "Amosar o control de lendas",
    "<empty value>": "<valor valeiro>",
    "Min": "Mín.",
    "Max": "Máx.",
    "From": "Desde",
    "Until": "Ata",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": " Exemplo: clave1,clave2|Etiqueta 2,clave3|Etiqueta 3|caixa de verificación",
    "Edit in OpenStreetMap": "Editar en OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Non é posíbel determinar as columnas de latitude e lonxitude.",
    "Back to layers": "Volver ás capas",
    "Filters": "Filtros",
    "Comma separated list of properties to use when filtering features by text input": "Lista de propiedades separadas por comas a empregar ao filtrar funcións pola entrada de texto",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Lista de propiedades separadas por comas a empregar para os filtros (p. ex.: amiñaclave,outraclave). Para controlar a etiqueta, engádaa após unha | (p. ex.: amiñaclave|AmiñaClave,outraclave|Outra chave). Para controlar o tipo de campo de entrada, engádeo após outra | (p. ex.: amiñaclave|AmiñaClave|caixadeverificación,otraclave|Outra clave|datahora). Os valores permitidos para o tipo de campo de entrada son caixa de verificación (predeterminado), botón de opción, número, data e datahora.",
    "Search keys": "Claves de busca",
    "Filters keys": "Claves de filtrado",
    "Filter data": "Filtrar datos",
    "Search map features…": " Buscar elementos do mapa…",
    "Reset all": "Restabelecer todo",
    "Open browser": "Abrir o navegador",
    "Open caption": "Abrir as lendas",
    "Your map has been created with an anonymous account!": "O teu mapa creouse cunha conta anónima.",
    "Real-time collaboration": "Colaboración en tempo real",
    "Cannot parse data": "Non é posíbel analizar os datos",
    "Start typing...": "Comeza a escribir…",
    "No result": "Sen resultados",
    "Data browser": "Navegador de datos",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Ao fornecer un URL, uMap pode copiar os datos remotos nunha capa ou engadir este URL como fonte remota da capa. Nese caso, os datos sempre se obterán dese URL e, polo tanto, estarán actualizados, mais non será posíbel editalos dentro de uMap.",
    "Overpass supported expressions": " Expresións compatíbeis con Overpass",
    "key (eg. building)": "clave (ex. building)",
    "!key (eg. !name)": "!clave (ex. !name)",
    "key=value (eg. building=yes)": "clave=valor (ex. building=yes)",
    "key!=value (eg. building!=yes)": "clave!=valor (ex. building!=yes)",
    "key~value (eg. name~Grisy)": "clave~valor (ex. name~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "clave=\"valor|valor2\" (ex. name=\"Paris|Berlin\")",
    "More info about Overpass syntax": "Máis información sobre a sintaxe Overpass",
    "For more complex needs, see": "Para necesidades máis complexas, consultao",
    "Choose data": "Escoller os datos",
    "Choose the format": "Escoller o formato",
    "Choose the layer": "Escoller a capa",
    "Layer name": "Nome da capa",
    "Choose import mode": "Escoller o modo de importación",
    "Copy into the layer": "Copiar na capa",
    "Link to the layer as remote data": "Ligazón á capa como datos remotos",
    "Condition": "Condición",
    "key=value or key!=value": "clave=valor ou clave!=valor",
    "Are you sure you want to delete this rule?": "Confirmas que queres eliminar esta regra?",
    "empty rule": "regra baleira",
    "Conditional style rules": "Regras de estilo condicional",
    "Add rule": "Engadir regra",
    "Browser: data": "Navegador: datos",
    "Browser: layers": "Navegador: capas",
    "Browser: filters": "Navegador: filtros",
    "Enable real-time collaboration": "Activa a colaboración en tempo real",
    "✅ Copied!": "✅ Copiado!",
    "Choose a dataset": "Escoller un conxunto de datos",
    "Choose this dataset": "Escoller este conxunto de datos",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: datos temáticos de OpenStreetMap",
    "Choose a theme": "Escoller un tema",
    "Choose this data": "Escoller estes datos",
    "Search admin boundary": "Buscar un límite administrativo",
    "Please choose a theme and a boundary first.": "Escolle primeiro un tema e un límite.",
    "Expression": "Expresión",
    "Geometry mode": "Modo xeometría",
    "Only geometry centers": "Só centros xeométricos",
    "Search area": "Área de busca",
    "Type area name, or let empty to load data in current map view": "Escribe o nome da área ou déixao baleiro para cargar datos na vista de mapa actual",
    "Data successfully imported!": "Os datos foron importados correctamente!",
    "Clear data": "Limpar os datos",
    "Remove layers": "Retirar as capas",
    "Categorized": "Categorizado",
    "Alphabetical": "Alfabético",
    "Category property": "Propiedade de categoría",
    "Color palette": "Paleta de cores",
    "Categories": "Categorias",
    "Comma separated list of categories.": "Lista de categorías separadas por comas.",
    "Categories mode": "Modo de categorías",
    "Remove filter for this column": "Retirar o filtro para esta columna",
    "Add filter for this column": "Engadir filtro para esta columna",
    "Rename this column": "Cambiar o nome desta columna",
    "Delete this column": "Eliminar esta columna",
    "Name “{name}” should not contain a dot.": "O nome «{name}» non debe conter un punto.",
    "This name already exists: “{name}”": "O nome «{name}» xa existe",
    "Delete selected rows": "Eliminar as filas seleccionadas",
    "Found {count} rows. Are you sure you want to delete all?": "Atopáronse {count} filas. Confirmas que queres eliminalo todo?",
    "Expression is empty": "A expresión está baleira",
    "OK": "Aceptar",
    "Cancel": "Cancelar",
    "Attach map to a team": "Incorporar o mapa ao equipo",
    "Display the polygon inverted": "Amosar o polígono invertido",
    "Proportional circles": "Círculos proporcionais",
    "Property name to compute circles": "Nome da propiedade para calcular círculos",
    "Min circle radius": "Raio mínimo do círculo",
    "Max circle radius": "Raio máximo do círculo",
    "Display the open browser control": "Mostra o control para abrir o navegador",
    "Copy as GeoJSON": "Copiar como GeoJSON",
    "Please zoom in to edit the geometry": "Achegar co zoom para editar a xeometría",
    "New map": "Mapa novo",
    "My maps": "Os meus mapas",
    "My teams": "Os meus equipos",
    "My profile": "O meu perfil",
    "Type new owner's username": "Escribe o nome de usuario do novo propietario",
    "Type editor's username": "Escribe o nome de usuario do editor",
    "Map": "Mapa",
    "Manage collaborators": "Xestionar os colaboradores",
    "show/hide all layers": "amosar/agochar todas as capas",
    "zoom to data extent": "Achegar co zoom para a extensión dos datos",
    "download visible data": "descargar os datos visíbeis",
    "Import helpers": "Asistentes de importación",
    "Import helpers will fill the URL field for you.": "Os asistentes de importación encherán o campo URL por Vde.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Gardar o borrador",
    "No data has been found for import": "Non se atoparon datos para importar",
    "Successfully imported {count} feature(s)": "Importado(s) satisfactoriamente {count} elemento(s)",
    "Disconnected": "Desconectado",
    "You must be logged in": "Debes ter accedido",
    "on hover": "ó pasar o rato por riba",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Non é posíbel cargar datos remotos para a capa «{layer}» co url «{url}»",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Non é posíbel analizar os datos remotos da capa «{layer}» co url «{url}»",
    "Import failed: invalid data": "Produciuse un fallo na importación: os datos non son válidos",
    "Anonymous": "Anónimo",
    "created at {date}": "creado o {data}",
    "modified at {date}": "modificado o {data}",
    "Default zoom": "Zoom predeterminado",
    "Default latitude": "Latitude predeterminada",
    "Default longitude": "Lonxitude predeterminada",
    "Edit map default view": "Editar a vista predeterminada do mapa",
    "Use current center and zoom": "Usar o centrado e o nivel de zoom actual",
    "Layer permalink": "Ligazón permanente de capa",
    "Back to home": "Back to home",
    "Home logo": "Home logo",
    "Add this geometry to my map": "Add this geometry to my map",
    "Add this place to my map": "Add this place to my map",
    "Cancel last edit": "Cancel last edit",
    "Redo last edit": "Redo last edit",
    "Links": "Links",
    "Images": "Images",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Display the back to home icon",
    "Do you want to display layer switcher in caption bar?": "Do you want to display layer switcher in caption bar?",
    "Simplify all geometries to points": "Simplify all geometries to points",
    "Back to list": "Back to list",
    "Toggle rule": "Toggle rule",
    "Delete rule": "Delete rule",
    "Cannot save layer, please try again in a few minutes.": "Cannot save layer, please try again in a few minutes."
}
L.registerLocale("gl", locale)
L.setLocale("gl")
