# Generated by Django 5.0.2 on 2024-04-17 09:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0019_migrate_internal_remote_datalayers"),
    ]

    operations = [
        migrations.AlterField(
            model_name="tilelayer",
            name="url_template",
            field=models.CharField(
                help_text="URL template using OSM tile format", max_length=400
            ),
        ),
    ]
