const locale = {
    "(area: {measure})": "(oppervlakte: {measure})",
    "(length: {measure})": "(lengte: {measure})",
    "# one hash for main heading": "# een hekje voor koptekst 1",
    "## two hashes for second heading": "## twee hekjes voor koptekst 2",
    "### three hashes for third heading": "### drie hekjes voor koptekst 3",
    "**double star for bold**": "** Twee sterretjes voor vet **",
    "*single star for italic*": "*één ster voor italic*",
    "--- for a horizontal rule": "--- voor een horizontale lijn",
    "1 day": "1 dag",
    "1 hour": "1 uur",
    "5 min": "5 minuten",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Een lijst getallen, gescheiden door komma's, die het streepjespatroon definiëren. Vb: \"5, 10, 15\".",
    "About": "Over",
    "Action not allowed :(": "Handeling niet toegelaten :(",
    "Activate slideshow mode": "Activeer slidshow modus",
    "Add a layer": "Laag toevoegen",
    "Add a line to the current multi": "Voeg een lijn toe aan de huidige multilijn",
    "Add a new property": "Voeg een nieuwe eigenschap toe",
    "Add a polygon to the current multi": "Voeg een nieuwe polygoon toe aan de huidige multipolygoon",
    "Add image URL": "Voeg URL van afbeelding toe",
    "Advanced actions": "Geavanceerde acties",
    "Advanced properties": "Geavanceerde eigenschappen",
    "All data and settings of the map": "Alle data en instellingen van de kaart",
    "All properties are imported.": "Alle eigenschappen zijn geïmporteerd",
    "Allow interactions": "Sta interactie toe",
    "Allow scroll wheel zoom?": "Zoomen met scrollwiel toestaan?",
    "always": "altijd",
    "Animated transitions": "Geavanceerde overgangen",
    "Are you sure you want to clone this map and all its datalayers?": "Weet je zeker dat je deze kaart en alle gegevenslagen wil klonen?",
    "Are you sure you want to delete this map?": "Weet je zeker dat je deze kaart wilt verwijderen?",
    "Are you sure you want to delete this property on all the features?": "Ben je zeker dat je deze eigenschap bij alle objecten wil verwijderen?",
    "Are you sure you want to restore this version?": "Weet je zeker dat je deze versie wilt terugzetten?",
    "Attach the map to my account": "Voeg de kaart toe aan mijn account",
    "attribution": "bronvermelding",
    "Auto": "Auto",
    "Automatic": "Automatisch",
    "Autostart when map is loaded": "Autostart als kaart wordt geladen",
    "Back to preview": "Terug naar voorvertoning",
    "Background overlay url": "Achtergrond overlay url",
    "Ball": "Kopspeld",
    "Bring feature to center": "Breng element naar het midden",
    "Browse data": "Gegevens doorbladeren",
    "by": "door",
    "Cache proxied request": "Cache proxied request",
    "Caption": "Hoofding",
    "Center map on your location": "Centreer kaart op je locatie",
    "Change tilelayers": "Andere kaartachtergrond instellen",
    "Change": "Veranderen",
    "Choose the data format": "Gegevensformaat selecteren",
    "Choropleth breakpoints": "Choropleten verdeelpunten",
    "Choropleth classes": "Choropleten klassen",
    "Choropleth color palette": "Choropleten kleurenpalet",
    "Choropleth mode": "Choropleten modus",
    "Choropleth property value": "Choropleten eigenschap waarde",
    "Choropleth": "Choropleten",
    "Circle": "Cirkel",
    "clear": "wis",
    "Click last point to finish shape": "Klik op het laatste punt om de vorm af te maken",
    "Click to add a marker": "Klik om een punt toe te voegen",
    "Click to continue drawing": "Klik om te blijven tekenen",
    "Click to edit": "Klik om te bewerken",
    "Click to start drawing a line": "Klik om een lijn te beginnen tekenen",
    "Click to start drawing a polygon": "Klik om een polygoon te beginnen tekenen",
    "Clone of {name}": "Kloon van {name}",
    "Clone this feature": "Kloon dit object",
    "Clone this map": "Deze kaart klonen",
    "Clone": "Klonen",
    "Close": "Sluit",
    "Clustered": "Bij elkaar gevoegd",
    "Clustering radius": "Doorsnede voor clusteren",
    "collapsed": "dichtgeklapt",
    "color": "kleur",
    "Comma separated list of numbers, including min and max values.": "Door komma's gescheiden lijst van getallen, inclusief minimale en maximale waarden.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Komma-gescheiden lijst van eigenschappen die gebruikt worden om objecten te sorteren. Om de sortering om te draaien, plaats er een minteken (-) voor . Bijvoorbeeld mykey,-otherkey.",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Komma-, tabulator- of puntkomma-gescheiden waardes, SRS WGS84 wordt verondersteld. Enkel puntgeometrieën worden geïmporteerd. Bij het importeren wordt gekeken naar kolomkoppen die met «lat» of «lon» beginnen. Alle andere kolommen worden als eigenschappen geïmporteerd",
    "Congratulations, your map has been created!": "Proficiat, je kaart is aangemaakt!",
    "Continue line": "Ga door met deze lijn",
    "Coordinates": "Coördinaten",
    "copy": "kopieer",
    "Credits": "Bronvermelding",
    "Current map view": "Huidige kaartweergave",
    "Current view instead of default map view?": "Huidig zicht in plaats van standaard kaartaanzicht",
    "Custom background": "Eigen achtergrond",
    "Custom overlay": "Eigen overlay",
    "dash array": "soort stippellijn",
    "Data is browsable": "Data kan verkend worden",
    "Datalayers": "Datalagen",
    "Default interaction options": "Standaard interactie-opties",
    "Default properties": "Standaardeigenschappen",
    "Default shape properties": "Standaard vorm eigenschappen",
    "Default view": "Stanaardweergave",
    "Default zoom level": "Standaard schaalniveau",
    "Default": "Standaard",
    "Default: name": "Standaard: naam",
    "Define link to open in a new window on polygon click.": "Stel outputlink in om een nieuw venster te openen wanneer polygoon wordt aangeklikt",
    "define": "definieer",
    "Delay between two transitions when in play mode": "Pauze tussen twee transities wanneer in afspeel-modus",
    "Delete layer": "Verwijder laag",
    "Delete this feature": "Dit object verwijderen",
    "Delete this shape": "Verwijder deze vorm",
    "Delete this vertex (Alt+Click)": "Verwijder dit knooppunt (Alt+Click)",
    "Delete": "Verwijderen",
    "description": "beschrijving",
    "Direct link": "Directe link",
    "Directions from here": "Wegbeschrijving vanaf hier",
    "Display label": "Toon het label",
    "Display measure": "Toon meting",
    "display name": "toon de naam",
    "Display on load": "Tonen bij laden",
    "Display the control to open OpenStreetMap editor": "Toon OpenStreetMap editor knop",
    "Display the embed control": "Toon inbedden knop",
    "Display the fullscreen control": "Toon volledig scherm knop",
    "Display the locate control": "Toon lokaliseer mij knop",
    "Display the measure control": "Toon meetinstrument knop",
    "Display the search control": "Toon zoeken knop",
    "Display the tile layers control": "Toon achtergrondlagen knop",
    "Display the zoom control": "Toon zoom knop",
    "Do you want to display a caption bar?": "Wil je een hoofding tonen?",
    "Do you want to display a minimap?": "Wil je een minikaartje tonen?",
    "Do you want to display a panel on load?": "Wil je een zijpaneel tonen als de kaart geladen wordt?",
    "Do you want to display caption menus?": "Wil je een menu met bijschriften weergeven?",
    "Do you want to display popup footer?": "Wil je een popup-footer tonen?",
    "Do you want to display the scale control?": "Wil je het schaal-besturingselement tonen?",
    "Do you want to display the «more» control?": "Wil je de knop «meer» laten zien?",
    "Download": "Downloaden",
    "Drag to reorder": "Sleep om de volgorde te wijzigen",
    "Draw a marker": "Teken een punt",
    "Draw a polygon": "Teken een veelhoek",
    "Draw a polyline": "Teken een lijn",
    "Drawing": "Tekenen",
    "Drop": "Druppel",
    "Dynamic properties": "Dynamische eigenschappen",
    "Dynamic": "Dynamisch",
    "Edit feature's layer": "Objectlaag bewerken",
    "Edit properties in a table": "Edit properties in a table",
    "Edit the title of the map": "Bewerk de titel van de kaart",
    "Edit this feature": "Dit object bewerken",
    "Edit": "Bewerken",
    "Embed and link options": "Invoegtoepassing- en linkopties",
    "Embed the map": "Kaart inbedden",
    "Emoji & Character": "Emoji & karakter",
    "Empty": "Leeg",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Fout in de overlay URL",
    "Error in the tilelayer URL": "Er is een fout opgetreden met de achtergrondtegels",
    "Exit Fullscreen": "Verlaat volledig scherm",
    "expanded": "opengeklapt",
    "Extract shape to separate feature": "Verplaats deze vorm naar een eigen object",
    "Feature identifier key": "Unieke identificator van het object",
    "Feature properties": "Eigenschappen van het object",
    "Fetch data each time map view changes.": "Haal data op elke keer het kaartaanzicht verandert",
    "fill color": "opvulkleur",
    "fill opacity": "(on)doorzichtigheid van inkleuring",
    "fill": "opvullen",
    "Fit all data": "Doe alle data passen",
    "Format": "Formaat",
    "From zoom": "Van zoom",
    "full backup": "Volledige back-up ",
    "Generic": "Algemeen",
    "GeoRSS (only link)": "GeoRSS (enkel link)",
    "GeoRSS (title + image)": "GeoRSS (titel + afbeelding)",
    "Go to \"{coords}\"": "Ga naar \"{coords}\"",
    "Go to the homepage": "Ga naar de thuispagina",
    "Go to «{feature}»": "Ga naar «{feature}»",
    "Heatmap intensity property": "Eigenschap die intensiteit van de heatmap bepaalt",
    "Heatmap radius": "Doorsnede van de heatmap",
    "Heatmap": "Hittekaart",
    "height": "hoogte",
    "Help": "Help",
    "hidden": "verborgen",
    "Hide controls": "Verberg besturingselementen",
    "Home": "Home",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Graad van vereenvoudiging van een veelhoek, per zoomniveau. (Hogere waarde = betere prestaties, lagere waarde = getrouwere precisie)",
    "icon opacity": "Icoon ondoorzichtigheid",
    "Icon shape": "Vorm van het icoon",
    "Icon symbol": "Symbool voor het icoon",
    "If false, the polygon or line will act as a part of the underlying map.": "Indien uit, zal de polygoon of lijn dienen als deel van de onderliggende kaart.",
    "Iframe with custom height (in px): {{{https://iframe.url.com|height}}}": "Iframe met gespecifieerde hoogte (in px): {{{https://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{https://iframe.url.com|height*width}}}": "Iframe met gespecifieerde hoogte en breedte (in px): {{{https://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{https://iframe.url.com}}}": "Iframe: {{{https://iframe.url.com}}}",
    "Image with custom width (in px): {{https://image.url.com|width}}": "Afbeelding met aangepaste breedte (in px): {{https://image.url.com|width}}",
    "Image: {{https://image.url.com}}": "Afbeelding: {{https://image.url.com}}",
    "Import data": "Gegevens importeren",
    "Import in a new layer": "Importeer in een nieuwe laag",
    "Imports all umap data, including layers and settings.": "Importeert alle umap gegevens, inclusief lagen en instellingen",
    "Include full screen link?": "Link voor volledig scherm meegeven?",
    "Inherit": "Overerving",
    "inherit": "overerven",
    "Interaction options": "Opties voor interactie",
    "Invalid latitude or longitude": "Incorrecte lengte- of breedtegraad",
    "Invalid umap data in {filename}": "Incorrecte umap data in {filename}",
    "Invalid umap data": "Incorrecte umap data",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "Behoud de lagen die nu zichtbaar zijn",
    "kilometers": "kilometer",
    "km": "km",
    "Label direction": "Richting van het label",
    "Label key": "Attribuut als label",
    "Labels are clickable": "Labels kunnen aangeklikt worden",
    "Latest feature": "Recentste object",
    "Latitude": "Breedtegraad",
    "Layer properties": "Laag eigenschappen",
    "Layer": "Laag",
    "Licence": "Licentie",
    "licence": "licentie",
    "Limit bounds": "Gebied begrenzen",
    "Link to view the map": "Link om de kaart te zien",
    "Link to…": "Link naar…",
    "Link with text: [[https://example.com|text of the link]]": "Link met tekst: [[https://example.com|tekst van de link]]",
    "Long credits": "Lange bronvermelding",
    "Longitude": "Lengtegraad",
    "Make main shape": "Maak hoofd-vorm",
    "Manage layers": "Manage layers",
    "Manual": "Handmatig",
    "Map background credits": "Bronvermelding kaartachtergrond",
    "Map has been attached to your account": "Kaart werd toegevoegd aan je account",
    "Map has been saved!": "De kaart is bewaard!",
    "Map has been starred": "De kaart heeft een ster gekregen",
    "Map has been unstarred": "De kaart heeft geen ster meer",
    "Map user content has been published under licence": "Inhoud toegevoegd aan deze kaart wordt gepubliceerd onder deze licentievoorwaarden",
    "Map's editors": "Bewerkers van de kaart",
    "Map's owner": "Eigenaar van de kaart",
    "max East": "maximale oostwaarde",
    "max North": "maximale noordwaarde",
    "max South": "maximale zuidwaarde",
    "max West": "maximale westwaarde",
    "max zoom": "max zoom",
    "Measure distances": "Afstanden meten",
    "Merge lines": "Lijnen samenvoegen",
    "mi": "mi",
    "miles": "mijl",
    "min zoom": "min zoom",
    "More controls": "Meer instelknoppen",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Dit moet een geldige CSS-waarde zijn (vb.: DarkBlue of #123456)",
    "name": "naam",
    "nautical miles": "zeemijl",
    "never": "nooit",
    "new window": "nieuw venster",
    "next": "volgende",
    "NM": "NM",
    "No cache": "Geen cache",
    "No licence has been set": "Er is geen licentie ingesteld",
    "No results": "Geen resultaten",
    "no": "neen",
    "No.": "Neen.",
    "None": "Geen",
    "Number of desired classes (default 5)": "Gewenst aantal klassen (standaard 5)",
    "On the bottom": "Aan de onderkant",
    "On the left": "Aan de linkerkant",
    "On the right": "Aan de rechterkant",
    "On the top": "Aan de bovenkant",
    "Only visible layers' data": "Alleen zichtbare laaggegevens",
    "opacity": "ondoorzichtigheid",
    "Opacity": "Ondoorzichtigheid",
    "Open current feature on load": "Dit object openen bij laden",
    "Open link in…": "Open link in…",
    "Open share & download panel": "Open het deel & download paneel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Open dit gedeelte van de kaart in een editor, zodat u de kaartgegeven in Openstreetmap zelf kan bijwerken.",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "Optionele eigenschap om voor intensiteit van de heatmap te gebruiken",
    "Optional. Same as color if not set.": "Optioneel. Gelijk aan kleur indien niet ingesteld",
    "Optional.": "Optioneel.",
    "Override clustering radius (default 80)": "Andere clustering doorsnede gebruiken (standaard80)",
    "Override heatmap radius (default 25)": "Andere heatmap doorsnede gebruiken (standaard 25)",
    "parent window": "bovenliggend venster",
    "Paste your data here": "Plak je data hier",
    "Permalink": "Permalink",
    "Permanent credits background": "Permanente bronverwijzing achtergrond",
    "Permanent credits": "Permanente bronverwijzing",
    "Please be sure the licence is compliant with your use.": "Zorg er aub voor dat je je aan de licentievoorwaarden houdt",
    "Please choose a format": "Kies een formaat",
    "Please enter the name of the property": "Vul de naam in van de eigenschap",
    "Please enter the new name of this property": "Vul de nieuwe naam in van de eigenschap",
    "Please save the map first": "Graag eerst de kaart opslaan",
    "Popup (large)": "Popup (groot)",
    "Popup content style": "Stijl van de inhoud van de Popup",
    "Popup content template": "Template voor de popup",
    "Popup shape": "Vorm van de Popup",
    "Popup": "Popup",
    "Powered by uMap": "Aangedreven door uMap",
    "previous": "vorige",
    "Problem in the response": "Fout in het antwoord",
    "Properties imported:": "Geïmporteerde eigenschappen:",
    "Provide an URL here": "Geef hier een URL-adres op",
    "Proxy request": "Proxy request",
    "Quantiles": "Kwantielen",
    "Recent": "Recent",
    "Remote data": "Data van elders",
    "Remove shape from the multi": "Verwijder de vorm uit de multi",
    "Replace layer content": "Vervang de inhoud van de laag",
    "Restore this version": "Keer terug naar deze versie",
    "Save current edits": "Huidige bewerkingen opslaan",
    "Save map": "Kaart opslaan",
    "Save": "Opslaan",
    "Saved center and zoom": "Midden en zoom bewaard",
    "Search location": "Zoek locatie",
    "Search": "Zoeken",
    "Secret edit link:": "Geheime editeer-link",
    "See full screen": "Op volledig scherm weergeven",
    "See on OpenStreetMap": "Bekijk op OpenStreetMap",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Zet op onwaar ('false') om deze laag te verbergen in de slideshow, data verkenner, popup navigatie, ...",
    "settings": "instellingen",
    "Shape properties": "Eigenschappen van de vorm",
    "Share and download": "Deel en download",
    "Share this link to open a customized map view": "Deel deze link voor een gespecifieerde kaartweergave",
    "Short credits": "Korte bronvermelding",
    "Short link": "Korte link",
    "Show this layer in the caption": "Toon deze laag in het bijschrift",
    "Show/hide layer": "Laag tonen/verbergen",
    "Side panel": "Zijpaneel",
    "Simple link: [[https://example.com]]": "Eenvoudige link: [[http://example.com]]",
    "Simplify": "Vereenvoudig",
    "Skipping unknown geometry.type: {type}": "Overgeslaan wegens onbekend geometry.type: {type}",
    "Slideshow": "Slideshow",
    "Sort key": "Sleutel om op te sorteren",
    "Split line": "Splits de lijn",
    "Star this map": "Geef een ster aan deze kaart",
    "Start a hole here": "Begin hier een gat",
    "Start slideshow": "Start slideshow",
    "Stop editing": "Stop met editeren",
    "Stop slideshow": "Stop slideshow",
    "Street": "Straat",
    "stroke": "omlijnde vlakken",
    "Supported scheme": "Toegestaan datamodel",
    "Supported variables that will be dynamically replaced": "Toegestane variabele die dynamisch vervangen zullen worden",
    "Symbol": "Symbool",
    "Table": "Tabel",
    "Text color for the cluster label": "Kleur van de text voor het label van de cluster",
    "Text formatting": "Opmaak van de tekst",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "De naam van de eigenschap die als functielabel moet worden gebruikt (bijvoorbeeld: 'naam'). U kunt ook eigenschappen tussen haakjes gebruiken om er meer dan één te gebruiken of te mengen met statische inhoud (bv.: \"&lcub;naam&rcub; in &lcub;plaats&rcub;\")",
    "The name of the property to use as feature unique identifier.": "De naam van de eigenschap die als unieke identificator van objecten geldt",
    "The zoom and center have been modified.": "Zoom en centrum zijn bijgewerkt.",
    "TMS format": "TMS-formaat",
    "To use if remote server doesn't allow cross domain (slower)": "Activeer indien de externe server geen cross domain toelaat (trager)",
    "To zoom": "Tot zoomniveau",
    "Toggle edit mode (⇧+Click)": "Editeer modus aan/uitzetten (⇧+klik)",
    "Toggle edit mode": "Bewerkmodus schakelen",
    "Transfer shape to edited feature": "Verplaats vorm naar bewerkt object",
    "Transform to lines": "Omzetten naar lijnen",
    "Transform to polygon": "Omzetten naar polygoon",
    "Type a place name or coordinates": "Type een plaatsnaam of coördinaten ",
    "Type char or paste emoji": "Type karakter of plak emoji",
    "Type of layer": "Type laag",
    "Unable to detect format of file {filename}": "Kan het bestandstype van {filename} niet detecteren",
    "Untitled layer": "Laag zonder naam",
    "Untitled map": "Kaart zonder naam",
    "Update permissions and editors": "Bijwerken van permissies en bewerkers",
    "Update permissions": "Gebruiksrechten aanpassen",
    "Update who can see and edit the map": "Pas aan wie de kaart kan zien en bewerken",
    "Url": "URL",
    "URL": "URL",
    "Use current bounds": "Gebied begrenzen op wat nu te zien is",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Gebruik een \"placeholders\" met de eigenschappen van objecten, vb. &#123;naam&#125;. Deze zullen dynamisch vervangen worden door de bijhorende waarde.",
    "User content credits": "Gebruikersinhoud bronvermelding",
    "User interface options": "Gebruikersinterfaceopties",
    "User location": "Locatie van de gebruiker",
    "Verify remote URL": "Verifieer externe URL",
    "Versions": "Versies",
    "View Fullscreen": "Toon op volledig scherm",
    "View": "Weergave",
    "Visibility: {status}": "Zichtbaarheid: {status}",
    "weight": "lijndikte",
    "Where do we go from here?": "Wat gaan we doen?",
    "Whether to display or not polygons paths.": "Schakelaar toon polygoon omlijning",
    "Whether to fill polygons with color.": "Schakelaar vul polygonen met een kleur",
    "Who can edit \"{layer}\"": "Wie kan \"{layer}\" bewerken?",
    "Who can edit": "Wie kan bewerken",
    "Who can view": "Wie kan bekijken",
    "width": "breedte",
    "Will be displayed in the bottom right corner of the map": "Zal getoond worden in de rechter onderhoek van de kaart",
    "Will be permanently visible in the bottom left corner of the map": "Will be permanently visible in the bottom left corner of the map",
    "Will be visible in the caption of the map": "Zal getoond worden in de hoofding van de kaart",
    "yes": "ja",
    "Zoom in": "Inzoomen",
    "Zoom level for automatic zooms": "Schaalniveau voor automatische zooms",
    "Zoom out": "Uitzoomen",
    "Zoom to layer extent": "Zodanig zoomen dat alle data in venster past",
    "Zoom to the next": "Inzoomen op de volgende",
    "Zoom to the previous": "Inzoomen op de vorige",
    "Zoom to this feature": "Op dit object inzoomen",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{count} fouten tijdens import: {message}",
    "{delay} seconds": "{delay} seconden",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} mijl",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Bewerk de naam en het bijschrift van de kaart",
    "Map advanced properties": "Geavanceerde eigenschappen in kaart brengen",
    "Edit map details": "Kaartdetails bewerken",
    "Back to browser": "Terug naar browser",
    "Toggle size": "Grootte wisselen",
    "Display the caption control": "De controleknop van de Het ondertiteling weergeven",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "Van",
    "Until": "Tot",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Voorbeeld: sleutel1,sleutel2|Label 2,sleutel3|Label 3|selectievakje",
    "Edit in OpenStreetMap": "Bewerken in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Kan lengte- en breedtegraadkolommen niet bepalen.",
    "Back to layers": "Terug naar lagen",
    "Filters": "Filters",
    "Comma separated list of properties to use when filtering features by text input": "Door komma's gescheiden lijst met eigenschappen die moeten worden gebruikt bij het filteren van elementen op tekstinvoer",
    "Comma separated list of properties to use for filters (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Door komma's gescheiden lijst met eigenschappen die voor filters moeten worden gebruikt (bv.: mijnsleutel, anderesleutel). Als u het label wilt beheren, voeg je het toe na een | (bv.: mijnsleutel|Mijn Sleutel, otherkey|Andere Sleutel). Als u het invoerveldtype wilt beheren, voeg je het na een ander | toe (bv.: mijnsleutel|Mijn Sleutel|aanvinkvak,anderesleutel|Andere Sleutel|datum/tijd). Toegestane waarden voor het invoerveldtype zijn aanvinkvak (standaard), radioknop, nummer, datum en datum/tijd.",
    "Search keys": "Zoek sleutels",
    "Filters keys": "Filter sleutels",
    "Filter data": "Filter data",
    "Search map features…": "Zoek naar kaarteigenschappen...",
    "Reset all": "Alles herstellen",
    "Open browser": "Open browser",
    "Open caption": "Open bijschrift",
    "Your map has been created with an anonymous account!": "Je kaart is gemaakt met een anoniem account!",
    "Real-time collaboration": "Realtime samenwerking",
    "Cannot parse data": "Kan data niet parseren",
    "Start typing...": "Begin met typen...",
    "No result": "Geen resultaat",
    "Data browser": "Data browser",
    "When providing an URL, uMap can copy the remote data in a layer, or add this URL as remote source of the layer. In that case, data will always be fetched from that URL, and thus be up to date, but it will not be possible to edit it inside uMap.": "Bij het verstrekken van een URL kan uMap de externe data in een laag kopiëren, of deze URL toevoegen als externe bron van de laag. In dat geval worden de data altijd van die URL opgehaald en dus up-to-date, maar is het niet mogelijk om ze in uMap te bewerken.",
    "Overpass supported expressions": "Ondersteunde Overpass uitdrukkingen",
    "key (eg. building)": "sleutel (bijv. gebouw)",
    "!key (eg. !name)": "!sleutel (bv. !naam)",
    "key=value (eg. building=yes)": "sleutel=waarde (bv. gebouw=ja)",
    "key!=value (eg. building!=yes)": "sleuyel!=waarde (bv. gebouw!=yes)",
    "key~value (eg. name~Grisy)": "sleutel~waarde (bv. naam~Grisy)",
    "key=\"value|value2\" (eg. name=\"Paris|Berlin\")": "sleutel=\"waarde|waarde2\" (bv. naam=\"Parijs|Berlijn\")",
    "More info about Overpass syntax": "Meer informatie over de syntaxis van Overpass",
    "For more complex needs, see": "Voor complexere behoeften, zie",
    "Choose data": "Kies data",
    "Choose the format": "Kies het formaat",
    "Choose the layer": "Kies de laag",
    "Layer name": "Naam van de laag",
    "Choose import mode": "Kies import modus",
    "Copy into the layer": "Kopieer in de laag",
    "Link to the layer as remote data": "Koppeling naar de laag als externe data",
    "Condition": "Conditie",
    "key=value or key!=value": "Sleutel=waarde of sleutel!=waarde",
    "Are you sure you want to delete this rule?": "Weet je zeker dat je deze regel wilt verwijderen?",
    "empty rule": "lege regel",
    "Conditional style rules": "Voorwaardelijke stijlregels",
    "Add rule": "Voeg regel toe",
    "Browser: data": "Browser: data",
    "Browser: layers": "Browser: lagen",
    "Browser: filters": "Browser: filters",
    "Enable real-time collaboration": "Maak realtime samenwerking mogelijk",
    "✅ Copied!": "✅ Gekopieerd!",
    "Choose a dataset": "Kies een dataset",
    "Choose this dataset": "Kies deze dataset",
    "GeoDataMine: thematic data from OpenStreetMap": "GeoDataMine: thematische data van OpenStreetMap",
    "Choose a theme": "Kies een thema",
    "Choose this data": "Kies deze data",
    "Search admin boundary": "Zoeken administrative grens",
    "Please choose a theme and a boundary first.": "Kies eerst een thema en een grens.",
    "Expression": "Uitdrukking",
    "Geometry mode": "Geometrie-modus",
    "Only geometry centers": "Alleen geometriecentra",
    "Search area": "Doorzoek gebied",
    "Type area name, or let empty to load data in current map view": "Typ de naam van het gebied of laat leeg om data in de huidige kaartweergave te laden",
    "Data successfully imported!": "Data succesvol geïmporteerd!",
    "Clear data": "Wis data",
    "Remove layers": "Verwijder lagen",
    "Categorized": "Gecategoriseerd",
    "Alphabetical": "Alfabetisch",
    "Category property": "Categorie eigenschap",
    "Color palette": "Kleurenpalet",
    "Categories": "Categoriën",
    "Comma separated list of categories.": "Door komma's gescheiden lijst van categorieën.",
    "Categories mode": "Categorieën modus",
    "Remove filter for this column": "Verwijder filter voor deze kolom",
    "Add filter for this column": "Voeg filter toe voor deze kolom",
    "Rename this column": "Hernoem deze kolom",
    "Delete this column": "Verwijder deze kolom",
    "Name “{name}” should not contain a dot.": "De naam \"{name}\" mag geen punt bevatten.",
    "This name already exists: “{name}”": "Deze naam bestaat al: \"{name}\"",
    "Delete selected rows": "Geselecteerde rijen verwijderen",
    "Found {count} rows. Are you sure you want to delete all?": "Gevonden {count} rijen. Weet je zeker dat je alles wilt verwijderen?",
    "Expression is empty": "Expressie is leeg",
    "OK": "OK",
    "Cancel": "Annuleren",
    "Attach map to a team": "Kaart aan een team toewijzen",
    "Display the polygon inverted": "De omgekeerde veelhoek weergeven",
    "Proportional circles": "Proportionele circels",
    "Property name to compute circles": "Eigenschapsnaam om cirkels te berekenen",
    "Min circle radius": "Min. circlestraal",
    "Max circle radius": "Max. cirkelstraal",
    "Display the open browser control": "Het besturingselement voor het openen van de browser weergeven",
    "Copy as GeoJSON": "Kopiëren als GeoJSON",
    "Please zoom in to edit the geometry": "Zoom in om de geometrie te bewerken",
    "New map": "Nieuwe kaart",
    "My maps": "Mijn kaarten",
    "My teams": "Mijn teams",
    "My profile": "Mijn profiel",
    "Type new owner's username": "Typ de gebruikersnaam van de nieuwe eigenaar",
    "Type editor's username": "Typ de gebruikersnaam van de redacteur",
    "Map": "Kaart",
    "Manage collaborators": "Medewerkers beheren",
    "show/hide all layers": "Alle lagen tonen/verbergen",
    "zoom to data extent": "Inzoomen op data omvang",
    "download visible data": "Zichtbare data downloaden",
    "Import helpers": "Importhelpers",
    "Import helpers will fill the URL field for you.": "Importhelpers vullen het URL-veld voor u in.",
    "Wikipedia": "Wikipedia",
    "Save draft": "Concept opslaan",
    "No data has been found for import": "Er zijn geen data gevonden voor import",
    "Successfully imported {count} feature(s)": "Succesvol geïmporteerde {count} functie(s)",
    "Disconnected": "Verbroken",
    "You must be logged in": "U moet ingelogd zijn",
    "on hover": "bij hoveren",
    "Cannot load remote data for layer \"{layer}\" with url \"{url}\"": "Kan geen externe data laden voor laag \"{layer}\" met url \"{url}\"",
    "Cannot parse remote data for layer \"{layer}\" with url \"{url}\"": "Kan externe data niet parseren voor laag \"{layer}\" met url \"{url}\"",
    "Import failed: invalid data": "Importeren mislukt: ongeldige data",
    "Anonymous": "Anoniem",
    "created at {date}": "gemaakt op {date}",
    "modified at {date}": "gewijzigd op {date}",
    "Default zoom": "Standaard zoomniveau",
    "Default latitude": "Standaard breedtegraad",
    "Default longitude": "Standaard lengtegraad",
    "Edit map default view": "Standaardweergave van de kaart bewerken",
    "Use current center and zoom": "Gebruik huidig centrum en zoomniveau",
    "Layer permalink": "Permalink-laag",
    "Back to home": "Terug naar thuispagina",
    "Home logo": "Thuispagina logo",
    "Add this geometry to my map": "Voeg deze geometrie toe aan mijn kaart",
    "Add this place to my map": "Voeg deze plaats toe aan mijn kaart",
    "Cancel last edit": "Laatste bewerking annuleren",
    "Redo last edit": "Laatste bewerking opnieuw uitvoeren",
    "Links": "Koppelingen",
    "Images": "Afbeeldingen",
    "Iframes": "Iframes",
    "Tags": "Tags",
    "Geocode": "Geocode",
    "Display the back to home icon": "Het pictogram Terug naar huis weergeven",
    "Do you want to display layer switcher in caption bar?": "Wilt u de laagwisselaar weergeven in de ondertitelingsbalk?",
    "Simplify all geometries to points": "Vereenvoudig alle geometrieën tot punten",
    "Back to list": "Terug naar lijst",
    "Toggle rule": "Regel wisselen",
    "Delete rule": "Verwijder regel",
    "Cannot save layer, please try again in a few minutes.": "Kan de laag niet opslaan, probeer het over een paar minuten opnieuw.",
    "Activate collaborative live editing on this map. Other users must reload the map after changing this setting.": "Activeer samen live editeren voor deze kaart. Anderen moeten de kaart vernieuwen vooraleer dit actief wordt bij hen.",
    "More help resources": "Meer hulpbronnen",
    "This map is a template": "Deze kaart is een sjabloon",
    "Add text along path": "Een tekst langs een pad",
    "Text color": "Tekst kleur",
    "Text offset": "Tekst offset",
    "Text position": "Tekst positie",
    "start": "start",
    "center": "center",
    "end": "einde",
    "Text repeat": "Tekst herhaling",
    "Text rotate": "Tekst draaien",
    "Text size": "Tekst grootte",
    "Load map template": "Laad een sjabloonkaart",
    "My templates": "Mijn sjablonen",
    "From staff": "Van de beheerders",
    "From community": "Van de community",
    "You must select a template.": "Je moet een sjabloon kiezen",
    "Line decoration": "Lijn tekenstijl",
    "Reuse this template": "Hergebruik dit sjabloon",
    "Create a new map using this template": "Maak een nieuwe kaart met dit sjabloon",
    "Save template": "Sla sjabloon op",
    "Load template": "Laad sjabloon",
    "Loading a template will apply predefined styles and settings to your map": "Loading a template will apply predefined styles and settings to your map",
    "Load template with data": "Load template with data",
    "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".": "You have no registered template yet. You can add one by creating a new map and flagging it as \"template\".",
    "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.": "There is no recommended template yet. Recommended templates are the ones starred by uMap administrators.",
    "There is no public template yet.": "There is no public template yet.",
    "Explore": "Explore",
    "Import data from public open data portals": "Import data from public open data portals",
    "Choose a portal": "Choose a portal",
    "Limit results to current map view": "Limit results to current map view",
    "Please choose an instance first.": "Please choose an instance first."
}
L.registerLocale("nl", locale)
L.setLocale("nl")
