# Generated by Django 4.2.2 on 2023-09-27 08:50

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0013_datalayer_edit_status"),
    ]

    operations = [
        migrations.AddField(
            model_name="map",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, default=django.utils.timezone.now
            ),
            preserve_default=False,
        ),
        # Did not find a way to provide default from a column in the field creation
        migrations.RunSQL("UPDATE umap_map SET created_at=modified_at;"),
    ]
