# Generated by Django 5.1.6 on 2025-02-26 16:18

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("umap", "0026_datalayer_modified_at_datalayer_share_status"),
    ]

    operations = [
        migrations.AddField(
            model_name="map",
            name="tags",
            field=django.contrib.postgres.fields.ArrayField(
                base_field=models.CharField(max_length=200),
                blank=True,
                default=list,
                size=None,
            ),
        ),
    ]
